@@ -519,8 +519,7 @@ int tmout;
 	if (mode == MOVE) {
 	    if (curunit != NULL
 	    	&& in_play(curunit)
-		&& (curunit->act
-		&& curunit->act->acp > 0)  /* should be "above min"? */
+		&& has_acp_left(curunit)
 	    	&& (curunit->plan
 		    && !curunit->plan->asleep
 		    && !curunit->plan->reserve
@@ -1179,8 +1178,6 @@ void
 exit_cconq()
 {
     close_displays();
-    /* Leave any commentary on the console. */
-    printf("\n%s\n", exit_commentary(dside));
     printf("\n%s\n", get_scores(dside));
     exit(0);
 }
