@@ -404,7 +404,6 @@ Unit *from, *to;
 int m, amount;
 {
     int amt2, origfrom = from->supply[m], origto = to->supply[m];
-    Side *side = NULL;
 
     /* Constrain the amount of supply that may be unloaded. */
     amount = min(amount, origfrom);
@@ -416,13 +415,9 @@ int m, amount;
     }
     amt2 = min(amount, um_storage_x(to->type, m) - origto);
 
-    /* Only do this if the unit has a real side. Allowing indepside to
-       use a treasury does prevent crashes, but defeats the purpose of
-       having independent cities that should not cooperate with each
-       other. */
-    /* (should rethink this though -sts) */
-    
-    if (to->side != NULL && um_gives_to_treasury(to->type, m)) {
+    /* Transfer overflow to side's treasury if it exists. */
+    if (side_has_treasury(to->side, m)
+        && um_gives_to_treasury(to->type, m)) {
 	to->side->treasury[m] += (amount - amt2);
     } else {
 	amount = amt2;
@@ -433,8 +428,8 @@ int m, amount;
     update_unit_display(from->side, from, TRUE);
     update_unit_display(to->side, to, TRUE);
     if (amount != amt2) {
-	update_side_display(from->side, side, TRUE);
-	update_side_display(to->side, side, TRUE);
+	update_side_display(from->side, from->side, TRUE);
+	update_side_display(to->side, to->side, TRUE);
     }
     Dprintf("%s (had %d) transfers %d %s to %s (had %d) (%d to side)\n",
 	    unit_desig(from), origfrom, amount, m_type_name(m),
@@ -511,8 +506,8 @@ int u3;
       return A_ANY_ERROR;
     u = unit->type;  u2 = unit2->type;
     side = unit->side;
-    /* Independent units don't do develop. */
-    if (side == NULL)
+    /* Independent units might not do develop. */
+    if (side == indepside && g_indepside_can_develop() == FALSE)
       return A_ANY_ERROR;
     /* This unit must be of a type that can develop the given type. */
     if (uu_acp_to_develop(u2, u3) < 1)
@@ -709,8 +704,6 @@ Side *side;
 Unit *unit;
 int u2, oldtp, newtp;
 {
-    if (side == NULL)
-      return;
     if (oldtp < uu_tp_to_build(unit->type, u2)
 	&& newtp >= uu_tp_to_build(unit->type, u2)) {
 	notify(side, "%s is now tooled to build %s units",
@@ -793,9 +786,17 @@ int u3;
 		    consum = unit2->supply[m];
 		}
 		unit2->supply[m] -= consum;
-		/* Null side crash fix. */
-		if (unit2->side)
-		  unit2->side->treasury[m] -= consum2;
+		
+		/* Use material from treasury if necessary. */
+		if (consum2 > 0) {
+			if (side_has_treasury(unit2->side, m)
+			    && um_takes_from_treasury(unit2->type, m)) {  
+			          unit2->side->treasury[m] -= consum2;	    
+		    	} else {
+				/* Should never happen. */
+		    		run_warning("Unit created even though material was insufficient"); 
+			}
+	         }
 	    }
 	}
 	use_up_acp(unit, uu_acp_to_create(u2, u3));
@@ -852,8 +853,6 @@ int u3;
       return A_ANY_CANNOT_DO;
     /* Check the tech level of the side. */
     if (u_tech_to_build(u3) > 0) {
-	if (unit->side == NULL)
-	  return A_ANY_ERROR;
 	if (unit->side->tech[u3] < u_tech_to_own(u3))
 	  return A_ANY_ERROR;
 	if (unit->side->tech[u3] < u_tech_to_build(u3))
@@ -869,8 +868,12 @@ int u3;
         && !uu_occ_can_build(unit2->transport->type, u2))
       return A_ANY_ERROR;
     for_all_material_types(m) {
- 	/* Null side crash fix. */
-	totsup = unit2->supply[m] + (unit2->side != NULL ? unit2->side->treasury[m] : 0);
+	totsup = unit2->supply[m];
+	/* Add material in treasury if available to this unit. */
+	if (side_has_treasury(unit2->side, m)
+	    && um_takes_from_treasury(unit2->type, m)) {
+	      totsup += unit2->side->treasury[m]; 
+	}
     	if (totsup < um_to_create(u3, m))
     	  return A_ANY_NO_MATERIAL;
     	if (totsup < um_consumption_on_creation(u3, m))
@@ -1015,10 +1018,16 @@ int u3, x, y, z;
 		    consum2 = consum - unit2->supply[m];
 		    consum = unit2->supply[m];
 		}
-		unit2->supply[m] -= consum;
-		/* Null side crash fix. */
-		if (unit2->side)
-		  unit2->side->treasury[m] -= consum2;
+		/* Use material from treasury if necessary. */
+		if (consum2 > 0) {
+			if (side_has_treasury(unit2->side, m)
+			    && um_takes_from_treasury(unit2->type, m)) {  
+			          unit2->side->treasury[m] -= consum2;	    
+		    	} else {
+				/* Should never happen. */
+		    		run_warning("Unit created even though material was insufficient"); 
+			}
+	         }
 	    }
 	}
 	use_up_acp(unit, uu_acp_to_create(u2, u3));
@@ -1211,8 +1220,6 @@ Unit *unit, *unit2, *newunit;
       return A_ANY_ERROR;
     /* Can't finish building a unit until we have the technology. */
     if (u_tech_to_build(u3) > 0) {
-	if (unit->side == NULL)
-	  return A_ANY_ERROR;
 	if (unit->side->tech[u3] < u_tech_to_build(u3))
 	  return A_ANY_ERROR;
     }
@@ -1244,12 +1251,11 @@ Unit *unit, *unit2, *newunit;
 /* Do all the little things to make a fully operational unit. */
 
 void
-make_unit_complete(unit)
-Unit *unit;
+make_unit_complete(Unit *unit)
 {
     int u = unit->type, m;
     SideMask observers;
-    Side *side, *side2;
+    Side *side2;
 
     /* Make this a "complete" but not a "fullsized" unit. */
     unit->cp = max(unit->cp, u_cp(u) / u_parts(u));
@@ -1278,16 +1284,13 @@ Unit *unit;
     if (unit->act) {
 	compute_acp(unit);
 	if (unit->act->initacp > 0) {
-	    side = (unit->side ? unit->side : indepside);
-
 	   /* Make_unit_complete may be called by advanced units at
 	      turn 0 before compose_actionvectors has been called! */
-	   if (side->actionvector == NULL) {
-		side->actionvector = make_unit_vector(max(numunits, 100));
-		clear_unit_vector(side->actionvector);
+	   if (unit->side->actionvector == NULL) {
+		unit->side->actionvector = make_unit_vector(max(numunits, 100));
+		clear_unit_vector(unit->side->actionvector);
 	   }
-	   side->actionvector =
-	     add_unit_to_vector(side->actionvector, unit, 0);
+	   unit->side->actionvector = add_unit_to_vector(unit->side->actionvector, unit, 0);
 	}
     }
     /* Inform all sides that should know about the completion. */
@@ -1295,7 +1298,7 @@ Unit *unit;
     for_all_sides(side2) {
 	if (side2 == unit->side
 	    || trusted_side(unit->side, side2)
-	    /* (or add all sides if all_see_all?) */
+	    /* (or add all sides if g_see_all?) */
 	    ) {
 	    observers = add_side_to_set(unit->side, observers);
 	}
@@ -2187,6 +2190,8 @@ execute_action(Unit *unit, Action *action)
 	    break;
 	  case 'S':
 	    asides[i] = side_n(action->args[i]);
+	    if (asides[i] == NULL)
+	      asides[i] = indepside;
 	    break;
 	  default:
 	    case_panic("action argument type", argtypestr[i]);
@@ -2394,7 +2399,7 @@ execute_action(Unit *unit, Action *action)
        *before* the action, not after (some actions may cause type
        changes). */
     if (u_spot_action(u)
-	&& !all_see_all
+	&& !g_see_all()
 	&& !u_see_always(u)
 	&& in_area(unit->x, unit->y)) {
 	Side *side2;
