@@ -17,6 +17,7 @@ extern void give_up(Side *side, char *ainame);
 /* Declarations of all AI types. */
 
 extern AI_ops mplayer_ops;
+extern AI_ops iplayer_ops;
 
 /* The array of all possible AI types. */
 
@@ -31,6 +32,8 @@ init_ai_types(void)
     all_ai_ops[0] = (AI_ops *) xmalloc(sizeof(AI_ops));
     /* The generic AI "mplayer". */
     all_ai_ops[1] = &mplayer_ops;
+    /* The independent AI "iplayer". */
+    all_ai_ops[2] = &iplayer_ops;
 }
 
 /* Given a side that wants to have an AI running its units, find and
@@ -311,6 +314,9 @@ give_up(Side *side, char *ainame)
 {
     Side *side1;
 
+    /* The independents cannot by definition resign. */
+    if (side == indepside)
+         return;
     /* Can't resign if we've been forbidden to do so. */
     if (side_has_display(side) && !side->ai_may_resign) {
 	/* But speak up about it. */
@@ -380,7 +386,7 @@ int
 cell_unknown(x, y)
 int x, y;
 {
-    return (!all_see_all && !tmpside->see_all && terrain_view(tmpside, x, y) == UNSEEN);
+    return !(tmpside->see_all || terrain_view(tmpside, x, y) != UNSEEN);
 }
 
 int
