@@ -7,8 +7,6 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern int warnings_logged;
-extern Agreement *find_agreement(int id);
 #include "kpublic.h"
 #include "imf.h"
 #include "ui.h"
@@ -206,20 +204,26 @@ TextBuffer *buf;
 /* Generic command functions.  These are the command functions that
    behave identically for all interfaces. */
 
+#define DURING_GAME_ONLY(side)  \
+  if (endofgame) {  \
+    cmd_error((side), "Cannot do after game is over!");  \
+    return;  \
+  }
+
 void
-do_add_player(side)
-Side *side;
+do_add_player(Side *side)
 {
+    DURING_GAME_ONLY(side);
     net_request_additional_side(cmdargstr);
 }
 
 void
-do_agreement_draft(side)
-Side *side;
+do_agreement_draft(Side *side)
 {
     char *title, titlebuf[20];
     Agreement *ag;
 
+    DURING_GAME_ONLY(side);
     /* (should have a net_create_agreement) */
     ag = create_agreement(0);
     if (!empty_string(cmdargstr)) {
@@ -237,30 +241,35 @@ void
 do_agreement_drafter(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
 }
 
 void
 do_agreement_propose(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
 }
 
 void
 do_agreement_proposer(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
 }
 
 void
 do_agreement_sign(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
 }
 
 void
 do_agreement_signer(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
 }
 
 void
@@ -271,6 +280,7 @@ Side *side;
     char *arg, *rest, *term;
     Agreement *ag;
 
+    DURING_GAME_ONLY(side);
     rest = get_next_arg(cmdargstr, tmpbuf, &arg);
     if (empty_string(arg)) {
 	cmd_error(side, "no agreement id");
@@ -295,11 +305,11 @@ Side *side;
 /* Set which AI is to run the side's play. */
 
 void
-do_ai_side(side)
-Side *side;
+do_ai_side(Side *side)
 {
-    char *arg, *rest, *aitypename = "mplayer";
+    char *arg, *rest, *aitypename = NULL;
 
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr)) {
 	rest = get_next_arg(cmdargstr, tmpbuf, &arg);
 	if (strcmp(arg, "+") == 0) {
@@ -314,22 +324,30 @@ Side *side;
 	    rest = get_next_arg(rest, tmpbuf, &arg);
 	}
 	aitypename = arg;
-    }
-    if (empty_string(cmdargstr) && side_has_ai(side)) {
-	net_set_side_ai(side, NULL);
-    } else if (empty_string(aitypename)) {
-	/* Was just toggling AI control flag. */
+	}
+    if (empty_string(aitypename)) {
+    	/* Toggle AI between mplayer, iplayer and NULL. */
+    	if (side->player->aitypename == NULL) {
+	      net_set_side_ai(side, "mplayer");
+		} else if (strcmp(side->player->aitypename, "mplayer") == 0) {   	    
+	      net_set_side_ai(side, "iplayer");
+		} else {
+	      net_set_side_ai(side, NULL);
+    	}
+	/* Special case to handle command "AI None" in Side menu. */
+	} else if (strcmp(aitypename, "none") == 0) {
+		net_set_side_ai(side, NULL);
     } else {
-	net_set_side_ai(side, aitypename);
+		net_set_side_ai(side, aitypename);
     }
 }
 
 void
-do_distrust(side)
-Side *side;
+do_distrust(Side *side)
 {
     Side *side2;
 
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr)) {
 	side2 = parse_side_spec(cmdargstr);
 	if (side2 != NULL && side2 != side) {
@@ -344,6 +362,7 @@ void
 do_doctrine(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr)) {
 	if (strcmp(cmdargstr, "set") == 0) {
 	    notify(side, "Set what?");
@@ -370,6 +389,7 @@ void
 do_draw_willingness(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
     if (side->prefixarg < 0)
       side->prefixarg = 1;
     net_set_willing_to_draw(side, (side->prefixarg ? 1 : 0));
@@ -381,6 +401,7 @@ void
 do_end_turn(side)
 Side *side;
 {
+    DURING_GAME_ONLY(side);
     net_finish_turn(side);
 }
 
@@ -390,6 +411,7 @@ Side *side;
 {
     Unit *unit;
     
+    DURING_GAME_ONLY(side);
     for_all_side_units(side, unit) {
 	if (in_play(unit) && unit->plan != NULL) {
 	    net_force_replan(side, unit, FALSE);
@@ -403,6 +425,7 @@ Side *side;
 {
     Side *side2;
 
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr)) {
 	side2 = parse_side_spec(cmdargstr);
 	if (side2 != NULL && side2 != side) {
@@ -419,6 +442,7 @@ Side *side;
 {
     int turns;
 
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr))
       turns = atoi(cmdargstr);
     else
@@ -441,6 +465,7 @@ Side *side;
     int slow, fast;
     char *reststr;
 
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr)) {
 	slow = strtol(cmdargstr, &reststr, 10);
 	fast = strtol(reststr, &reststr, 10);
@@ -454,6 +479,7 @@ Side *side;
 {
     Side *side2;
 
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr)) {
 	side2 = parse_side_spec(cmdargstr);
 	if (side2 != NULL && side2 != side) {
@@ -469,6 +495,7 @@ Side *side;
 {
     Side *side2;
 
+    DURING_GAME_ONLY(side);
     if (!empty_string(cmdargstr)) {
 	side2 = parse_side_spec(cmdargstr);
 	if (side2 != NULL && side2 != side) {
