@@ -180,9 +180,7 @@ int n;
    to attack and/or capture any units in the way. */
 
 int
-prep_overrun_action(unit, unit2, x, y, z, n)
-Unit *unit, *unit2;
-int x, y, z, n;
+prep_overrun_action(Unit *unit, Unit *unit2, int x, int y, int z, int n)
 {
     if (unit == NULL || unit->act == NULL || unit2 == NULL)
       return FALSE;
@@ -196,9 +194,7 @@ int x, y, z, n;
 }
 
 int
-net_prep_overrun_action(unit, unit2, x, y, z, n)
-Unit *unit, *unit2;
-int x, y, z, n;
+net_prep_overrun_action(Unit *unit, Unit *unit2, int x, int y, int z, int n)
 {
     int rslt;
 
@@ -208,9 +204,7 @@ int x, y, z, n;
 }
 
 int
-do_overrun_action(unit, unit2, x, y, z, n)
-Unit *unit, *unit2;
-int x, y, z, n;
+do_overrun_action(Unit *unit, Unit *unit2, int x, int y, int z, int n)
 {
     int u, u2, u3, acpused, mpcost, acpcost, speed, ox, oy, oz;
     int withdrawchance, surrenderchance, gotonext;
@@ -247,8 +241,9 @@ int x, y, z, n;
 		gotonext = TRUE;
 	    }
 	}
+	/* (should automatically prefer direct attack if better odds) */
 	if (can_fire(unit)) {
-	    do_fire_at_action(unit, unit, unit2, -1); 
+	    do_fire_at_action(unit, unit, defender, -1); 
 	    acpused += u_acp_to_fire(u2);
 	    /* Unlike the case below, target acp consumption has
 	       already been dealt with in fire_on_unit, which is
@@ -296,9 +291,7 @@ int x, y, z, n;
 }
 
 int
-check_overrun_action(unit, unit2, x, y, z, n)
-Unit *unit, *unit2;
-int x, y, z, n;
+check_overrun_action(Unit *unit, Unit *unit2, int x, int y, int z, int n)
 {
     int u, u2, u2x, u2y, u2z, u3, totcost, speed, mpavail, m;
     Unit *defender;
@@ -356,8 +349,7 @@ int x, y, z, n;
    try to move into the defender's old position. */
 
 static int
-one_attack(atker, defender)
-Unit *atker, *defender;
+one_attack(Unit *atker, Unit *defender)
 {
     int ua = atker->type, ud = defender->type;
     int ax = atker->x, ay = atker->y, ox = defender->x, oy = defender->y;
@@ -974,30 +966,33 @@ maybe_hit_unit(Unit *atker, Unit *other, int fire, int fallsoff)
     }
     hit_unit(other, hit, atker);
     /* Pick the hit movie to show. */
-    hitmovietype = ((hit >= other->hp) ? "death" : ((hit > 0) ? "hit" : "miss"));
+    hitmovietype =
+      ((hit >= other->hp) ? "death" : ((hit > 0) ? "hit" : "miss"));
     /* Make up the list of sides that will see it. */
     sidemask = NOSIDES;
     for_all_sides(side3) {
-    /* Let all sides that can see the attacker's cell see it. */
+	/* Let all sides that can see the attacker's cell see it. */
 	if (units_visible(side3, atker->x, atker->y))
-		sidemask = add_side_to_set(side3, sidemask);
-    /* Let all sides that can see the defender's cell see it. */
+	  sidemask = add_side_to_set(side3, sidemask);
+	/* Let all sides that can see the defender's cell see it. */
 	if (units_visible(side3, other->x, other->y))
-		sidemask = add_side_to_set(side3, sidemask);
+	  sidemask = add_side_to_set(side3, sidemask);
     }
     /* Show the movie. */
     for_all_sides(side3) {
 	if (side_in_set(side3, sidemask))
-		schedule_movie(side3, hitmovietype, other->id);
+	  schedule_movie(side3, hitmovietype, other->id);
     }
     Dprintf("\n");
     /* Recurse into occupants, maybe hit them too.  */
     for_all_occupants(other, occ) {
 	if (is_active(other)) {
-		if (probability(uu_protection(o, occ->type)))
-		 maybe_hit_unit(atker, occ, fire, fallsoff);
-     	/* No protection by incomplete transport. */
-    	} else maybe_hit_unit(atker, occ, fire, fallsoff);
+	    if (probability(uu_protection(o, occ->type)))
+	      maybe_hit_unit(atker, occ, fire, fallsoff);
+    	} else {
+	    /* No protection by incomplete transport. */
+	    maybe_hit_unit(atker, occ, fire, fallsoff);
+	}
     }
     /* We get combat experience only if there could have been some damage. */
     if (chance > 0) {
@@ -1012,9 +1007,7 @@ maybe_hit_unit(Unit *atker, Unit *other, int fire, int fallsoff)
 /* Do the hit itself. */
 
 static void
-hit_unit(unit, hit, atker)
-Unit *unit, *atker;
-int hit;
+hit_unit(Unit *unit, int hit, Unit *atker)
 {
     int u = unit->type, u2, hpmin, dmgspec, tpdmg, tp;
 
@@ -1079,8 +1072,7 @@ int hit;
 /* (What if occupants change type when killed, but transport vanishes?) */
 
 static void
-reckon_damage(fire)
-int fire;
+reckon_damage(int fire)
 {
     /* Entertain everybody. */
     play_movies(ALLSIDES);
@@ -1103,8 +1095,7 @@ int fire;
 }
 
 static void
-reckon_damage_here(x, y)
-int x, y;
+reckon_damage_here(int x, int y)
 {
     Unit *unit;
 
@@ -1114,8 +1105,7 @@ int x, y;
 }
 
 void
-reckon_damage_around(x, y, r)
-int x, y, r;
+reckon_damage_around(int x, int y, int r)
 {
     if (r > 0) {
 	apply_to_area(x, y, r, reckon_damage_here);
@@ -1125,8 +1115,7 @@ int x, y, r;
 }
 
 static void
-report_damage(unit, atker, mainunit)
-Unit *unit, *atker, *mainunit;
+report_damage(Unit *unit, Unit *atker, Unit *mainunit)
 {
     Unit *occ;
 
@@ -1155,8 +1144,7 @@ Unit *unit, *atker, *mainunit;
 }
 
 static int
-will_report_damage(unit)
-Unit *unit;
+will_report_damage(Unit *unit)
 {
     Unit *occ;
 
@@ -1172,9 +1160,7 @@ Unit *unit;
 /* Make the intended damage become real, and do any consequences. */
 /* (should include agent unit with hevts if appropriate) */
 void
-damage_unit(unit, dmgreason, agent)
-Unit *unit, *agent;
-enum damage_reasons dmgreason;
+damage_unit(Unit *unit, enum damage_reasons dmgreason, Unit *agent)
 {
     int newacp;
     HistEventType hevttype;
@@ -1660,6 +1646,7 @@ Side *prevside;
 {
     int chance, x, y, notesee;
     Unit *occ, *unit2;
+    Side *newside;
 
     /* Our new unit's experience might be higher or lower, depending on what
        capture really means (change of crew perhaps). */
@@ -1678,19 +1665,20 @@ Side *prevside;
     /* (should probably adjust side's acp sums by new unit's amounts) */
     init_unit_plan(pris);
     /* Maybe get a pile of interesting information. */
-    if (!all_see_all
-	&& unit->side
-	&& !unit->side->see_all
+    newside = unit->side;
+    if (newside
+	&& !newside->see_all
 	&& prevside != NULL) {
 	notesee = FALSE;
 	chance = u_see_terrain_captured(pris->type);
 	if (!g_terrain_seen() && probability(chance)) {
 	    for_all_cells(x, y) {
 		if (terrain_view(prevside, x, y) != UNSEEN
-		    && terrain_view(unit->side, x, y) == UNSEEN) {
-		    set_terrain_view(unit->side, x, y, terrain_view(prevside, x, y));
+		    && terrain_view(newside, x, y) == UNSEEN) {
+		    set_terrain_view(newside, x, y,
+				     terrain_view(prevside, x, y));
 		    /* (should also view see-always units here) */
-		    update_cell_display(unit->side, x, y, UPDATE_ALWAYS);
+		    update_cell_display(newside, x, y, UPDATE_ALWAYS);
 		    notesee = TRUE;
 		}
 	    }
@@ -1700,15 +1688,19 @@ Side *prevside;
 		if (in_play(unit2)) {
 		    chance = uu_see_others_captured(pris->type, unit2->type);
 		    if (probability(chance)) {
-			see_exact(unit->side, unit2->x, unit2->y);
-			update_cell_display(unit->side, unit2->x, unit2->y, UPDATE_ALWAYS);
+			see_exact(newside, unit2->x, unit2->y);
+			update_cell_display(newside, unit2->x, unit2->y,
+					    UPDATE_ALWAYS);
 			notesee = TRUE;
 		    }
 		}
 	    }
 	}
+	/* Only say something to the capturing side if we actually got
+	   any new information - after several captures, may not be
+	   anything new to find out. */
 	if (notesee) {
-	    notify(unit->side, "Enemy information fell into your hands!");
+	    notify(newside, "Enemy information fell into your hands!");
 	}
     }
     /* Likewise for occupants. */
@@ -1823,7 +1815,8 @@ detonate_unit(Unit *unit, int x, int y, int z)
     report_combat(unit, NULL, "detonate");
     for_all_sides(side) {
     	if (active_display(side)
-	    && (all_see_all
+	    /* (should figure out proper visibility rules) */
+	    && (g_see_all()
     	    	|| (side == unit->side || 1))) {
 	    schedule_movie(side, "flash", unit->x, unit->y);
     	}
@@ -1905,7 +1898,8 @@ hit_unit_with_detonation(Unit *unit, int hit, Unit *atker)
     hit_unit(unit, hit, atker);
     for_all_sides(side) {
     	if (active_display(side)
-	    && (all_see_all
+	    /* (should figure out visibility rules) */
+	    && (g_see_all()
 	        || side == unit->side
 	        || 0 /* visible to other sides */)) {
 	    hitmovietype = ((hit >= unit->hp) ? "death" :
@@ -2209,11 +2203,9 @@ mobile_enemy_threat(Unit *unit, int range)
 	
     /* Go through all cells within the specified range. */
     for_all_cells_within_range(unit->x, unit->y, range, x, y) {
-		Side *sidex = (unit->side ? unit->side : indepside);
-    	
 		if (!inside_area(x, y))
 		  continue;
-		if (!terrain_visible(sidex, x, y))
+		if (!terrain_visible(unit->side, x, y))
 		  continue;
 		/* Important to count also occupants here. */
 		for_all_stack_with_occs(x, y, unit2) {
@@ -2223,10 +2215,10 @@ mobile_enemy_threat(Unit *unit, int range)
 			/* The NULL side rarely attacks anybody :-) */
 			&& unit2->side
 			&& mobile(unit2->type)
-			&& unit_actually_visible(sidex, unit2)
-			&& !trusted_side(sidex, unit2->side)
+			&& side_sees_image(unit->side, unit2)
+			&& !trusted_side(unit->side, unit2->side)
 			&& (could_hit(unit2->type, unit->type)
-			    || capture_chance(unit2->type, unit->type, sidex) > 0)) {
+			    || capture_chance(unit2->type, unit->type, unit->side) > 0)) {
 			return unit2;
 		    }
 		}
