@@ -50,12 +50,12 @@ extern enum setup_stage current_stage;
 /* Declarations of globally visible globals. */
 
 extern int gamedefined;
+extern int gameinited;
 extern int compromised;
 extern int cursequence;
 extern int beforestart;
 extern int endofgame;
 extern int gamestatesafe;
-extern int interfacestatesafe;
 extern int any_post_action_scores;
 extern short any_people_side_changes;
 extern int max_zoc_range;
@@ -87,6 +87,8 @@ extern int sunx, suny;
 
 extern short daynight;
 
+extern int warnings_logged;
+
 /* Declarations of functions that must be supplied by an interface. */
 
 extern void announce_read_progress(void);
@@ -174,6 +176,10 @@ extern char *version_string(void);
 extern char *copyright_string(void);
 extern char *license_string(void);
 extern int already_seen_chance(Side *side, Unit *unit);
+extern void add_remote_players(void);
+extern void set_player_advantage(int n, int newadv);
+extern void rename_side_for_player(int n);
+extern void set_ai_for_player(int n, char *aitype);
 
 /* read.c */
 
@@ -366,7 +372,6 @@ extern char *summarize_units(char *buf, int *ucnts);
 extern void notify_doctrine(Side *side, char *spec);
 extern void report_combat(Unit *unit, Unit *atker, char *str);
 extern void report_take(Side *side, Unit *unit, int needed, short *rslts);
-extern char *exit_commentary(Side *side);
 extern char *ordinal_suffix(int n);
 extern char *plural_form(char *word);
 extern char *make_text(char *buf, Obj *maker, long a1, long a2, long a3, long a4);
@@ -453,4 +458,3 @@ int supply_system_in_use(void);
 void compute_supply_zones(Side *side, int m);
 void compute_unit_supply_zone(Side *side, Unit *unit, int m);
 extern int has_advance_to_build(Side *side, int a);
-extern int unit_actually_visible(Side *side, Unit *unit);
