@@ -1426,8 +1426,8 @@ TextBuffer *buf;
 	ut_table_row_desc(buf, u, ut_attrition, tb_percent_100th_desc, "in");
 	tbcat(buf, ".\n");
     }
-    /* Don't bother with this if standard economy has been disabled. */
-    if (nummtypes > 0 && !g_disable_standard_economy()) {
+    /* Don't bother with this if economy code is not running. */
+    if (nummtypes > 0 && g_economy()) {
 	tbcat(buf, "\nMaterial Handling:\n");
 	for_all_material_types(m) {
 	    usesm = FALSE;
