@@ -2015,9 +2015,10 @@ get_generic_images(char *name)
 	    /* Load data filling in the family. */
 	    for_all_library_paths(path) {
 		make_pathname(path->path, imf->location->name, "", spbuf);
-		if (load_imf_file(spbuf, NULL))
+		if (load_imf_file(spbuf, NULL)) {
 		  found = TRUE;
 		  break;
+		}
 	    }
 	    /* Maybe try the plain filename, just in case. */
 	    if (!found)
