@@ -27,6 +27,7 @@ static Obj *read_form_aux(Strm *strm);
 static Obj *read_list(Strm *strm);
 static int read_delimited_text(Strm *strm, char *delim, int spacedelimits,
 			       int eofdelimits);
+static void internal_type_error(char *funname, Obj *x, char *typename);
 
 /* Pointer to "nil", the empty list. */
 
@@ -233,9 +234,11 @@ Strm *strm;
     strcat(buf, ")");
 }
 
+/* The main body of the the Lisp reader, works from a stream and returns
+   an object. */
+
 static Obj *
-read_form_aux(strm)
-Strm *strm;
+read_form_aux(Strm *strm)
 {
     int minus, factor, commentclosed, ch, ch2, ch3, ch4, num;
     int numdice, dice, indice;
@@ -356,6 +359,14 @@ Strm *strm;
 	    if (minus)
 	      num = 0 - num;
 	    if (numdice > 0) {
+		/* Warn about out-of-bounds values. */
+		if (!between(0, numdice, 7))
+		  init_warning("Number of dice is %d, not between 0 and 7",
+			       numdice);
+		if (!between(0, dice, 15))
+		  init_warning("Dice size is %d, not between 0 and 15", dice);
+		if (!between(0, num, 127))
+		  init_warning("Dice addon is %d, not between 0 and 127", num);
 	    	num = (1 << 14) | (numdice << 11) | (dice << 7) | (num & 0x7f);
 	    } else {
 	    	num = factor * num;
@@ -578,22 +589,21 @@ char *ptr;
 }
 
 Obj *
-cons(x, y)
-Obj *x, *y;
+cons(Obj *x, Obj *y)
 {
     Obj *new = newobj();
 
     new->type = CONS;  
     new->v.cons.car = x;  new->v.cons.cdr = y;
+    /* Xconq's Lisp does not include dot notation for consing, so this
+       can only happen if there is an internal error somewhere. */
     if (!listp(y))
-      run_warning("cdr of cons is not a list");
+      run_error("cdr of cons is not a list");
     return new;
 }
 
 void
-type_warning(funname, x, typename, subst)
-char *funname, *typename;
-Obj *x, *subst;
+type_warning(char *funname, Obj *x, char *typename, Obj *subst)
 {
     char buf1[BUFSIZE], buf2[BUFSIZE];
 
@@ -603,28 +613,37 @@ Obj *x, *subst;
                 funname, typename, buf1, buf2);
 }
 
+/* This routine reports fatal errors with handling objects. */
+
+static void
+internal_type_error(char *funname, Obj *x, char *typename)
+{
+    char buf1[BUFSIZE];
+
+    sprintlisp(buf1, x, BUFSIZE);
+    run_error("%s of non-%s `%s'", funname, typename, buf1);
+}
+
 /* The usual suspects. */
 
 Obj *
-car(x)
-Obj *x;
+car(Obj *x)
 {
     if (x->type == CONS || x->type == NIL) {
 	return x->v.cons.car;
     } else {
-    	type_warning("Car", x, "list", lispnil);
+    	internal_type_error("car", x, "list");
 	return lispnil;
     }
 }
 
 Obj *
-cdr(x)
-Obj *x;
+cdr(Obj *x)
 {
     if (x->type == CONS || x->type == NIL) {
 	return x->v.cons.cdr;
     } else {
-    	type_warning("Cdr", x, "list", lispnil);
+    	internal_type_error("cdr", x, "list");
 	return lispnil;
     }
 }
@@ -664,7 +683,7 @@ Obj *x, *v;
     if (x->type == CONS) {
 	x->v.cons.cdr = v;
     } else {
-    	type_warning("set_cdr", x, "cons", lispnil);
+    	internal_type_error("set_cdr", x, "cons");
     }
 }
 
@@ -679,6 +698,7 @@ Obj *x;
     } else if (x->type == SYMBOL) {
 	return x->v.sym.symentry->name;
     } else {
+	/* (should be internal_type_error?) */
      	type_warning("c_string", x, "string/symbol", lispnil);
 	return "";
    }
@@ -697,6 +717,7 @@ Obj *x;
 	|| x->type == ATYPE) {
 	return x->v.num;
     } else {
+	/* (should be internal_type_error?) */
      	type_warning("c_number", x, "number", lispnil);
 	return 0;
     }
@@ -748,15 +769,13 @@ char *str;
 }
 
 static int
-hash_name(str)
-char *str;
+hash_name(char *str)
 {
     return str[0];
 }
 
 Obj *
-symbol_value(sym)
-Obj *sym;
+symbol_value(Obj *sym)
 {
     Obj *val = sym->v.sym.value;
 
@@ -768,12 +787,11 @@ Obj *sym;
 }
 
 Obj *
-setq(sym, x)
-Obj *sym, *x;
+setq(Obj *sym, Obj *x)
 {
+    /* All the callers check for symbolness, but be careful. */
     if (!symbolp(sym)) {
-	run_warning("Can't set a non-symbol, ignoring attempt");
-	return x;
+	internal_type_error("setq", sym, "symbol");
     }
     if (constantp(sym)) {
     	run_warning("Can't alter the constant `%s', ignoring attempt",
@@ -785,99 +803,85 @@ Obj *sym, *x;
 }
 
 void
-makunbound(sym)
-Obj *sym;
+makunbound(Obj *sym)
 {
     sym->v.sym.value = lispunbound;
 }
 
 void
-flag_as_constant(sym)
-Obj *sym;
+flag_as_constant(Obj *sym)
 {
     sym->v.sym.symentry->constantp = TRUE;
 }
 
 int
-constantp(sym)
-Obj *sym;
+constantp(Obj *sym)
 {	
     return (sym->v.sym.symentry->constantp);
 }
 
 int
-numberp(x)
-Obj *x;
+numberp(Obj *x)
 {
     return (x->type == NUMBER);
 }
 
 int
-stringp(x)
-Obj *x;
+stringp(Obj *x)
 {
     return (x->type == STRING);
 }
 
 int
-symbolp(x)
-Obj *x;
+symbolp(Obj *x)
 {
     return (x->type == SYMBOL);
 }
 
 int
-consp(x)
-Obj *x;
+consp(Obj *x)
 {
     return (x->type == CONS);
 }
 
 int
-utypep(x)
-Obj *x;
+utypep(Obj *x)
 {
     return (x->type == UTYPE);
 }
 
 int
-mtypep(x)
-Obj *x;
+mtypep(Obj *x)
 {
     return (x->type == MTYPE);
 }
 
 int
-ttypep(x)
-Obj *x;
+ttypep(Obj *x)
 {
     return (x->type == TTYPE);
 }
 
 int
-atypep(x)
-Obj *x;
+atypep(Obj *x)
 {
     return (x->type == ATYPE);
 }
 
 int
-pointerp(x)
-Obj *x;
+pointerp(Obj *x)
 {
     return (x->type == POINTER);
 }
 
 int
-boundp(sym)
-Obj *sym;
+boundp(Obj *sym)
 {
     return (sym->v.sym.value != lispunbound);
 }
 
 int
-numberishp(x)
-Obj *x;
+numberishp(Obj *x)
 {
     return (x->type == NUMBER
 	    || x->type == UTYPE
@@ -887,18 +891,16 @@ Obj *x;
 }
 
 int
-listp(x)
-Obj *x;
+listp(Obj *x)
 {
     return (x->type == NIL || x->type == CONS);
 }
 
 /* General structural equality test.  Assumes that it is not getting
-   passed any circular structures. */
+   passed any circular structures, which should never happen in Xconq. */
 
 int
-equal(x, y)
-Obj *x, *y;
+equal(Obj *x, Obj *y)
 {
     /* Objects of different types can never be equal. */
     if (x->type != y->type)
@@ -928,8 +930,7 @@ Obj *x, *y;
 }
 
 int
-member(x, lis)
-Obj *x, *lis;
+member(Obj *x, Obj *lis)
 {
     if (lis == lispnil) {
 	return FALSE;
@@ -946,9 +947,7 @@ Obj *x, *lis;
 /* Return the nth element of a list. */
 
 Obj *
-elt(lis, n)
-Obj *lis;
-int n;
+elt(Obj *lis, int n)
 {
     while (n-- > 0) {
 	lis = cdr(lis);
@@ -957,8 +956,7 @@ int n;
 }
 
 Obj *
-reverse(lis)
-Obj *lis;
+reverse(Obj *lis)
 {
     Obj *rslt = lispnil;
 
@@ -969,9 +967,7 @@ Obj *lis;
 }
 
 Obj *
-find_at_key(lis, key)
-Obj *lis;
-char *key;
+find_at_key(Obj *lis, char *key)
 {
     Obj *rest, *bdgs, *bdg;
 
@@ -986,9 +982,7 @@ char *key;
 }
 
 Obj *
-replace_at_key(lis, key, newval)
-Obj *lis, *newval;
-char *key;
+replace_at_key(Obj *lis, char *key, Obj *newval)
 {
     Obj *rest, *bdgs, *bdg;
 
@@ -1004,9 +998,7 @@ char *key;
 }
 
 void
-fprintlisp(fp, obj)
-FILE *fp;
-Obj *obj;
+fprintlisp(FILE *fp, Obj *obj)
 {
     int needescape;
     char *str, *tmp;
@@ -1086,9 +1078,7 @@ Obj *obj;
 }
 
 void
-fprint_list(fp, obj)
-FILE *fp;
-Obj *obj;
+fprint_list(FILE *fp, Obj *obj)
 {
     Obj *tmp;
 
@@ -1100,10 +1090,7 @@ Obj *obj;
 }
 
 void
-sprintlisp(buf, obj, maxlen)
-char *buf;
-Obj *obj;
-int maxlen;
+sprintlisp(char *buf, Obj *obj, int maxlen)
 {
     if (maxlen < 10) {
 	strcpy(buf, " ... ");
@@ -1161,10 +1148,7 @@ int maxlen;
 }
 
 void
-sprint_list(buf, obj, maxlen)
-char *buf;
-Obj *obj;
-int maxlen;
+sprint_list(char *buf, Obj *obj, int maxlen)
 {
     Obj *tmp;
 
@@ -1184,8 +1168,7 @@ int maxlen;
    be read in again. */
 
 char *
-escaped_symbol(str)
-char *str;
+escaped_symbol(char *str)
 {
     char *tmp = str;
 
@@ -1209,8 +1192,7 @@ char *str;
    strings of length 0. */
 
 char *
-escaped_string(str)
-char *str;
+escaped_string(char *str)
 {
     char *tmp = str, *rslt = escapedthingbuf;
 
