@@ -1,5 +1,5 @@
 /* Terrain generation for Xconq.
-   Copyright (C) 1986-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1986-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -9,41 +9,41 @@ any later version.  See the file COPYING.  */
 /* This is the collection of terrain generation methods. */
 
 #include "conq.h"
-extern void divide_into_regions PARAMS ((char *tlayer, TRegion **rlayer));
+extern void divide_into_regions(char *tlayer, TRegion **rlayer);
 #include "kernel.h"
 
-static void make_blobs PARAMS ((short *layer, int numblobs, int blobradius, int blobalt));
-static void limit_layer PARAMS ((short *layer, int hi, int lo));
-static void smooth_layer PARAMS ((short *layer, int times));
-static void percentile PARAMS ((short *layer, int *percentiles));
-static void compose_area PARAMS ((void));
-static int terrain_from_percentiles PARAMS ((int x, int y));
-static void make_earthlike_fractal_terrain PARAMS ((int calls, int runs));
-static void compose_earthlike_area PARAMS ((void));
-static int earthlike_terrain_from_percentiles PARAMS ((int x, int y));
-static void dig_maze_path PARAMS ((int x1, int y1, int dir1));
-static void dig_maze_path_between PARAMS ((int x1, int y1, int x2, int y2));
-static int test_maze_segment PARAMS ((int x, int y, int dir));
-static int sort_maze_segments PARAMS ((int x, int y, int *dirchoices,
-				       int numchoices));
-static int lay_maze_segment PARAMS ((int x, int y, int dir, int choice,
-				     int numchoices));
-static int num_open_adj PARAMS ((int x, int y));
-static int random_solid_terrain PARAMS ((void));
-static int random_room_terrain PARAMS ((void));
-static int random_passage_terrain PARAMS ((void));
-static void set_room_interior PARAMS ((int x, int y));
-static void name_highest_peaks PARAMS ((char *specificname, Obj *parms));
-static int high_point PARAMS ((int x, int y));
-static void name_islands PARAMS ((char *specificname, Obj *parms));
-static void name_lakes PARAMS ((char *specificname, Obj *parms));
-static void name_bays PARAMS ((char *specificname, Obj *parms));
-static int bay_point PARAMS ((int x, int y));
-static char *name_feature_at PARAMS ((int x, int y, char *typename));
-static char *name_feature_at_using PARAMS ((Obj *namerlist, int x, int y, char *typename));
-static void fix_adjacent_terrain PARAMS ((void));
-static void flatten_liquid_terrain PARAMS ((void));
-static void set_edge_values PARAMS ((int x, int y, int t));
+static void make_blobs(short *layer, int numblobs, int blobradius,
+		       int blobalt);
+static void limit_layer(short *layer, int hi, int lo);
+static void smooth_layer(short *layer, int times);
+static void percentile(short *layer, int *percentiles);
+static void compose_area(void);
+static int terrain_from_percentiles(int x, int y);
+static void make_earthlike_fractal_terrain(int calls, int runs);
+static void compose_earthlike_area(void);
+static int earthlike_terrain_from_percentiles(int x, int y);
+static void dig_maze_path(int x1, int y1, int dir1);
+static void dig_maze_path_between(int x1, int y1, int x2, int y2);
+static int test_maze_segment(int x, int y, int dir);
+static int sort_maze_segments(int x, int y, int *dirchoices, int numchoices);
+static int lay_maze_segment(int x, int y, int dir, int choice, int numchoices);
+static int num_open_adj(int x, int y);
+static int random_solid_terrain(void);
+static int random_room_terrain(void);
+static int random_passage_terrain(void);
+static void set_room_interior(int x, int y);
+static void name_highest_peaks(char *specificname, Obj *parms);
+static int high_point(int x, int y);
+static void name_islands(char *specificname, Obj *parms);
+static void name_lakes(char *specificname, Obj *parms);
+static void name_bays(char *specificname, Obj *parms);
+static int bay_point(int x, int y);
+static char *name_feature_at(int x, int y, char *typename);
+static char *name_feature_at_using(Obj *namerlist, int x, int y,
+				   char *typename);
+static void fix_adjacent_terrain(void);
+static void flatten_liquid_terrain(void);
+static void set_edge_values(int x, int y, int t);
 
 /* Fractal terrain generation. */
 
@@ -540,7 +540,7 @@ int
 make_earthlike_terrain(calls, runs)
 int calls, runs;
 {
-    int t, x, y, elevrange;
+    int t, elevrange;
     int seafrac, desertfrac, forestfrac;
 
     if (terrain_defined())
@@ -704,8 +704,8 @@ int calls, runs;
 static void
 compose_earthlike_area()
 {
-    int x, y, t, t2, t3;
-    int elev, elevrange[MAXTTYPES], elevlo[MAXTTYPES], elevhi[MAXTTYPES];
+    int x, y, t;
+    int elev, elevrange[MAXTTYPES];
 
     Dprintf("Assigning terrain types to cells...\n");
     /* Make the terrain layer itself. */
