@@ -195,8 +195,8 @@ make_countries(int calls, int runs)
 		    totnumtodo += numtodo[u];
 		}
 		/* Seems logical that null side does not get units at start it can't build. */
-		if (type_allowed_on_side(u, NULL)
-		    && has_advance_to_build(NULL, u)) {
+		if (type_allowed_on_side(u, indepside)
+		    && has_advance_to_build(indepside, u)) {
 			numindeptodo[u] = (u_indep_near_start(u) * advantage) / sideadvantage;
 			totnumtodo += numindeptodo[u];
 		}
@@ -220,7 +220,7 @@ make_countries(int calls, int runs)
 	    for_all_unit_types(u) {
 		for (i = 0; i < numindeptodo[u]; ++i) {
 		    if (find_unit_place(u, x0, y0, &x, &y)) {
-			place_unit(u, NULL, x, y, NULL);
+			place_unit(u, indepside, x, y, NULL);
 		    } else {
 			/* If can't find places for this type, give up. */
 			numindepleft[u] = numindeptodo[u] - i;
@@ -299,6 +299,10 @@ int runs;
     int sideadvantage = max(1, side->advantage);
     int advantage = (side->player ? side->player->advantage : sideadvantage);
 
+    /* Don't make any more independent units than preassigned. This prevents 
+    the formation of a third side in games like flattop.g and duel.g. */
+    if (side == indepside)
+      return TRUE;
     /* If side no longer in game, then we don't want to do country
        synth on it. */
     if (!side->ingame)
