@@ -1147,15 +1147,15 @@ int
 sides_allow_entry(unit, transport)
 Unit *unit, *transport;
 {
-    if (unit->side == NULL) {
-    	if (transport->side == NULL) {
+    if (unit->side == indepside) {
+    	if (transport->side == indepside) {
     	    return TRUE;
     	} else {
 	    /* (should fix this - table does not apply to indeps entering?) */
     	    return uu_can_enter_indep(unit->type, transport->type);
     	}
     } else {
-    	if (transport->side == NULL) {
+    	if (transport->side == indepside) {
     	    return uu_can_enter_indep(unit->type, transport->type);
     	} else {
 	    /* Note that because this is for an explicit action, the unit
