@@ -219,23 +219,21 @@ pad_out(char *buf, int n)
 char *
 side_name(Side *side)
 {
-    return (side == NULL ? "independent" :
-      (side->name ? side->name :
+    return (side->name ? side->name :
 	    (side->adjective ? side->adjective :
 	     (side->pluralnoun ? side->pluralnoun :
 	      (side->noun ? side->noun :
-	       "")))));
+	       ""))));
 }
 
 char *
 side_adjective(Side *side)
 {
-    return (side == NULL ? "independent" :
-       (side->adjective ? side->adjective :
+    return (side->adjective ? side->adjective :
 	    (side->noun ? side->noun :
 	     (side->pluralnoun ? side->pluralnoun :
 	      (side->name ? side->name :
-	       "")))));
+	       ""))));
 }
 
 char *
@@ -243,9 +241,7 @@ short_side_title(Side *side)
 {
     if (side_short_title == NULL)
       side_short_title = xmalloc(BUFSIZE);
-    if (side == NULL) {
-	return " - ";
-    } else if (side->name) {
+    if (side->name) {
 	return side->name;
     } else if (side->pluralnoun) {
 	sprintf(side_short_title, "the %s", side->pluralnoun);
@@ -265,9 +261,7 @@ short_side_title_with_adjective(Side *side, char *adjective)
     if (side_short_title == NULL)
       side_short_title = xmalloc(BUFSIZE);
     side_short_title[0] = '\0';
-    if (side == NULL) {
-	return " - ";
-    } else if (side->name) {
+    if (side->name) {
 	if (empty_string(adjective))
 	  return side->name;
 	else {
@@ -309,9 +303,7 @@ short_side_title_with_adjective(Side *side, char *adjective)
 int
 short_side_title_plural_p(Side *side)
 {
-    if (side == NULL) {
-	return FALSE;
-    } else if (side->name) {
+    if (side->name) {
 	return FALSE;
     } else if (side->pluralnoun) {
 	return TRUE;
@@ -328,9 +320,7 @@ short_side_title_plural_p(Side *side)
 char *
 shortest_side_title(Side *side2, char *buf)
 {
-    if (side2 == NULL) {
-	return "-";
-    } else if (side2->name) {
+    if (side2->name) {
 	return side2->name;
     } else if (side2->adjective) {
 	return side2->adjective;
@@ -2143,8 +2133,6 @@ char *spec;
     char *arg, *rest, substr[BUFSIZE], outbuf[BUFSIZE];
     Doctrine *doctrine;
 
-    if (side == NULL)
-      return;
     if (!empty_string(spec))
       rest = get_next_arg(spec, substr, &arg);
     else
@@ -2200,9 +2188,7 @@ int report_combat_special(Unit *unit1, Unit *unit2, char *str);
 int type_matches_symbol(Obj *sym, int u);
 
 void
-report_combat(atker, other, str)
-Unit *atker, *other;
-char *str;
+report_combat(Unit *atker, Unit *other, char *str)
 {
     int rslt;
 
@@ -2244,16 +2230,14 @@ char *str;
 }
 
 static void
-notify_combat(unit1, unit2, str)
-Unit *unit1, *unit2;
-char *str;
+notify_combat(Unit *unit1, Unit *unit2, char *str)
 {
     char buf1[BUFSIZE], buf2[BUFSIZE];
     Side *side3;
 
     for_all_sides(side3) {
 	if (active_display(side3)
-	    && (all_see_all
+	    && (side3->see_all
 		|| (unit1 != NULL && side3 == unit1->side)
 		|| (unit2 != NULL && side3 == unit2->side))) {
 	    strcpy(buf1, unit_handle(side3, unit1));
@@ -2269,6 +2253,7 @@ report_combat_special(Unit *unit1, Unit *unit2, char *str)
     int found = FALSE;
     char abuf[BUFSIZE];
     Obj *rest, *head, *pat, *msgdesc;
+    Side *side3;
 
     for_all_list(g_action_notices(), rest) {
 	head = car(rest);
@@ -2295,14 +2280,14 @@ report_combat_special(Unit *unit1, Unit *unit2, char *str)
 	if (stringp(msgdesc)) {
 	    strcpy(abuf, c_string(msgdesc));
 	} else {
-	    Side *side3;
-
+	    /* Notify all sides that could have seen the combat. */
 	    for_all_sides(side3) {
 		if (active_display(side3)
-		    && (all_see_all
+		    && (side3->see_all
 			|| (unit1 != NULL && side3 == unit1->side)
 			|| (unit2 != NULL && side3 == unit2->side))) {
-		    combat_desc_from_list(side3, msgdesc, unit1, unit2, str, abuf);
+		    combat_desc_from_list(side3, msgdesc, unit1, unit2, str,
+					  abuf);
 		    notify(side3, abuf);
 		}
 	    }
@@ -2427,60 +2412,6 @@ short *rslts;
     }
 }
 
-/* Compose a one-line comment on the game. */
-
-char *
-exit_commentary(side)
-Side *side;
-{
-    int numingame = 0, numwon = 0, numlost = 0;
-    Side *side2, *lastside, *winner, *loser;
-
-    for_all_sides(side2) {
-	if (side2->ingame) {
-	    ++numingame;
-	    lastside = side2;
-	}
-	if (side_won(side2)) {
-	    ++numwon;
-	    winner = side2;
-	}
-	if (side_lost(side2)) {
-	    ++numlost;
-	    loser = side2;
-	}
-    }
-    if (numingame > 0) {
-    	if (0 /* could have been resolved, need to check scorekeepers */) {
-	    sprintf(spbuf, "The outcome remains undecided");
-#ifdef RUDE
-	    if (numsides > 1) {
-		strcat(spbuf, ", but you're probably the loser!");
-	    } else {
-		strcat(spbuf, "...");
-	    }
-#else
-	    strcat(spbuf, "...");
-#endif /* RUDE */
-	} else {
-	    sprintf(spbuf, "Game is over.");
-    	}
-    } else if (numwon == numsides) {
-	sprintf(spbuf, "Everybody won!");
-    } else if (numlost == numsides) {
-	sprintf(spbuf, "Everybody lost!");
-    } else if (numwon == 1) {
-	sprintf(spbuf, "%s won!",
-		(side == winner ? "You" : side_desig(winner)));
-    } else if (numlost == 1) {
-	sprintf(spbuf, "%s lost!",
-		(side == loser ? "You" : side_desig(loser)));
-    } else {
-	sprintf(spbuf, "Some won and some lost.");
-    }
-    return spbuf;
-}
-
 void
 notify_all_of_resignation(side, side2)
 Side *side, *side2;
