@@ -220,6 +220,12 @@ execute_plan(Unit *unit)
     if (plan->asleep || plan->reserve) {
       return 0;
     }
+
+    if (plan->type == PLAN_PASSIVE && plan->execs_this_turn > 10) {
+		    DMprintf(" not found\n");
+	
+    }
+
     if (plan->execs_this_turn > 1000 && g_units_may_go_into_reserve()) {
 	DMprintf("%s executed plan 1000 times this turn, going into reserve\n",
 		 unit_desig(unit));
@@ -309,12 +315,9 @@ Unit *unit;
 int addtask;
 {
     Unit *transport;
-    Side *side;
+    Side *side = unit->side;
     StandingOrder *sorder;
 
-    side = unit->side;
-    if (side == NULL)
-      return FALSE;
     for (sorder = side->orders; sorder != NULL; sorder = sorder->next) {
 	if (sorder->types[unit->type] && unit->plan) {
 	    switch (sorder->condtype) {
@@ -404,8 +407,7 @@ plan_passive(Unit *unit)
     	force_replan(unit->side, unit, FALSE);
     	return;
     }
-
-    /* Special-case human cities in the intro game to automatically
+    /* Special-case human cities/towns in the intro game to automatically
        start producing infantry initially. */
     /* (would be more efficient to put in a once-per-turn location,
        should look for one) */
@@ -415,7 +417,8 @@ plan_passive(Unit *unit)
 	     && strcmp(mainmodule->name, INTRO_GAME) == 0)
 	    || (mainmodule->origmodulename != NULL
 		&& strcmp(mainmodule->origmodulename, INTRO_GAME) == 0))
-	&& strcmp(u_type_name(unit->type), "city") == 0) {
+	&& ((strcmp(u_type_name(unit->type), "city") == 0)
+	    || (strcmp(u_type_name(unit->type), "town") == 0))) {
 	push_build_task(unit, 0, 99);
     }
     if (plan->supply_is_low && plan->supply_alarm) {
@@ -552,7 +555,7 @@ Unit *unit;
 		} else if (go_after_victim(unit, range)) {
 		    /* Found a victim to go after, fall through. */
 		} else if (probability(20) && self_build_base_for_self(unit)) {
-		} else if (!all_see_all) {
+		} else if (!g_see_all()) {
 		    DMprintf("%s will explore instead\n", unit_desig(unit));
 		    plan_exploration(unit); /* or patrol */
 		    /* Running under exploration rules now. */
@@ -571,7 +574,7 @@ Unit *unit;
 	if (do_for_occupants(unit)) {
 	} else if (go_after_victim(unit, range)) {
 	    /* No special goal, but found something to fight with. */
-	} else if (!all_see_all) {
+	} else if (!g_see_all()) {
 	    DMprintf("%s will explore instead\n", unit_desig(unit));
 	    plan_exploration(unit); /* or patrol */
 	    /* Running under exploration rules now. */
@@ -824,7 +827,7 @@ Unit *unit;
 		} else if (go_after_victim(unit, range)) {
 		    /* Found a victim to go after, fall through. */
 		} else if (probability(20) && self_build_base_for_self(unit)) {
-		} else if (!all_see_all) {
+		} else if (!g_see_all()) {
 		    DMprintf("%s will explore instead\n", unit_desig(unit));
 		    plan_exploration(unit); /* or patrol */
 		    /* Running under exploration rules now. */
@@ -1113,8 +1116,7 @@ good_cell_to_colonize(int u, Unit *unit)
 }
 
 static void
-plan_exploration(unit)
-Unit *unit;
+plan_exploration(Unit *unit)
 {
     Unit *unit2;
     Plan *plan = unit->plan;
@@ -1122,7 +1124,7 @@ Unit *unit;
     int x, y, w, h, range, x1, y1;
 
     /* If the world has no secrets, exploration is sort of pointless. */
-    if (all_see_all && g_units_may_go_into_reserve()) {
+    if (g_see_all() && g_units_may_go_into_reserve()) {
     	plan->reserve = TRUE;
     	return;
     }
@@ -2625,12 +2627,11 @@ Unit *unit;
    other occupants. */
 
 int
-occupant_can_capture_neighbor(unit)
-Unit *unit;
+occupant_can_capture_neighbor(Unit *unit)
 {
     Unit *occ = unit->occupant;
 
-    if (occ != NULL && occ->act && occ->act->acp > 0 && occ->side == unit->side) {
+    if (occ != NULL && has_acp_left(occ) && occ->side == unit->side) {
 	if (can_capture_neighbor(occ)) {
 	    return TRUE;
 	}
@@ -2857,7 +2858,7 @@ Side *side;
 {
     int dir, x1, y1, t;
 
-    if (!inside_area(x, y) || side == NULL)
+    if (!inside_area(x, y))
       return FALSE;
     for_all_directions(dir) {
 	if (interior_point_in_dir(x, y, dir, &x1, &y1)) {
@@ -2874,13 +2875,11 @@ Side *side;
 /* Go to the nearest cell that we can see how to get to. */
 
 int
-explore_reachable_cell(unit, range)
-Unit *unit;
-int range;
+explore_reachable_cell(Unit *unit, int range)
 {
     int x, y;
 
-    if (all_see_all || g_terrain_seen())
+    if (g_see_all() || g_terrain_seen())
       return FALSE;
     tmpunit = unit;
     tmpside = unit->side;
