@@ -13,12 +13,14 @@ any later version.  See the file COPYING.  */
 #include "kpublic.h"
 #include "ai.h"
 
-/* This is for storing basic stuff about the most recently executed action. */
+/* This is for storing basic stuff about the most recently executed
+   action. */
+
 typedef struct a_action_record {
-	Unit *actor;			/* Pointer to the actor if it still exists. */
-	short x, y, z;			/* Actor's location at the time of action. */
-	ActionType type;			/* Type of action. */
-	HistEventType result;		/* Its result. */		
+    Unit *actor;		/* Pointer to the actor if it still exists. */
+    short x, y, z;		/* Actor's location at the time of action. */
+    ActionType type;		/* Type of action. */
+    HistEventType result;	/* Its result. */		
 } ActionRecord;
 
 static ActionRecord *latest_action = NULL;
@@ -127,6 +129,8 @@ static int nothing_count;
 
 int need_post_event_scores;
 
+int num_local_ais = -1;
+
 /* Flags that other code uses to signal the AI code that it ought
    to consider running something. */
 
@@ -145,7 +149,7 @@ int need_ai_finish_movement;
 int debugging_state_sync;
 
 void
-init_run()
+init_run(void)
 {
     int u;
     Unit *unit;
@@ -185,8 +189,7 @@ init_run()
    function's callers will know that something was done. */
 
 int
-run_game(maxactions)
-int maxactions;
+run_game(int maxactions)
 {
     int numacted, numother, runtime, numdone, bump;
     long saved_randstate;
@@ -368,7 +371,7 @@ rungamereturn:
    work before the game has started, but game time doesn't move. */
 
 void
-test_for_game_start()
+test_for_game_start(void)
 {
     int anydisplays = FALSE;
     Side *side;
@@ -405,7 +408,7 @@ test_for_game_start()
 /* This routine looks to see if the game is completely over. */
 
 void
-test_for_game_end()
+test_for_game_end(void)
 {
     Side *side;
 
@@ -429,7 +432,7 @@ test_for_game_end()
 /* This is true when all participating sides have finished their turn. */
 
 int
-all_sides_finished()
+all_sides_finished(void)
 {
     Side *side;
 
@@ -445,7 +448,7 @@ all_sides_finished()
 /* This is true when AIs should move more quickly. */
 
 int
-all_human_only_sides_finished()
+all_human_only_sides_finished(void)
 {
     Side *side;
 
@@ -464,7 +467,7 @@ all_human_only_sides_finished()
    going into run_game.  Will call back to interface if necessary. */
 
 void
-check_realtime()
+check_realtime(void)
 {
     Side *side;
 
@@ -484,7 +487,7 @@ check_realtime()
 }
 
 int
-exceeded_rt_for_game()
+exceeded_rt_for_game(void)
 {
     time_t now;
 
@@ -497,7 +500,7 @@ exceeded_rt_for_game()
 }
 
 int
-exceeded_rt_per_turn()
+exceeded_rt_per_turn(void)
 {
     time_t now;
 
@@ -510,8 +513,7 @@ exceeded_rt_per_turn()
 /* This returns true if the given side is still wanting to do stuff. */
 
 int
-units_still_acting(side)
-Side *side;
+units_still_acting(Side *side)
 {
     int curactor;
     Unit *unit;
@@ -532,17 +534,20 @@ Side *side;
     return FALSE;
 }
 
+/* Handle movement priorities and various flags. */
+
 static void
-init_movement()
+init_movement(void)
 {
     int i;
     Side *side;
 
     i = 1;
     curpriority = 9999;
-    /* In the absence of any idea about how to handle actions by
-       independent units, force their turn to be finished
-       immediately. */
+    /* If the indepside has no AI and cannot build or research, it's done. */
+    if (g_indepside_can_research() == FALSE
+    	&& g_indepside_can_build() == FALSE 
+         && g_indepside_has_ai() == FALSE)	
     indepside->finishedturn = TRUE;
     for_all_sides(side) {
 	if (side->ingame) {
@@ -577,8 +582,11 @@ init_movement()
     }
 }
 
+/* Create (if necessary) and fill in the action vectors, which are the
+   arrays of units that will be moving during the turn. */
+
 static void
-compose_actionvectors()
+compose_actionvectors(void)
 {
     int priority;
     Unit *unit;
@@ -592,7 +600,8 @@ compose_actionvectors()
 	    if (unit->act && unit->act->initacp > 0) {
 		priority = unit_priority(unit);
 		if (priority == cur_unit_priority) {
-		    side->actionvector = add_unit_to_vector(side->actionvector, unit, 0);
+		    side->actionvector =
+		      add_unit_to_vector(side->actionvector, unit, 0);
 		    /* Clear any delay flags. */
 		    if (unit->plan)
 		      unit->plan->delayed = FALSE;
@@ -603,7 +612,8 @@ compose_actionvectors()
 	    }
 	}
 	Dprintf("Action vector for %s has %d units, at priority %d\n",
-		side_desig(side), side->actionvector->numunits, cur_unit_priority);
+		side_desig(side), side->actionvector->numunits,
+		cur_unit_priority);
     }
     /* Inform sides with displays of how many units are ready to act. */
     for_all_sides(side) {
@@ -616,16 +626,14 @@ compose_actionvectors()
 }
 
 int
-unit_priority(unit)
-Unit *unit;
+unit_priority(Unit *unit)
 {
     int pri;
-    Side *side;
+    Side *side = unit->side;
 
     pri = unit_extra_priority(unit);
     if (pri >= 0)
       return pri;
-    side = (unit->side ? unit->side : indepside);
     if (side->action_priorities != NULL) {
 	pri = side->action_priorities[unit->type];
 	if (pri >= 0)
@@ -638,8 +646,7 @@ Unit *unit;
    the total number of actions performed. */
 
 static int
-move_some_units(lim)
-int lim;
+move_some_units(int lim)
 {
     int num = 0, sidenum;
     Side *side;
@@ -658,9 +665,7 @@ int lim;
 /* Do some number of actions. */
 
 static int
-side_move_some_units(side, lim)
-Side *side;
-int lim;
+side_move_some_units(Side *side, int lim)
 {
     int num, foundanytomove, curactor0, curactor, numdelayed;
     Unit *unit;
@@ -696,15 +701,14 @@ int lim;
 	/* If the unit is keeping formation, then give it a chance to
 	   adjust its position, even if it's not "still acting". */
 	if (is_active(unit)
-	    && (unit->side ?
-		(unit->side->ingame && !unit->side->finishedturn) : TRUE)
-	    && (unit->act && unit->act->acp > 0)
+	    && unit->side->ingame 
+	    && !unit->side->finishedturn
+	    && has_acp_left(unit)
 	    && (unit->plan && unit->plan->formation)) {
 	    num += move_one_unit_multiple(unit, lim - num);
 	    foundanytomove = TRUE;
 	}
-	if (unit->side
-	    && unit->side->orders
+	if (unit->side->orders
 	    && unit->plan
 	    && unit->plan->tasks == NULL
 	    && execute_standing_order(unit, FALSE)) {
@@ -763,15 +767,13 @@ int lim;
 }
 
 static int
-unit_still_acting(unit)
-Unit *unit;
+unit_still_acting(Unit *unit)
 {
     return (is_active(unit)
 	    && (unit->side
 		&& unit->side->ingame
 		&& !unit->side->finishedturn)
-	    && (unit->act
-		&& unit->act->acp > 0)
+	    && has_acp_left(unit)
 	    && ((unit->plan
 		&& !unit->plan->asleep
 		&& !unit->plan->reserve)
@@ -786,8 +788,7 @@ Unit *unit;
 	    && (unit->side
 		&& unit->side->ingame
 		&& !unit->side->finishedturn)
-	    && (unit->act
-		&& unit->act->acp > 0)
+	    && has_acp_left(unit)
 	    && has_pending_action(unit));
 }
 
@@ -809,8 +810,7 @@ int lim;
       return 0;
     acp1 = unit->act->acp;
     while (is_active(unit)
-	   && (unit->act
-	       && unit->act->acp > u_acp_min(unit->type))
+	   && has_acp_left(unit)
 	   && ((unit->plan
 		&& !unit->plan->asleep
 		&& !unit->plan->reserve
@@ -993,7 +993,22 @@ int when, maxplanning;
     Unit *unit;
     char *activity = "run_local_ai";
 
+    if (num_local_ais < 0) {
+	num_local_ais = 0;
+	for_all_sides(side) {
+	    if (side_has_ai(side))
+	      ++num_local_ais;
+	}
+    }
+    /* If no AIs to run, get out quickly. */
+    if (num_local_ais == 0 && !need_ai_for_new_side)
+      return 0;
+
     record_activity_start(activity, when);
+
+#if 0	/* This caused buzzing by preventing passive units under AI 
+	control from getting necessary replanning. */
+     
     /* Only do this routine at a certain rate. */
     if (current_play_rate > 0
 	&& !n_ms_elapsed(60000 / current_play_rate)
@@ -1001,6 +1016,9 @@ int when, maxplanning;
 	record_activity_end(activity, 1);
 	return 0;
     }
+    
+#endif
+    
     if (need_ai_for_new_side) {
 	for_all_sides(side) {
 	    if (side_wants_ai(side) && !side_has_ai(side)) {
@@ -1236,8 +1254,11 @@ end_the_game()
     record_into_scorefile();
     /* Done with internal state change, now echo onto displays. */
     for_all_sides(side) {
-	if (!all_see_all)
-	  side->may_set_see_all = TRUE;
+	/* Enable the display of everything in the world. */
+	if (!side->see_all)
+	  side->may_set_show_all = TRUE;
+	/* ...by default display it all. */
+	side->show_all = TRUE;
     	if (side_has_display(side)) {
     	    update_turn_display(side, TRUE);
     	    /* (should update side's view of all sides?) */
@@ -1253,6 +1274,8 @@ end_the_game()
 /* 	Advanced unit and advance code for Xconq.
      	Copyright (C) 1998 Hans Ronne. */
 
+extern void run_people(void);
+
 extern void run_advanced_units(void);
 extern void free_used_cells(Unit *unit);
 extern void unit_advance_dialog(Unit *unit);
@@ -1290,6 +1313,13 @@ int a;
     return TRUE;
 }
 
+/* Called from run_turn_start. */
+
+void
+run_people()
+{
+}
+
 /* Main city emulating routine. Called by run_turn_start in run2.c. */
 
 void
@@ -1316,12 +1346,10 @@ run_advanced_units()
 
 	/* Make sure the city's side can see everything in visible cells within its reach. */
 	for_all_cells_within_reach(unit, x, y) {
-		Side *sidex = (unit->side ? unit->side : indepside);
-
 	    if (!inside_area(x, y))
 		continue;
-	    if (terrain_visible(sidex, x, y))
-		see_exact(sidex, x, y);
+	    if (terrain_visible(unit->side, x, y))
+		see_exact(unit->side, x, y);
 	}
 	/* Break here if no material types exist. */
 	if (!nummtypes)
@@ -1380,11 +1408,10 @@ run_advanced_units()
 	    /* Finally add production to unit supply. */
 	    unit->supply[m] += unit->production[m];
 	    /* Borrow material from treasury if it exists. */
-	    if (m_treasury(m)) {
-		Side *sidex = (unit->side ? unit->side : indepside);
-
-		unit->supply[m] += sidex->treasury[m];
-		sidex->treasury[m] = 0; 			
+	    if (side_has_treasury(unit->side, m)
+	        && um_takes_from_treasury(unit->type, m)) {
+		unit->supply[m] += unit->side->treasury[m];
+		unit->side->treasury[m] = 0; 			
 	    }
 	}
 	/* Growth or starvation. */
@@ -1409,10 +1436,9 @@ run_advanced_units()
 	run_research(unit);
 	/* Return any borrowed material to treasury. */
 	for_all_material_types(m) {
-	    if (m_treasury(m)) {
-		Side *sidex = (unit->side ? unit->side : indepside);
-    
-		sidex->treasury[m] += unit->supply[m];
+	    if (side_has_treasury(unit->side, m)
+	        && um_gives_to_treasury(unit->type, m)) {
+		unit->side->treasury[m] += unit->supply[m];
 		unit->supply[m] = 0; 			
 	    }
 	}
@@ -1451,11 +1477,9 @@ run_population(Unit *unit)
 	    /* Kill the unit, but first return borrowed material to
                treasury. */
 	    for_all_material_types(m) {
-		if (m_treasury(m)) {
-		    /* Copy of Stan's bug fix in run_advanced_units. */
-  		    Side *sidex = (unit->side ? unit->side : indepside);
-    
-		    sidex->treasury[m] += unit->supply[m];
+	    	if (side_has_treasury(unit->side, m)
+	    	    && um_gives_to_treasury(unit->type, m)) {
+		    unit->side->treasury[m] += unit->supply[m];
 		    unit->supply[m] = 0; 			
 		}
 	    }
@@ -1473,7 +1497,7 @@ run_population(Unit *unit)
 	return;
     /* Then check if we have the required advances for the next size. */
     for_all_advance_types(a) {
-	if ((unit->side == NULL || unit->side->advance[a] != DONE) 
+	if (unit->side->advance[a] != DONE 
 	    && ua_size_limit_without_adv(u, a) <= unit->size) {
 	    notify(unit->side, "Your %s %s needs %s advance to grow in size.", 
 		   			u_type_name(u), unit->name, a_type_name(a));			
@@ -1516,7 +1540,7 @@ run_construction(Unit *unit)
     int builds = unit->size;
 
     /* Skip if this is an indep which cannot build. */
-    if (indep(unit) &! g_indep_may_build())
+    if (indep(unit) &! g_indepside_can_build())
       return;
     /* Make sure we have a real plan. */
     if (unit->plan == NULL
@@ -1653,8 +1677,8 @@ run_research(Unit *unit)
 {
     int m, a;
 
-    /* Only units controlled by a side do research. */
-    if (!unit->side)
+    /* Check if independent units are allowed to do research. */
+    if (indep(unit) &! g_indepside_can_research())
       return; 
     /* First test if we are already done, and select new research in
        that case. */
@@ -1800,8 +1824,6 @@ allocate_used_cells(Unit *unit)
 	int tmpy = unit->y;
 
 	for_all_cells_within_reach(unit, x, y) {
-		Side *sidex = (unit->side ? unit->side : indepside);
-
 	    /* Skip if not inside area */
 	    if (!inside_area(x, y))
 	      continue;
@@ -1809,13 +1831,13 @@ allocate_used_cells(Unit *unit)
 	    if (user_at(x, y) != NOUSER)
 	      continue;
 	    /* Skip if cell is invisible to unit */
-	    if (!terrain_visible(sidex, x, y))
+	    if (!terrain_visible(unit->side, x, y))
 	      continue;
 	    /* Skip if untrusted side has a unit in the cell */
 	    if (unit_at(x, y) != NULL) {
 		int enemy = FALSE;
 		for_all_stack(x, y, unit2) {
-		    if (!trusted_side(sidex, unit2->side)) {
+		    if (!trusted_side(unit->side, unit2->side)) {
 			enemy = TRUE;
 			break;
 		    }
@@ -1948,8 +1970,8 @@ auto_pick_new_build_task(Unit *unit)
 	    && distance(unit->x, unit->y, unit2->x, unit2->y)
 	    >= u_ai_tactical_range(unit->type)
 	    && enemy_side(unit->side, unit2->side)
-	    /* Only count citites that we can actually see. */
-	    && unit_actually_visible(unit->side, unit2)) {
+	    /* Only count cities that we can actually see. */
+	    && side_sees_image(unit->side, unit2)) {
 	    enemy_city_near = TRUE;
 	    break;
 	}
@@ -2070,11 +2092,9 @@ auto_pick_new_plan(Unit *unit)
     /* Check out the tactical neighbourhood. */
     for_all_cells_within_range(unit->x, unit->y, 
 				 u_ai_tactical_range(unit->type), x, y) {
-		Side *sidex = (unit->side ? unit->side : indepside);
-
 		if (!inside_area(x, y))
 		  continue;
-		if (!terrain_visible(sidex, x, y))
+		if (!terrain_visible(unit->side, x, y))
 		  invisible_cells +=1;
 		unit2 = NULL;
 		/* Important to count also occupants here. */
@@ -2083,18 +2103,18 @@ auto_pick_new_plan(Unit *unit)
 		    if (!is_active(unit2))
 		      continue;
 		    /* Only count units that we can see. */
-		    if (!unit_actually_visible(sidex, unit2))
+		    if (!side_sees_image(unit->side, unit2))
 		      continue;
 		    u2 = unit2->type;
 		    /* First count own units. */
-		    if (sidex == unit2->side) {
+		    if (unit->side == unit2->side) {
 			if (u_advanced(u2))
 			  my_advanced += 1;
 			else if (u_colonizer_worth(u2))
 			  my_colonizers += 1;
 			my_total += 1;
 			/* Then count hostile units. */
-		    } else if (enemy_side(sidex, unit2->side)){
+		    } else if (enemy_side(unit->side, unit2->side)){
 			if (u_advanced(u2))
 			  enemy_advanced += 1;
 			else if (u_colonizer_worth(u2))
