@@ -17,6 +17,7 @@ extern int stop_apply;
 static void vary_winds(void);
 
 /* Advanced unit support. */
+extern void run_people(void);
 extern void run_advanced_units(void);
 extern void run_turn_start(void);
 extern void run_restored_turn_start(void);
@@ -30,6 +31,7 @@ static void cache_init_tech_levels(void);
 static void run_tooling_attrition(void);
 static void run_cp_attrition(void);
 static void reset_all_reserves(void);
+static void save_checkpoint(int curturn);
 static void compute_moves(void);
 static void finish_movement(void);
 static void test_agreements(void);
@@ -93,6 +95,8 @@ char *curdatestr;
 
 int checkpoint_interval;
 
+static char *last_checkpoint_filename;
+
 /* The number of new sides that have been requested to be added. */
 
 int new_sides_requested;
@@ -229,11 +233,13 @@ run_turn_start(void)
     /* Do a variety of each-turn backdrop activities. */
     run_sun();
     run_environment();
-    /* Optionally turn off standard economy in advanced game to avoid complications. */
-    if (g_disable_standard_economy() != TRUE) {
+    /* Optionally run population, economy and supply code. */
+    if (g_people())
+	run_people();
+    if (g_economy())
 	run_economy();
+    if (g_supply())
 	run_supply();
-    }
     /* Advanced unit support. */
     run_advanced_units();
     run_hp_recovery();
@@ -256,9 +262,7 @@ run_turn_start(void)
     cache_init_tech_levels();
     reset_all_reserves();
     gamestatesafe = FALSE;
-    if ((checkpoint_interval > 0) && (curturn % checkpoint_interval == 0)) {
-	write_entire_game_state(checkpoint_filename());
-    }
+    save_checkpoint(curturn);
     time(&turncalcend);
     Dprintf("%d seconds to calc at turn start\n",
 	    idifftime(turncalcend, turncalcstart));
@@ -411,6 +415,8 @@ add_new_sides_to_game(void)
 	    /* Recalculate all view info for all sides; simpler than
 	       trying to figure out what's really changed. */
 	    reset_coverage();
+	    /* (should not use this, it will lose the results of
+	       spotting hard-to-see units) */
 	    reset_all_views();
 	    compute_all_feature_centroids();
 	    /* Redraw everything that's displayed. */
@@ -612,6 +618,30 @@ reset_all_reserves(void)
     }
 }
 
+/* Record a checkpoint, which is just a saved game, saved
+   automatically every n turns.  The code is slightly complicated
+   by our desire to ensure successful saving before removing
+   the previous checkpoint.  Note also that interfaces are not
+   required to incorporate the turn number into the result of
+   checkpoint_filename. */
+
+static void
+save_checkpoint(int curturn)
+{
+    char *checkfname;
+
+    if ((checkpoint_interval > 0) && (curturn % checkpoint_interval == 0)) {
+	checkfname = checkpoint_filename(curturn);
+	write_entire_game_state(checkfname);
+	if (last_checkpoint_filename == NULL)
+	  last_checkpoint_filename = xmalloc(BUFSIZE);
+	if (strcmp(checkfname, last_checkpoint_filename) != 0)
+	  remove_file(last_checkpoint_filename);
+	strcpy(last_checkpoint_filename, checkfname);
+	Dprintf("Saved checkpoint %s\n", checkfname);
+    }
+}
+
 /* Compute moves and actions for all the units at once, put everybody that
    can do anything into a list. */
 
@@ -1246,7 +1276,7 @@ int x, y;
 
     /* (should build layer mask and call cell updating once) */
     for_all_sides(side) {
-	if (all_see_all) {
+	if (side->see_all) {
 	    update_cell_display(side, x, y,
 				UPDATE_TEMP | UPDATE_CLOUDS | UPDATE_WINDS);
 	} else if (g_see_weather_always()
@@ -1324,7 +1354,7 @@ run_spies()
 	    }
 	}
 	/* But spying is pointless if everybody can see everything anyway. */
-	if (all_see_all)
+	if (g_see_all())
 	  any_spying = FALSE;
 	Dprintf("Any spying: %d\n", any_spying);
     }
@@ -1485,8 +1515,7 @@ int force;
     if (force || xrandom(10000) < chance) {
 	newside = oldside;
 	if (oldside != unit->origside
-	    && (unit->origside == NULL
-		|| unit->origside == indepside
+	    && (unit->origside == indepside
 		|| unit->origside->ingame)
 	    && !trusted_side(oldside, unit->origside)
 	    && unit_allowed_on_side(unit, unit->origside)
@@ -1505,7 +1534,7 @@ int force;
 		    && unit_allowed_on_side(unit, side2)
 		    /* Don't go over to a side that doesn't even know
                        we're there. */
-		    && (all_see_all
+		    && (side2->see_all
 			|| side2 == indepside
 			|| (unit_view(side2, ux, uy) != EMPTY
 			    && vtype(unit_view(side2, ux, uy)) == unit->type))
@@ -1541,7 +1570,7 @@ int force;
 		    && unit_allowed_on_side(unit, side2)
 		    /* Don't go over to a side that doesn't even know
                        we're there. */
-		    && (all_see_all
+		    && (side2->see_all
 			|| side2 == indepside
 			|| (unit_view(side2, ux, uy) != EMPTY
 			    && vtype(unit_view(side2, ux, uy)) == unit->type))
@@ -1574,7 +1603,7 @@ int force;
 	  return;
 	/* Tell the players what happened. */
 	/* (should notify other players, if they're observing the unit?) */
-	if (newside == NULL) {
+	if (newside == indepside) {
 	    notify(oldside, "%s revolts, becomes independent!",
 		   unit_handle(oldside, unit));
 	} else {
@@ -1684,7 +1713,7 @@ Unit *unit, *unit2;
 {
     int uview;
 
-    if (all_see_all) {
+    if (g_see_all()) {
 	return TRUE;
     } else if (unit->side != NULL) {
     	uview = unit_view(unit->side, unit2->x, unit2->y);
@@ -2964,6 +2993,8 @@ finish_movement(void)
 	    lostacp = 0;
 	    for_all_side_units(side, unit) {
 		if (is_active(unit) && unit->act && unit->act->acp > 0) {
+		    /* Note that we don't count acp-min here, would be
+		       way too confusing. */
 		    lostacp += unit->act->acp;
 		}
 	    }
