@@ -15,17 +15,17 @@ any later version.  See the file COPYING.  */
    "the Star of Satyria enters Noblum".  The other is the accumulation
    of a numeric score.  A scorekeeper may include both, so it can (for
    instance) end the game the instant that a player's score reaches
-   100, or 100 more than another player, or whatever.  */
+   100, or 100 more than another player, or whatever.
+
+   The indepside should not participate in scoring, so the iterations
+   in this file generally iterate only over the "real" sides. */
 
 #include "conq.h"
-extern char *escaped_symbol(char *str);
-extern char *escaped_string(char *str);
 #include "kernel.h"
 
-char *basic_player_name(Player *player);
-int read_scorefile(void);
-int interp_score_record(Obj *form);
-char *get_scores(Side *side);
+static int read_scorefile(void);
+static int interp_score_record(Obj *form);
+static char *basic_player_name(Player *player);
 
 typedef struct a_score_record {
     char *gamename;
@@ -94,6 +94,10 @@ int any_turn_specific_scores;
 
 static int num_sides_originally;
 
+static int only_checking;
+
+static int we_have_a_winner;
+
 ScoreRecord *records;
 
 /* Clear out any possible scorekeepers. */
@@ -222,7 +226,7 @@ init_scores(void)
        we don't force the game to end because (for whatever reason)
        only one side was active from the beginning. */
     num_sides_originally = 0;
-    for_all_sides(side) {
+    for_all_real_sides(side) {
 	if (side->ingame)
 	  ++num_sides_originally;
     }
@@ -240,7 +244,7 @@ check_pre_turn_scores(void)
     if (any_pre_turn_scores) {
 	for_all_scorekeepers(sk) {
 	    if (match_keyword(sk->when, K_BEFORE_TURN)) {
-		for_all_sides(side) {
+		for_all_real_sides(side) {
 		    if (scorekeeper_applicable(side, sk)) {
 			run_scorekeeper(side, sk); 
 		    } else {
@@ -274,7 +278,7 @@ check_post_turn_scores(void)
 			   && match_keyword(sk->body, K_LAST_ALLIANCE_WINS)) {
 		    eval_sk_last_alliance_wins(sk);
 	    	} else {
-		    for_all_sides(side) {
+		    for_all_real_sides(side) {
 			if (scorekeeper_applicable(side, sk)) {
 			    run_scorekeeper(side, sk); 
 			} else {
@@ -299,7 +303,7 @@ check_post_action_scores(void)
 	for_all_scorekeepers(sk) {
 	    if (match_keyword(sk->when, K_AFTER_ACTION)) {
 		if (sk->trigger == lispnil || sk->triggered) {
-		    for_all_sides(side) {
+		    for_all_real_sides(side) {
 			if (scorekeeper_applicable(side, sk)) {
 			    run_scorekeeper(side, sk);
 		        } else {
@@ -324,7 +328,7 @@ check_post_event_scores(void)
 	for_all_scorekeepers(sk) {
 	    if (match_keyword(sk->when, K_AFTER_EVENT)) {
 		if (sk->trigger == lispnil || sk->triggered) {
-		    for_all_sides(side) {
+		    for_all_real_sides(side) {
 			if (scorekeeper_applicable(side, sk)) {
 			    run_scorekeeper(side, sk); 
 		        } else {
@@ -391,15 +395,16 @@ eval_sk_form(Side *side, Scorekeeper *sk, Obj *form)
 	  }
 	  break;
 	case K_WIN:
-	  if (side->ingame)
+	  if (side->ingame && !only_checking)
 	    side_wins(side, sk->id);
 	  break;
 	case K_LOSE:
-	  if (side->ingame)
+	  if (side->ingame && !only_checking)
 	    side_loses(side, NULL, sk->id);
 	  break;
 	case K_END:
-	  all_sides_draw();
+	  if (!only_checking)
+	    all_sides_draw();
 	  break;
 	case K_SET:
 	  if (sk->scorenum >= 0) {
@@ -583,20 +588,24 @@ eval_sk_last_side_wins(Scorekeeper *sk)
 
     /* This is only meaningful in games with at least two sides. */
     if (num_sides_originally >= 2) {
-	for_all_sides(side2) {
+	for_all_real_sides(side2) {
 	    if (side2->ingame) {
 		points = side_point_value(side2);
 		Dprintf("%s has %d points worth of units\n",
 			side_desig(side2), points);
 		if (points == 0) {
+		  if (!only_checking)
 		    side_loses(side2, NULL, sk->id);
-		} else {
+		/* Only count sides that have either ai or display. */
+		} else if (side2->ai || side_has_display(side2)) {
 		    ++numleft;
 		    winner = side2;
 		}
 	    }
 	}
 	if (numleft == 1) {
+	  we_have_a_winner = TRUE;
+	  if (!only_checking)
 	    side_wins(winner, sk->id);
 	}
     }
@@ -611,7 +620,7 @@ eval_sk_last_alliance_wins(Scorekeeper *sk)
 
     /* This is only meaningful in games with at least two sides. */
     if (num_sides_originally >= 2) {
-	for_all_sides(side2) {
+	for_all_real_sides(side2) {
 	    sidepoints[side2->id] = alliancepoints[side2->id] = 0;
 	    if (side2->ingame) {
 		sidepoints[side2->id] = side_point_value(side2);
@@ -620,9 +629,9 @@ eval_sk_last_alliance_wins(Scorekeeper *sk)
 	    }
 	}
 	/* Sum up to get points for each alliance. */
-	for_all_sides(side2) {
+	for_all_real_sides(side2) {
 	    if (side2->ingame) {
-		for_all_sides(side3) {
+		for_all_real_sides(side3) {
 		    if (side2 == side3 || trusted_side(side2, side3)) {
 			alliancepoints[side2->id] += sidepoints[side3->id];
 		    }
@@ -631,11 +640,13 @@ eval_sk_last_alliance_wins(Scorekeeper *sk)
 	}
 	/* Make all the sides belonging to point-less alliances lose now,
 	   and look for a non-losing side. */
-	for_all_sides(side2) {
+	for_all_real_sides(side2) {
 	    if (side2->ingame) {
 		if (alliancepoints[side2->id] == 0) {
-		    side_loses(side2, NULL, sk->id);
-		} else {
+		    if (!only_checking)
+		      side_loses(side2, NULL, sk->id);
+		/* Only count sides that have either ai or display. */
+		} else if (side2->ai || side_has_display(side2)) {
 		    ++numleft;
 		    winner = side2;
 		}
@@ -644,7 +655,7 @@ eval_sk_last_alliance_wins(Scorekeeper *sk)
 	if (numleft > 0) {
 	    /* See if the non-losers all belong to a single alliance. */
 	    alliancewins = TRUE;
-	    for_all_sides(side2) {
+	    for_all_real_sides(side2) {
 		if (side2->ingame && side2 != winner
 		    && !trusted_side(winner, side2)) {
 		    alliancewins = FALSE;
@@ -653,10 +664,12 @@ eval_sk_last_alliance_wins(Scorekeeper *sk)
 	    }
 	    /* If so, everybody in the alliance wins equally. */
 	    if (alliancewins) {
-		for_all_sides(side2) {
+		we_have_a_winner = TRUE;
+		for_all_real_sides(side2) {
 		    if (side2->ingame
 			&& (side2 == winner || trusted_side(winner, side2))) {
-			side_wins(side2, sk->id);
+			if (!only_checking)
+			  side_wins(side2, sk->id);
 		    }
 		}
 	    }
@@ -685,6 +698,10 @@ side_loses(Side *side, Side *side2, int why)
     int x, y, s, s2, ux, uy, changed;
     Unit *unit;
 
+    /* The independents cannot lose by definition even if they
+    are down to zero points. */
+    if (side == indepside)
+	return;
     /* These should not happen, but a stupid AI might try, so just
        and clear the mistaken side. */
     if (side == side2) {
@@ -733,7 +750,7 @@ side_loses(Side *side, Side *side2, int why)
 	    }
 	}
 	/* Reset view coverage everywhere. */
-	if (!all_see_all) {
+	if (!side->see_all) {
 	    for_all_cells(x, y) {
 		set_cover(side, x, y, 0);
 	    }
@@ -746,12 +763,12 @@ side_loses(Side *side, Side *side2, int why)
 	    if (unit->side == side && u_advanced(unit->type)) {
 		if (in_play(unit)) {
 		    ux = unit->x;  uy = unit->y;
-		    change_unit_side(unit, NULL, H_SIDE_LOST, NULL);
+		    change_unit_side(unit, indepside, H_SIDE_LOST, NULL);
 		    /* Everybody gets to see this change. */
 		    all_see_cell(ux, uy);
 		} else {
 		    /* Even out-of-play units need to have their side set. */
-		    set_unit_side(unit, NULL);
+		    set_unit_side(unit, indepside);
 		}
 	    }
 	}
@@ -763,6 +780,21 @@ side_loses(Side *side, Side *side2, int why)
     /* Record the event after the side is removed, so we don't get infinite
        recursion if there is an event-triggered scorekeeper. */
     record_event(H_SIDE_LOST, ALLSIDES, side_number(side), why);
+    /* As a special case, look at post-turn scorekeepers to see if
+       sides should end their turns early because the game is over. */
+    only_checking = TRUE;
+    check_post_turn_scores();
+    only_checking = FALSE;
+    if (we_have_a_winner) {
+	for_all_real_sides(side2) {
+	    if (side2->ingame) {
+		finish_turn(side2);
+	    }
+	}
+    }
+    /* When the remaining sides' turns are finished, the end-of-turn
+       processing will commence, and it includes the real run of
+       post-turn scorekeeper checking. */
 }
 
 /* Implement a draw.  Note that unlike winning or losing, the draw
@@ -775,7 +807,7 @@ all_sides_draw(void)
     Side *side;
 
     drew = NOSIDES;
-    for_all_sides(side) {
+    for_all_real_sides(side) {
     	if (side->ingame) {
 	    side->status = 0;
 	    remove_side_from_game(side);
@@ -784,16 +816,15 @@ all_sides_draw(void)
     }
     /* Now that all sides are out, safe to record events to that effect
        (no possibility of triggering post-even scorekeepers). */
-    for_all_sides(side) {
+    for_all_real_sides(side) {
     	if (side_in_set(side, drew)) {
 	    record_event(H_SIDE_WITHDREW, ALLSIDES, side_number(side));
 	}
     }
 }
 
-/* Record the outcome of the game into the scorefile. */
-
-char *
+/* (should move this to nlang.c?) */
+static char *
 basic_player_name(Player *player)
 {
     char *playername;
@@ -810,6 +841,8 @@ basic_player_name(Player *player)
     return playername;
 }
 
+/* Record the outcome of the game into the scorefile. */
+
 void
 record_into_scorefile(void)
 {
@@ -837,7 +870,11 @@ record_into_scorefile(void)
     if (!empty_string(g_scorefile_name()))
       filename = g_scorefile_name();
     fp = open_scorefile_for_writing(filename);
-    if (fp != NULL) {
+    if (fp == NULL) {
+	run_warning("%s cannot be opened for writing, will not record score",
+		    filename);
+	/* (should provide some sort of retry here) */
+    } else {
 	fprintf(fp, "(g %s",
 		/* (should record this for comparison when displaying
                    scores) */
@@ -867,11 +904,25 @@ record_into_scorefile(void)
 		    fprintf(fp, "2 %d", var->intvalue);
 		} else if (keyword_code(varname) == K_SEQUENTIAL) {
 		    fprintf(fp, "3 %d", var->intvalue);
+		} else if (keyword_code(varname) == K_PEOPLE) {
+		    fprintf(fp, "4 %d", var->intvalue);
+		} else if (keyword_code(varname) == K_ECONOMY) {
+		    fprintf(fp, "5 %d", var->intvalue);
+		} else if (keyword_code(varname) == K_SUPPLY) {
+		    fprintf(fp, "6 %d", var->intvalue);
+		} else if (keyword_code(varname) == K_INDEPSIDE_HAS_AI) {
+		    fprintf(fp, "7 %d", var->intvalue);
+		} else if (keyword_code(varname) == K_INDEPSIDE_CAN_BUILD) {
+		    fprintf(fp, "8 %d", var->intvalue);
+		} else if (keyword_code(varname) == K_INDEPSIDE_CAN_RESEARCH) {
+		    fprintf(fp, "9 %d", var->intvalue);
+		} else if (keyword_code(varname) == K_INDEPSIDE_HAS_TREASURY) {
+		    fprintf(fp, "10 %d", var->intvalue);
 		} else if (keyword_code(varname) == K_WORLD_SIZE) {
-		    fprintf(fp, "4 %d %d %d",
+		    fprintf(fp, "11 %d %d %d",
 			    area.width, area.height, world.circumference);
 		} else if (keyword_code(varname) == K_REAL_TIME) {
-		    fprintf(fp, "5 %d %d %d",
+		    fprintf(fp, "12 %d %d %d",
 			    g_rt_for_game(),
 			    g_rt_per_side(),
 			    g_rt_per_turn());
@@ -892,7 +943,7 @@ record_into_scorefile(void)
 	fprintf(fp, "\n");
 	/* Record all the participants and how they fared. */
 	fprintf(fp, " (s");
-	for_all_sides(side) {
+	for_all_real_sides(side) {
 	    /* Only record info about sides that actually participated. */
 	    if (side->everingame) {
 		fprintf(fp, " (");
@@ -931,7 +982,7 @@ record_into_scorefile(void)
     }
 }
 
-int
+static int
 read_scorefile(void)
 {
     int startlineno = 1, endlineno = 1;
@@ -946,6 +997,10 @@ read_scorefile(void)
       filename = g_scorefile_name();
     fp = open_scorefile_for_reading(filename);
     if (fp != NULL) {
+        /* Note that we clear all existing score records.  This is because
+	   the score file may be shared and thus getting multiple updates. */
+	/* (should free any existing records) */
+	records = NULL;
 	numrecs = 0;
 	/* Read everything in the file. */
 	while ((form = read_form(fp, &startlineno, &endlineno)) != lispeof) {
@@ -963,7 +1018,7 @@ read_scorefile(void)
     return FALSE;
 }
 
-int
+static int
 interp_score_record(Obj *form)
 {
     char *propname;
@@ -1008,12 +1063,16 @@ interp_score_record(Obj *form)
     return FALSE;
 }
 
+/* Collect scorefile contents and format them.  This routine starts from
+   a fresh set of records each time, and allocates a new formatting
+   buffer each time, so should be called sparingly. */
+
 char *
 get_scores(Side *side)
 {
     int wins, losses, draws, plays, allplays;
     char *buf, sdadvbuf[20], varbuf[BUFSIZE];
-    char *thisgame, *playername, *sdnamestr, *sdfatestr;
+    char *thisgame, *thisgametitle, *playername, *sdnamestr, *sdfatestr;
     Obj *sds, *sd, *sdname, *sdfate, *more, *more1;
     ScoreRecord *sr;
 
@@ -1026,7 +1085,11 @@ get_scores(Side *side)
     if (records == NULL)
       return "No scores available.\n";
     buf = xmalloc(5000);
-    sprintf(buf, "Scores for \"%s\":\n", thisgame);
+    thisgametitle = thisgame;
+    if (!empty_string(mainmodule->title))
+      thisgametitle = mainmodule->title;
+    sprintf(buf, "Scores for %s", thisgametitle);
+    strcat(buf, ":\n");
     playername = NULL;
     if (side != NULL) {
 	playername = basic_player_name(side->player);
@@ -1151,7 +1214,9 @@ score_variant_desc(ScoreRecord *sr, char *varbuf)
 
     varbuf[0] = '\0';
     if (sr->varsets != lispnil) {
-	variants = (mainmodule->origvariants ? mainmodule->origvariants : mainmodule->variants);
+	variants = (mainmodule->origvariants
+		    ? mainmodule->origvariants
+		    : mainmodule->variants);
 	for_all_list(sr->varsets, restvarset) {
 	    varset = car(restvarset);
 	    if (consp(varset)) {
@@ -1169,9 +1234,30 @@ score_variant_desc(ScoreRecord *sr, char *varbuf)
 			varsetname = intern_symbol(keyword_name(K_SEQUENTIAL));
 			break;
 		      case 4:
-			varsetname = intern_symbol(keyword_name(K_WORLD_SIZE));
+			varsetname = intern_symbol(keyword_name(K_PEOPLE));
 			break;
 		      case 5:
+			varsetname = intern_symbol(keyword_name(K_ECONOMY));
+			break;
+		      case 6:
+			varsetname = intern_symbol(keyword_name(K_SUPPLY));
+			break;
+		      case 7:
+			varsetname = intern_symbol(keyword_name(K_INDEPSIDE_HAS_AI));
+			break;
+		      case 8:
+			varsetname = intern_symbol(keyword_name(K_INDEPSIDE_CAN_BUILD));
+			break;
+		      case 9:
+			varsetname = intern_symbol(keyword_name(K_INDEPSIDE_CAN_RESEARCH));
+			break;
+		      case 10:
+			varsetname = intern_symbol(keyword_name(K_INDEPSIDE_HAS_TREASURY));
+			break;
+		      case 11:
+			varsetname = intern_symbol(keyword_name(K_WORLD_SIZE));
+			break;
+		      case 12:
 			varsetname = intern_symbol(keyword_name(K_REAL_TIME));
 			break;
 		      default:
@@ -1200,11 +1286,14 @@ score_variant_desc(ScoreRecord *sr, char *varbuf)
 		    hasdflt = TRUE;
 		}
 		val = 54321;
+		/* The numeric value is the second element in the variant
+		   setting. */
 		if (numberp(cadr(varset)) && cddr(varset) == lispnil)
 		  val = c_number(cadr(varset));
+		/* Handle variants with several values. */
 		if (keyword_code(c_string(varsetname)) == K_WORLD_SIZE) {
 		    if (!hasdflt || !equal(rslt, cdr(varset)))
-		      tprintf(varbuf, " %s=%dx%dw%d", c_string(varsetname),
+		      tprintf(varbuf, " %s=%dx%dW%d", c_string(varsetname),
 			      c_number(cadr(varset)), c_number(caddr(varset)),
 			      c_number(cadr(cddr(varset))));
 		} else if (keyword_code(c_string(varsetname)) == K_REAL_TIME) {
