@@ -11,19 +11,16 @@ any later version.  See the file COPYING.  */
 
 #include "conq.h"
 #include "kernel.h"
-extern int gameinited;
 #include "ai.h"
 
 #define checked_elev_at(x, y) (elevations_defined() ? elev_at(x, y) : 0)
 
-extern Agreement *find_agreement(int id);
-
 static void init_visible_elevation(int x, int y);
 static void init_visible_elevation_2(int x, int y);
 static void calc_visible_elevation(int x, int y);
 static void calc_visible_elevation_2(int x, int y);
-static void cover_area_1(Side *side, struct a_unit *unit,
-				  int x0, int y0, int x1, int y1);
+static void cover_area_1(Side *side, struct a_unit *unit, int x0, int y0,
+			 int x1, int y1);
 static int see_materials(Side *side, int x, int y);
 static int see_weather(Side *side, int x, int y);
 static int mistaken_type(int u2);
@@ -49,14 +46,19 @@ Side *tmpside;
 
 int numsides;
 
+/* This is the number of sides including indepside. We need it for the
+   AI assignment in init.c. We want to keep numsides referring to
+   normal sides only, since it is used a lot in the interface code,
+   where we typically don't want to include indepside. */
+
+int numtotsides;
+
 /* Used to generate the id number of the side. */
 
 int nextsideid;
 
 /* Cached values of global vision vars. */
 
-int all_see_all;
-
 short any_los = -1;
 
 int any_material_views = -1;
@@ -93,10 +95,8 @@ Doctrine *last_doctrine;
 
 int next_doctrine_id;
 
-/* Init side machinery.   We always have an "independent" side hanging around;
-   it will be at the head of the list of sides, but normal side iteration
-   finesses this by starting from the second list element.  The independent
-   side is also a good placeholder for random stuff. */
+/* Init side machinery. Don't fill in indepside yet since numutypes etc. may 
+not be defined.  */
 
 void
 init_sides()
@@ -105,39 +105,21 @@ init_sides()
     sidelist = lastside = (Side *) xmalloc(sizeof(Side));
     /* The independent units' side will be the first one, is always created. */
     indepside = sidelist;
-    /* Fill in some properties of the independents' side. */
-    indepside->name = "- indep -";
-    indepside->noun = "- indep -";
-    indepside->pluralnoun = "- indeps -";
-    indepside->adjective = "independent";
-    indepside->colorscheme = NULL;
-    /* By default, independent units are not identified by an emblem. */
-    /* A game design can set this appropriately if desired, however. */
-    indepside->emblemname = "none";
-    indepside->id = 0;
-    /* Put valid Lisp data into slots that need it. */
-    indepside->symbol = lispnil;
-    indepside->instructions = lispnil;
-    indepside->rawscores = lispnil;
-    indepside->aidata = lispnil;
-    indepside->uidata = lispnil;
-    indepside->possible_units = lispnil;
-    indepside->advance = (short *) xmalloc(MAXATYPES * sizeof(short));
-    indepside->numadvances = 0;
-    indepside->treasury = (short *) xmalloc(MAXMTYPES * sizeof(short));
-    /* The independent side is not counted in numsides. */
+    /* Note: indepside is included in numtotsides, but not numsides. */
+    numtotsides = 0;
     numsides = 0;
-    /* Regular side ids start at 1 and go up. */
-    nextsideid = 1;
+    nextsideid = 0;
     /* Set up the list of players. */
     playerlist = last_player = NULL;
     numplayers = 0;
-    nextplayerid = 1;
+    /* Indepside also needs a player, so we now start with id 0. */
+    nextplayerid = 0;
     /* Set up the player/side assignment array. */
     assignments = (Assign *) xmalloc(MAXSIDES * sizeof(Assign));
     /* Set up the list of doctrines. */
     doctrine_list = last_doctrine = NULL;
-    next_doctrine_id = 1;
+    /* Indepside also needs a doctrine, so we now start with id 0. */
+    next_doctrine_id = 0;
 }
 
 /* Create an object representing a side. */
@@ -148,11 +130,24 @@ create_side()
     int u, m;
     Side *newside;
 
-    if (numsides >= g_sides_max()) {
+    if (numsides >=  g_sides_max()) {
 	run_error("Cannot have more than %d sides total!", g_sides_max());
     }
-    /* Allocate the side object proper. */
+    /* Just fill in the names if dealing with indepside. */
+    if (nextsideid == 0) {
+    	newside = indepside;
+	newside->name = "Independents";
+	newside->noun = "Independent";
+	newside->pluralnoun = "Independents";
+	newside->adjective = "independent";
+	newside->colorscheme = "black,black,white";
+	newside->emblemname = "none";
+    } else {
+    /* Else allocate a new side object and increase numsides. */
     newside = (Side *) xmalloc(sizeof(Side));
+	/* numsides does not include indepside, thus increment it here. */
+    	++numsides;
+    }
     /* Fill in various side slots.  Only those with non-zero/non-NULL
        defaults need have anything done to them. */
     newside->id = nextsideid++;
@@ -191,7 +186,8 @@ create_side()
     newside->losscounts = (short *) xmalloc(numutypes * num_loss_reasons * sizeof(short));
     newside->atkstats = (long **) xmalloc(numutypes * sizeof(long *));
     newside->hitstats = (long **) xmalloc(numutypes * sizeof(long *));
-    newside->prefixarg = -1;    /* Necessary to enable AI control toggling of selected units! */
+    /* Necessary to enable AI control toggling of selected units! */
+    newside->prefixarg = -1; 
     if (numatypes > 0) {
    	 newside->advance = (short *) xmalloc(numatypes * sizeof(short));
     	 newside->numadvances = 0;
@@ -200,14 +196,19 @@ create_side()
 	/* Set up the side's supply of materials. */
 	newside->treasury = (short *) xmalloc(nummtypes * sizeof(short));
 	for_all_material_types(m)
+	     if (side_has_treasury(newside, m))
 	  newside->treasury[m] = m_initial_treasury(m);
     }
     /* Link in at the end of the list of sides. */
     newside->next = NULL;
+    /* Important to avoid the indepside->next = indepside loop! */
+    if (newside != indepside) {
     lastside->next = newside;
     lastside = newside;
+    }
     init_side_unithead(newside);
-    ++numsides;
+    /* numtotsides also includes indepside. */
+    ++numtotsides;
     return newside;
 }
 
@@ -412,8 +413,7 @@ Side *side;
 /* Calculate the centroid of all the starting units. */
 
 void
-calc_start_xy(side)
-Side *side;
+calc_start_xy(Side *side)
 {
     int num = 0, sumx = 0, sumy = 0;
     Unit *unit;
@@ -432,23 +432,19 @@ Side *side;
 /* Given a side, get its "number", which is same as its "id". */
 
 int
-side_number(side)
-Side *side;
+side_number(Side *side)
 {
-    return (side == NULL ? indepside->id : side->id);
+    return side->id;
 }
 
 /* The inverse function - given a number, figure out which side it is.
-   Returns NULL for independent side number and for any failures. */
+   Returns NULL for any failure. */
 
 Side *
-side_n(n)
-int n;
+side_n(int n)
 {
     Side *side;
 
-    if (n < 1)
-      return NULL;
     for_all_sides(side)
       if (side->id == n)
         return side;
@@ -456,8 +452,7 @@ int n;
 }
 
 Side *
-find_side_by_name(str)
-char *str;
+find_side_by_name(char *str)
 {
     Side *side;
 
@@ -477,8 +472,7 @@ char *str;
 }
 
 Side *
-parse_side_spec(str)
-char *str;
+parse_side_spec(char *str)
 {
     int s;
     char *reststr;
@@ -497,11 +491,8 @@ char *str;
 /* This is true when one side controls another. */
 
 int
-side_controls_side(side, side2)
-Side *side, *side2;
+side_controls_side(Side *side, Side *side2)
 {
-    if (side == NULL || side2 == NULL)
-      return FALSE;
     return (side == side2 || side2->controlled_by == side);
 }
 
@@ -510,8 +501,7 @@ short *max_control_ranges;
 static int controller_here(int x, int y);
 
 static int
-controller_here(x, y)
-int x, y;
+controller_here(int x, int y)
 {
     Unit *unit2;
 
@@ -528,14 +518,12 @@ int x, y;
 /* This is true if the given side may operate on the given unit. */
 
 int
-side_controls_unit(side, unit)
-Side *side;
-Unit *unit;
+side_controls_unit(Side *side, Unit *unit)
 {
     int dir, x1, y1;
     Unit *unit2;
 
-    if (side == NULL || unit == NULL)
+    if (unit == NULL)
       return FALSE;
     if (is_designer(side))
       return TRUE;
@@ -599,22 +587,17 @@ Unit *unit;
 /* This is true if the given side may examine the given unit. */
 
 int
-side_sees_unit(side, unit)
-Side *side;
-Unit *unit;
+side_sees_unit(Side *side, Unit *unit)
 {
-    if (side == NULL || unit == NULL)
+    if (unit == NULL)
       return FALSE;
-    if (is_designer(side))
+    if (side->see_all)
       return TRUE;
     if (side_controls_side(side, unit->side))
       return TRUE;
     /* We may also examine units that trust us, */
     if (trusted_side(unit->side, side))
       return TRUE;
-    /* and every unit if we are debugging, */
-    if (Debug || DebugG || DebugM)
-      return TRUE;
     /* or if enemy peeking is allowed, */
     if (g_peek_at_enemy())
       return TRUE;
@@ -624,23 +607,35 @@ Unit *unit;
     return FALSE;
 }
 
+/* This is true if the side can see the image of a unit. */
+/* (will be more accurate when glimpse objects impled, this
+   reports that a concealed unit is visible if it might at
+   some point actually be spotted) */
+
 int
-side_sees_image(side, unit)
-Side *side;
-Unit *unit;
+side_sees_image(Side *side, Unit *unit)
 {
-    if (side == NULL || unit == NULL)
+    int uview;
+
+    if (side == NULL)
+      run_error("NULL side to side_sees_image");
+    if (unit == NULL)
       return FALSE;
-    if (is_designer(side))
-      return TRUE;
-    if (all_see_all)
+    if (side->see_all)
       return TRUE;
     if (side_controls_side(side, unit->side))
       return TRUE;
+    if (u_see_always(unit->type))
+      return TRUE;
     if (in_area(unit->x, unit->y)
 	&& side->coverage != NULL
 	&& cover(side, unit->x, unit->y) > 0)
       return TRUE;
+    /* (should be true only if see chance >= 100) */
+    uview = unit_view(side, unit->x, unit->y);
+    if (unit->type == vtype(uview)
+	&& side_number(unit->side) == vside(uview))
+      return TRUE;
     return FALSE;
 }
 
@@ -764,9 +759,7 @@ Unit *nextunit;
 }
 
 Unit *
-find_next_mover(side, prevunit)
-Side *side;
-Unit *prevunit;
+find_next_mover(Side *side, Unit *prevunit)
 {
     Unit *unit = NULL;
 
@@ -777,7 +770,7 @@ Unit *prevunit;
 	    if (is_unit(unit) && unit->id > 0
 		&& alive(unit)
 		&& inside_area(unit->x, unit->y)
-		&& (unit->act && unit->act->acp > 0)) {
+		&& has_acp_left(unit)) {
 		return unit;
 	    }
 	}
@@ -786,9 +779,7 @@ Unit *prevunit;
 }
 
 Unit *
-find_prev_mover(side, nextunit)
-Side *side;
-Unit *nextunit;
+find_prev_mover(Side *side, Unit *nextunit)
 {
     Unit *unit = NULL;
 
@@ -799,7 +790,7 @@ Unit *nextunit;
 	    if (is_unit(unit) && unit->id > 0
 		&& alive(unit)
 		&& inside_area(unit->x, unit->y)
-		&& (unit->act && unit->act->acp > 0)) {
+		&& has_acp_left(unit)) {
 		return unit;
 	    }
 	}
@@ -808,9 +799,7 @@ Unit *nextunit;
 }
 
 Unit *
-find_next_awake_mover(side, prevunit)
-Side *side;
-Unit *prevunit;
+find_next_awake_mover(Side *side, Unit *prevunit)
 {
     Unit *unit = NULL;
 
@@ -822,7 +811,7 @@ Unit *prevunit;
 		&& unit->id > 0
 		&& alive(unit)
 		&& inside_area(unit->x, unit->y)
-		&& (unit->act && unit->act->acp > 0)
+		&& has_acp_left(unit)
 		&& (unit->plan
 		    && !unit->plan->asleep
 		    && !unit->plan->reserve
@@ -835,9 +824,7 @@ Unit *prevunit;
 }
 
 Unit *
-find_prev_awake_mover(side, nextunit)
-Side *side;
-Unit *nextunit;
+find_prev_awake_mover(Side *side, Unit *nextunit)
 {
     Unit *unit = NULL;
 
@@ -847,11 +834,11 @@ Unit *nextunit;
 	    if (is_unit(unit) && unit->id > 0
 		&& alive(unit)
 		&& inside_area(unit->x, unit->y)
-				&& (unit->act && unit->act->acp > 0)
-				&& (unit->plan
-				    && !unit->plan->asleep
-				    && !unit->plan->reserve
-				    && !unit->plan->delayed)) {
+		&& has_acp_left(unit)
+		&& (unit->plan
+		    && !unit->plan->asleep
+		    && !unit->plan->reserve
+		    && !unit->plan->delayed)) {
 		return unit;
 	    }
 	}
@@ -929,8 +916,7 @@ Side *side;
 	if (unit != NULL
 	    && alive(unit)
 	    && inside_area(unit->x, unit->y)
-	    && (unit->act
-		&& unit->act->acp > 0)
+	    && has_acp_left(unit)
 	    && (unit->plan
 		&& !unit->plan->asleep
 		&& !unit->plan->reserve
@@ -1087,8 +1073,7 @@ char *newname;
 #ifdef DESIGNERS
 
 void
-become_designer(side)
-Side *side;
+become_designer(Side *side)
 {
     Side *side2;
 
@@ -1099,9 +1084,8 @@ Side *side;
     /* Designers have godlike power in the game, so mark it (permanently)
        as no longer a normal game. */
     compromised = TRUE;
-    side->may_set_see_all = TRUE;
-    /* See everything by default - can turn off manually if desired. */
-    side->see_all = TRUE;
+    side->may_set_show_all = TRUE;
+    side->show_all = TRUE;
     update_everything();
     for_all_sides(side2) {
 	update_side_display(side2, side, TRUE);
@@ -1109,8 +1093,7 @@ Side *side;
 }
 
 void
-become_nondesigner(side)
-Side *side;
+become_nondesigner(Side *side)
 {
     Side *side2;
 
@@ -1118,8 +1101,8 @@ Side *side;
       return;
     side->designer = FALSE;
     --numdesigners;
-    side->may_set_see_all = FALSE;
-    side->see_all = all_see_all;
+    side->may_set_show_all = FALSE;
+    side->show_all = side->see_all;
     update_everything();
     for_all_sides(side2) {
 	update_side_display(side2, side, TRUE);
@@ -1147,7 +1130,7 @@ int val;
     int oldval;
     Side *side3;
 
-    if (side == NULL || side2 == NULL || side == side2)
+    if (side == side2)
       return;
     if (side->trusts == NULL)
       return;
@@ -1178,7 +1161,7 @@ int val;
     int oldval, oldval2;
     Side *side3;
 
-    if (side == NULL || side2 == NULL || side == side2)
+    if (side == side2)
       return;
     if (side->trusts == NULL || side2->trusts == NULL)
       return;
@@ -1411,7 +1394,7 @@ int *types;
 
     if (sender == NULL)
       return;
-    if (all_see_all)
+    if (g_see_all())
       return;
     if (!g_terrain_seen()) {
 	for_all_cells(x, y) {
@@ -1443,8 +1426,6 @@ char *spec;
     char *arg, *arg2, *rest, substr[BUFSIZE];
     Doctrine *doctrine;
 
-    if (side == NULL)
-      return;
     rest = get_next_arg(spec, substr, &arg);
     if ((doctrine = find_doctrine_by_name(arg)) != NULL) {
 	/* Found a specific named doctrine. */
@@ -1492,10 +1473,7 @@ char *spec;
    when it first moves! */
 
 void
-all_see_occupy(unit, x, y, inopen)
-Unit *unit;
-int x, y;
-int inopen;
+all_see_occupy(Unit *unit, int x, int y, int inopen)
 {
     Side *side;
     int always = u_see_always(unit->type);
@@ -1553,10 +1531,7 @@ int inopen;
    is decremented. */
 
 void
-all_see_leave(unit, x, y, inopen)
-Unit *unit;
-int x, y;
-int inopen;
+all_see_leave(Unit *unit, int x, int y, int inopen)
 {
     Side *side;
     int always = u_see_always(unit->type);
@@ -1695,7 +1670,7 @@ int x0, y0, nx, ny;
     Side *side2;
 
     if (side != NULL
-	&& !all_see_all
+	&& !g_see_all()
 	&& !indep(unit)
 	&& completed(unit)
         && (oldtransport == NULL
@@ -1923,11 +1898,11 @@ int x0, y0, nx, ny;
 /* Use this to clear out garbled view coverage. */
 
 void
-reset_coverage()
+reset_coverage(void)
 {
     Side *side;
 
-    if (all_see_all)
+    if (g_see_all())
       return;
     for_all_sides(side)
       calc_coverage(side);
@@ -1936,8 +1911,7 @@ reset_coverage()
 /* Calculate/recalculate the view coverage layers of a side. */
 
 void
-calc_coverage(side)
-Side *side;
+calc_coverage(Side *side)
 {
     int x, y, s2, pop, visible[MAXSIDES];
     Unit *unit;
@@ -1972,21 +1946,22 @@ Side *side;
     }
 }
 
+/* (what is this for?) */
+
 void
-reset_all_views()
+reset_all_views(void)
 {
     Side *side;
 
-    if (all_see_all)
-      return;
     for_all_sides(side) {
-	reset_view(side);
+	if (!side->see_all) {
+	    reset_view(side);
+	}
     }
 }
 
 void
-reset_view(side)
-Side *side;
+reset_view(Side *side)
 {
     int x, y, uview;
 
@@ -2009,7 +1984,7 @@ int x, y;
     Unit *eunit;
     Side *es;
 
-    if (all_see_all /* see real unit */) {
+    if (g_see_all() /* see real unit */) {
     	/* (should look at all of stack if can be mixed) */
 	if ((eunit = unit_at(x, y)) != NULL) {
 	    if (react_to_enemies(unit) && !allied_side(eunit->side, side)) {
@@ -2250,7 +2225,7 @@ see_cell(Side *side, int x, int y)
     int m, mupdate, wupdate, seentype, mistakechance, flags;
     Unit *unit, *unitseen, *seer;
 
-    if (side == NULL || side == indepside || !in_area(x, y))
+    if (!in_area(x, y))
       return FALSE;
     update = updatet = FALSE;
     unitseen = NULL;
@@ -2421,9 +2396,9 @@ see_exact(Side *side, int x, int y)
     int olduview, oldtview, newtview, newuview, update, mupdate, wupdate;
     Unit *unit;
 
-    if (side == NULL || side == indepside || !in_area(x, y))
+    if (!in_area(x, y))
       return;
-    if (all_see_all) {
+    if (side->see_all) {
 	/* It may not really be necessary to do anything to the
 	   display, but the kernel doesn't know if the interface is
 	   drawing all the units that are visible, or is only drawing
@@ -3041,8 +3016,7 @@ int id;
 }
 
 Agreement *
-find_agreement(id)
-int id;
+find_agreement(int id)
 {
     Agreement *ag;
 
@@ -3200,9 +3174,7 @@ static int tmpuview;
 /* Paint the side's view with given values. */
 
 void
-paint_view(side, x, y, r, tview, uview)
-Side *side;
-int x, y, r, tview, uview;
+paint_view(Side *side, int x, int y, int r, int tview, int uview)
 {
     tmpside = side;
     tmptview = tview;
@@ -3211,15 +3183,27 @@ int x, y, r, tview, uview;
 }
 
 static void
-paint_view_1(x, y)
-int x, y;
+paint_view_1(int x, int y)
 {
+    int tview, uview;
     int oldtview = terrain_view(tmpside, x, y);
     int olduview = unit_view(tmpside, x, y);
+    Unit *unit;
 
     if (oldtview != tmptview || olduview != tmpuview) {
-	set_terrain_view(tmpside, x, y, tmptview);
-	set_unit_view(tmpside, x, y, tmpuview);
+	tview = tmptview;
+	if (tview == 1234567) {
+	    tview = buildtview(terrain_at(x, y));
+	}
+	set_terrain_view(tmpside, x, y, tview);
+	uview = tmpuview;
+	if (uview == 1234567) {
+	    uview = EMPTY;
+	    unit = unit_at(x, y);
+	    if (unit != NULL)
+	      uview = builduview(side_number(unit->side), unit->type);
+	}
+	set_unit_view(tmpside, x, y, uview);
 	update_cell_display(tmpside, x, y, UPDATE_ALWAYS | UPDATE_ADJ);
     }
 }
