@@ -53,9 +53,10 @@ typedef struct a_standing_order {
     struct a_standing_order *next; /* link to next standing order for side */
 } StandingOrder;
 
-/* Each Xconq player is a "side" - more or less one country.  A side may or
-   may not be played by a person, and may or may not have a display attached
-   to it.  Each side has a different view of the world.  */
+/* Each Xconq player is a "side" - more or less one country.  A side
+   may or may not be played by a person, and may or may not have a
+   display attached to it.  Each side has a different view of the
+   world.  */
 
 typedef struct a_side {
     int id;			/* a unique id */
@@ -160,7 +161,8 @@ typedef struct a_side {
     short finalradius;
     short willingtosave;	/* will this side go along with saving game? */
     short see_all;		/* true if this side sees everything */
-    short may_set_see_all;	/* true if player can ask to see everything */
+    short show_all;		/* true if this side displays everything */
+    short may_set_show_all;	/* true if player can ask to disp everything */
     short unit_view_restored;	/* true if unit view was read in */
 #ifdef DESIGNERS
     short designer;		/* true if side is doing scenario design */
@@ -185,30 +187,40 @@ typedef struct a_side {
     int prefixarg;		/* cache of UI prefixarg, for generic cmds */
     short numadvances;		/* Number of completed advances */
     short *advance;		/* State of research (accum pts) for each */ 
-    					/* advance. Set to -1 when completed. */ 
-    short *treasury;		/* Globally available supply of each material type. */
+    				/* advance. Set to -1 when completed. */ 
+    short *treasury;		/* Globally available supply of each
+				   material type. */
     /* Links. */
     struct a_side *next;	/* pointer to next in list */
 } Side;
 
 /* Some convenient macros. */
 
-#define side_in_play(side) (side == NULL || side->ingame)
+#define side_in_play(side) (side->ingame)
 
 /* Iteration over all sides. */
 
-/* The first "side" is just the independent units, don't usually look at it. */
+/* This is the old for_all_sides which does not include indepside. It
+   now also avoids null pointer crashes by checking that the sidelist
+   exists. */
 
-#define for_all_sides(v) for (v = sidelist->next; v != NULL; v = v->next)
+#define for_all_real_sides(v)  \
+  for (v = (sidelist ? sidelist->next : NULL); v != NULL; v = v->next)
 
-/* But sometimes we need to treat independents if they were on a side. */
+/* This is the new indepside-including version of for_all_sides. */
+
+#define for_all_sides(v)  \
+  for (v = sidelist; v != NULL; v = v->next)
+
+/* This is kept for compatibility with those places in the code where
+   there already was a specific need to include indepside. */
 
 #define for_all_sides_plus_indep(v)  \
   for (v = sidelist; v != NULL; v = v->next)
 
-/* Macros for accessing and setting a side's view data.  In general, interfaces
-   should go through these macros instead of accessing the world's state
-   directly. */
+/* Macros for accessing and setting a side's view data.  In general,
+   interfaces should go through these macros instead of accessing the
+   world's state directly. */
 
 #define terrain_view(s,x,y)  \
   ((s)->terrview ? aref((s)->terrview, x, y) : buildtview(terrain_at(x, y)))
@@ -365,6 +377,10 @@ typedef struct a_side {
 #define set_alt_cover(s,x,y,v)  \
   ((s)->alt_coverage ? aset((s)->alt_coverage, x, y, v) : 0)
 
+/* Tests both that s can have a treasury and that m can be stored in it. */
+
+#define side_has_treasury(s,m) (s != indepside ? m_treasury(m) : g_indepside_has_treasury() ? m_treasury(m) : FALSE) 
+
 /* Tests of who/what runs the side. */
 
 #define side_wants_display(s) ((s)->player && (s)->player->displayname)
@@ -392,13 +408,13 @@ typedef struct a_side {
 #define side_hitstats(s,a,d) ((s)->hitstats[a] ? ((s)->hitstats[a])[d] : 0)
 
 #define terrain_visible(side, x, y)  \
-  (all_see_all || (side)->see_all || (terrain_view((side), wrapx(x), (y)) != UNSEEN))
+  ((side)->see_all || (terrain_view((side), wrapx(x), (y)) != UNSEEN))
 
 #define borders_visible(side, x, y, d)  \
-  (all_see_all || (side)->see_all || seen_border((side), (x), (y), (d)))
+  ((side)->see_all || seen_border((side), (x), (y), (d)))
 
 #define units_visible(side, x, y)  \
-  (all_see_all || (side)->see_all || (cover((side), wrapx(x), (y)) >= 1))
+  ((side)->see_all || (cover((side), wrapx(x), (y)) >= 1))
 
 /* Handle crashes due to null indep side. */
 #define has_advance(side,a) (side != NULL ? ((side)->advance[(a)] == -1) : FALSE)
@@ -418,14 +434,12 @@ extern Side *curside;
 extern Side *tmpside;
 
 extern int numsides;
+extern int numtotsides;
 extern int numplayers;
 #ifdef DESIGNERS
 extern int numdesigners;
 #endif /* DESIGNERS */
 
-extern int all_see_all;
-extern int all_see_all_terrain;
-
 /* Definition of an agreement between sides. */
 
 typedef struct a_agreement {
@@ -548,6 +562,7 @@ extern char *standing_order_desc(StandingOrder *sorder, char *buf);
 
 extern void init_agreements(void);
 extern Agreement *create_agreement(int id);
+extern Agreement *find_agreement(int id);
 extern char *agreement_desig(Agreement *ag);
 
 extern void fn_set_terrain_view(int x, int y, int val);
