@@ -517,7 +517,7 @@ Task *task;
 		if (!is_active(unit2))
 		  continue;
 		/* No cheating! */
-		if (!unit_actually_visible(unit->side, unit2))
+		if (!side_sees_image(unit->side, unit2))
 		  continue;
 		if (u_acp(u2) + u_acp_to_fire(u2) <= 0)
 		  continue;
@@ -605,7 +605,7 @@ Unit *unit, *unit2;
 	    || uu_damage(unit->type, occ->type <= 0))
 	  continue;
 	/* Skip occs that we cannot see (no cheating - not even for the AI!) */
-	if (!unit_actually_visible(unit->side, occ))
+	if (!side_sees_image(unit->side, occ))
 	  continue;		    	
 	/* For vulnerable occs, check recursively that we also can hit
 	   all transports in the chain leading down to the occ. */
@@ -653,7 +653,7 @@ Unit *unit, *unit2;
 	    || uu_damage(unit->type, occ->type <= 0))
 	    	continue;
 	/* Skip occs that we cannot see (no cheating - not even for the AI!) */
-	if (!unit_actually_visible(unit->side, occ))
+	if (!side_sees_image(unit->side, occ))
 		continue;		    	
 	/* For vulnerable occs, check recursively that we also can 
 	hit all transports in the chain leading down to the occ. */
@@ -698,7 +698,7 @@ fire_can_damage_or_capture(Unit *unit, Unit *unit2)
 	    || uu_damage(unit->type, occ->type <= 0))
 	  continue;
 	/* Skip occs that we cannot see (no cheating - not even for the AI!) */
-	if (!unit_actually_visible(unit->side, occ))
+	if (!side_sees_image(unit->side, occ))
 	  continue;		    	
 	/* For vulnerable occs, check recursively that we also can 
 	hit all transports in the chain leading down to the occ. */
@@ -734,7 +734,7 @@ real_capture_chance(Unit *unit, Unit *unit2)
     /* Occupants can protect the unit. */
     for_all_occupants(unit2, unit3) {
 	if (is_active(unit3)
-	    && unit_actually_visible(unit->side, unit3)) {
+	    && side_sees_image(unit->side, unit3)) {
 	    prot = uu_protection(unit3->type, u2);
 	    if (prot != 100)
 	      chance = (chance * prot) / 100;
@@ -744,7 +744,7 @@ real_capture_chance(Unit *unit, Unit *unit2)
     for_all_stack(unit2->x, unit2->y, unit3) {
 	if (unit3 != unit2
 	    && is_active(unit3)
-	    && unit_actually_visible(unit->side, unit3)
+	    && side_sees_image(unit->side, unit3)
 	    && unit3->side == unit2->side) {
 	    prot = uu_stack_protection(unit3->type, u2);
 	    if (prot != 100)
@@ -753,7 +753,7 @@ real_capture_chance(Unit *unit, Unit *unit2)
     }
     for_all_stack_with_occs(unit2->x, unit2->y, unit3) {
 	if (is_active(unit3)
-	    && unit_actually_visible(unit->side, unit3)
+	    && side_sees_image(unit->side, unit3)
 	    /* We also extend protection to our buddies! */
 	    && trusted_side(unit3->side, unit2->side)) {
 	    /* This is when a unit, such as triple-A, provides unique
