@@ -16,8 +16,6 @@ extern int net_add_side_and_player(void);
 extern void net_set_player_advantage(int n, int newadv);
 extern void net_rename_side_for_player(int n);
 extern void net_set_ai_for_player(int n, char *aitype);
-extern int net_exchange_players(int n, int n2);
-extern void set_player_advantage(int n, int newadv);
 extern void rename_side_for_player(int n);
 extern void set_ai_for_player(int n, char *aitype);
 extern void add_to_packet(char *str);
@@ -337,9 +335,6 @@ download_to_player(Player *player)
 	send_assignment(player->rid, assignments[i].side,
 			assignments[i].player);
     }
-#if 0
-    send_id(player->id);
-#endif
     /* Make it run everything up to the player setup phase. */
     send_randstate(player->rid);
     /* If errors, should set player rid back to zero */
@@ -356,30 +351,15 @@ download_game_module(int rid)
     tmprid = rid;
     send_packet(rid, "gameModule");
     module = create_game_module("*download*");
-    /* Fill in some default slots. */
-    module->startlineno = 1;
-    module->endlineno = 1;
+    copy_module(module, mainmodule);
+    /* This module is not associated with a file. */
+    module->filename = NULL;
+    /* The module will sent in its entirety, so suppress any attempt
+       to load a base module. */
+    module->basemodulename = NULL;
     module->compress_tables = TRUE;
     module->compress_layers = TRUE;
     module->def_all = TRUE; /* for now */
-    if (mainmodule != NULL) {
-	module->title = mainmodule->title;
-	module->blurb = mainmodule->blurb;
-	module->picturename = mainmodule->picturename;
-#if 0 /* side-effects... */
-	module->basemodulename = mainmodule->basemodulename;
-	module->defaultbasemodulename = mainmodule->defaultbasemodulename;
-	module->basegame = mainmodule->basegame;
-#endif
-	module->version = mainmodule->version;
-	module->variants = mainmodule->variants;
-	if (!empty_string(mainmodule->origmodulename)) {
-	    module->origmodulename = mainmodule->origmodulename;
-	} else if (!empty_string(mainmodule->name)) {
-	    module->origmodulename = mainmodule->name;
-	}
-	module->origvariants = mainmodule->origvariants;
-    }
     downloading = TRUE;
     rslt = write_game_module(module);
     downloading = FALSE;
@@ -387,7 +367,7 @@ download_game_module(int rid)
     tmprid = 0;
 }
 
-#ifdef UNIX
+#ifndef MAC
 #define DOWNLOADPACKETSIZE 200
 #else
 #define DOWNLOADPACKETSIZE 40
