@@ -19,8 +19,6 @@ any later version.  See the file COPYING.  */
 #include "ai.h"
 #include "imf.h"
 #include "ui.h"
-extern void set_contour_interval(VP *vp, int n);
-extern int unit_actually_visible(Side *side, Unit *unit);
 
 #ifdef MAC /* temporary */
 #ifdef NEW_HEADERS
@@ -839,7 +837,7 @@ int usx, usy, usw, ush, sx, sy;
 	&& (side_controls_unit(side, unit)
 	    /* If side can examine unit in detail it can also see its occs. */
 	    || side_sees_unit(side, unit)
-	    || vp->see_all
+	    || vp->show_all
 	    || u_see_occupants(unit->type)
 	    || side_owns_occupant(side, unit))) {
 	for_all_occupants(unit, occ) {
@@ -899,10 +897,10 @@ Unit **unitp;
     return TRUE;
 }
 
+/* Return true if the cell is visible in the viewport. */
+
 int
-cell_is_visible(vp, x, y)
-VP *vp;
-int x, y;
+cell_is_visible(VP *vp, int x, int y)
 {
     int sx, sy;
  
@@ -922,12 +920,11 @@ int x, y;
     return TRUE;
 }
 
-/* Decide whether given location is away from the edge of the map's window. */
+/* Decide whether given location is away from the edge of the map's
+   window. */
 
 int
-cell_is_in_middle(vp, x, y)
-VP *vp;
-int x, y;
+cell_is_in_middle(VP *vp, int x, int y)
 {
     int sx, sy, insetx1, insety1, insetx2, insety2;
     
@@ -954,8 +951,7 @@ int x, y;
 /* Set vcx/vcy to point to the center of the view. */
 
 void
-focus_on_center(vp)
-VP *vp;
+focus_on_center(VP *vp)
 {
     vp->vcy = (vp->totsh - (vp->sy + vp->pxh / 2)) / vp->hch;
     vp->vcx = vp->sx / vp->hw - (vp->vcy / 2) + (vp->pxw / vp->hch) / 2;
@@ -973,8 +969,7 @@ VP *vp;
 }
 
 void
-center_on_focus(vp)
-VP *vp;
+center_on_focus(VP *vp)
 {
     int sx, sy, xnw = vp->vcx;
 
@@ -985,14 +980,12 @@ VP *vp;
     /* Scale, translate to top edge, flip. */
     sy = vp->totsh - (vp->vcy * vp->hch + vp->pxh / 2 + vp->hh / 2);
     set_view_position(vp, sx, sy);
-    DGprintf("View at %d,%d, focused at %d,%d\n",
-	     vp->sx, vp->sy, vp->vcx, vp->vcy);
+    DGprintf("Viewport 0x%x at %d,%d, focused at %d,%d\n",
+	     vp, vp->sx, vp->sy, vp->vcx, vp->vcy);
 }
 
 int
-set_view_size(vp, w, h)
-VP *vp;
-int w, h;
+set_view_size(VP *vp, int w, int h)
 {
     if (w < 1 || h < 1)
       run_error("Bad viewport size %dx%d", w, h);
@@ -1002,9 +995,7 @@ int w, h;
 }
 
 int
-set_view_position(vp, sx, sy)
-VP *vp;
-int sx, sy;
+set_view_position(VP *vp, int sx, int sy)
 {
     vp->sx = sx;  vp->sy = sy;
     /* Clip to rational limits. */
@@ -1017,9 +1008,7 @@ int sx, sy;
    and the scaled size in pixels of the entire world. */
 
 int
-set_view_power(vp, power)
-VP *vp;
-int power;
+set_view_power(VP *vp, int power)
 {
     vp->power = power;
     vp->mag = mags[power]; /* is this used?? */
@@ -1034,15 +1023,13 @@ int power;
 	vp->hch /= 4;
     }
     calc_view_misc(vp);
-    DGprintf("Power is now %d, total scaled area is %d x %d\n",
-	     vp->power, vp->totsw, vp->totsh);
+    DGprintf("Viewport 0x%x power is now %d, total scaled area is %d x %d\n",
+	     vp, vp->power, vp->totsw, vp->totsh);
     return TRUE;
 }
 
 int
-set_view_focus(vp, x, y)
-VP *vp;
-int x, y;
+set_view_focus(VP *vp, int x, int y)
 {
     if (!in_area(x, y))
       run_error("View focus of %d,%d not in area", x, y);
@@ -1051,9 +1038,7 @@ int x, y;
 }
 
 int
-set_view_angle(vp, angle)
-VP *vp;
-int angle;
+set_view_angle(VP *vp, int angle)
 {
     if (!(angle == 90 || angle == 30 || angle == 15)) {
 	run_warning("Bad angle %d, setting to 90", angle);
@@ -1079,16 +1064,13 @@ int angle;
 }
 
 int
-set_view_direction(vp, dir)
-VP *vp;
-int dir;
+set_view_direction(VP *vp, int dir)
 {
     return TRUE;
 }
 
 static void
-calc_view_misc(vp)
-VP *vp;
+calc_view_misc(VP *vp)
 {
     /* Calculate and cache the width in pixels of the whole area, adding an
        an adjustment to account for the "bulge" of hexagon-shaped areas. */
@@ -1112,12 +1094,136 @@ VP *vp;
 }
 
 void
-free_vp(vp)
-VP *vp;
+free_vp(VP *vp)
 {
     free(vp);
 }
 
+static int any_borders_in_dir(int x, int y, int dir);
+
+static int
+any_borders_in_dir(int x, int y, int dir)
+{
+    int t;
+
+    if (!any_aux_terrain_defined())
+      return FALSE;
+    /* (should iterate only over border types) */
+    for_all_terrain_types(t) {
+	if (t_is_border(t)
+	    && border_at(x, y, dir, t))
+	  return TRUE;
+    }
+    return FALSE;
+}
+
+/* Compute the transition between two cells with different terrain,
+   returning the positioning of the transition and which of four
+   subimages to use. */
+
+int
+compute_transition(Side *side, VP *vp, int x, int y, int dir,
+		   int *sxp, int *syp, int *swp, int *shp, int *offsetp)
+{
+    int t, x1, y1, t1, x2, y2, sx, sy, sw, sh, sx2, sy2;
+    int trite, tleft, overrite, overleft, offset;
+    int w = vp->hw, h = vp->hh, hch = vp->hch;
+
+    if (!point_in_dir(x, y, dir, &x1, &y1))
+      return FALSE;
+    if (!(vp->show_all || terrain_visible(side, x1, y1)))
+      return FALSE;
+    t = terrain_at(x, y);
+    t1 = terrain_at(x1, y1);
+    /* We want to overlap the adjacent terrain into this cell if the
+       terrain type is lower-numbered (meaning that sea usually
+       overlaps land for instance), but not if there is a border,
+       because the border itself provides the transition. */
+    if (t1 >= t || any_borders_in_dir(x, y, dir))
+      return FALSE;
+    if (point_in_dir(x, y, right_dir(dir), &x2, &y2))
+      trite = terrain_at(x2, y2);
+    else
+      trite = t;
+    /* Overlap on the right-hand corner if the third cell's terrain is
+       the same as the adjacent cell's terrain. */
+    overrite = (trite == t1);
+    /* Border on one side suppresses overlap. */
+    if (any_borders_in_dir(x, y, right_dir(dir)))
+      overrite = FALSE;
+    if (point_in_dir(x, y, left_dir(dir), &x2, &y2))
+      tleft = terrain_at(x2, y2);
+    else
+      tleft = t;
+    /* Overlap on the left-hand corner if the third cell's terrain is
+       the same as the adjacent cell's terrain. */
+    overleft = (tleft == t1);
+    /* Border on one side suppresses overlap. */
+    if (any_borders_in_dir(x, y, left_dir(dir)))
+      overleft = FALSE;
+    xform_cell(vp, x, y, &sx, &sy);
+    /* Now, given the overlaps on each side, choose the right piece of
+       transition bitmap to use. */
+    switch (dir) {
+      case NORTHEAST:
+	sx2 = sx + w / 2;  sy2 = sy;
+	sw = w / 2;  sh = h - hch + 1;
+	if (overrite)
+	  offset = 1;
+	else if (overleft)
+	  offset = 2;
+	break;
+      case EAST:
+	sx2 = sx + w / 2;  sy2 = sy + (h - hch) + 1;
+	sw = w / 2;  sh = h - 2 * (h - hch) - 2;
+	if (overrite)
+	  offset = 2;
+	else if (overleft)
+	  offset = 1;
+	break;
+      case SOUTHEAST:
+	sx2 = sx + w / 2;  sy2 = sy + hch - 1;
+	sw = w / 2;  sh = h - hch + 1;
+	if (overrite)
+	  offset = 1;
+	else if (overleft)
+	  offset = 2;
+	break;
+      case SOUTHWEST:
+	sx2 = sx;  sy2 = sy + hch - 1;
+	sw = w / 2;  sh = h - hch + 1;
+	if (overrite)
+	  offset = 2;
+	else if (overleft)
+	  offset = 1;
+	break;
+      case WEST:
+	sx2 = sx;  sy2 = sy + (h - hch) + 1;
+	sw = w / 2;  sh = h - 2 * (h - hch) - 2;
+	if (overrite)
+	  offset = 1;
+	else if (overleft)
+	  offset = 2;
+	break;
+      case NORTHWEST:
+	sx2 = sx;  sy2 = sy;
+	sw = w / 2;  sh = h - hch + 1;
+	if (overrite)
+	  offset = 2;
+	else if (overleft)
+	  offset = 1;
+	break;
+    }
+    if (overrite && overleft)
+      offset = 0;
+    else if (!overrite && !overleft)
+      offset = 3;
+    *sxp = sx2;  *syp = sy2;
+    *swp = sw;  *shp = sh;
+    *offsetp = offset;
+    return TRUE;
+}
+
 void
 compute_fire_line_segment(sx1, sy1, sx2, sy2, i, n, xx, yy, dx, dy)
 int sx1, sy1, sx2, sy2, i, n, *xx, *yy, *dx, *dy;
@@ -1515,20 +1621,21 @@ LineSegment **lines;
     }
 }
 
+#if 0
+/* Yet another test of whether a given unit is visible to a given side. */
+
 int
-unit_actually_visible(side, unit)
-Side *side;
-Unit *unit;
+unit_actually_visible(Side *side, Unit *unit)
 {
     int uview;
 
-	if (side == NULL)
-	  side = indepside;
+    if (side == NULL)
+      side = indepside;
     if (!in_play(unit))
       return FALSE;
     if (unit->side == side)
       return TRUE;
-    if (all_see_all || side->see_all)
+    if (side->see_all)
       return TRUE;
     if (u_see_always(unit->type))
       return TRUE;
@@ -1541,6 +1648,38 @@ Unit *unit;
       return TRUE;
     return FALSE;
 }
+#endif
+
+int
+unit_visible(Side *side, VP *vp, Unit *unit)
+{
+    if (vp->show_all)
+      return TRUE;
+    /* Designer needs to see all units, even when show_all has been
+       turned off - otherwise cells with units look empty. */
+    if (is_designer(side))
+      return TRUE;
+    return side_sees_unit(side, unit);
+}
+
+/* Test whether the occupants of the given unit are visible to the
+   given side. */
+
+int
+occupants_visible(Side *side, VP *vp, Unit *unit)
+{
+    if (unit->occupant == NULL)
+      return FALSE;
+    if (vp->show_all)
+      return TRUE;
+    if (side_controls_unit(side, unit))
+      return TRUE;
+    if (u_see_occupants(unit->type))
+      return TRUE;
+    if (side_owns_occupant(side, unit))
+      return TRUE;
+    return FALSE;
+}
 
 /* Don't draw the temperature in every cell, only do ones with even
    coords or ones where the temperature in any adjacent cell is
@@ -1594,15 +1733,11 @@ draw_winds_here(Side *side, int x, int y)
     return (x % 2 == 1 && y % 2 == 1);
 }
 
-#define cell_terrain(side, x, y)  \
-  (side->see_all ? terrain_at(x, y)  \
-   : (terrain_visible(side, x, y) ? vterrain(terrain_view(side, x, y)) : NONTTYPE))
+/* Return a textual description of what is at the given pixel in the
+   given viewport. */
 
 void
-oneliner(side, vp, sx, sy)
-Side *side;
-VP *vp;
-int sx, sy;
+oneliner(Side *side, VP *vp, int sx, int sy)
 {
     int x, y, xf, yf;
     Unit *unit;
@@ -1617,7 +1752,7 @@ int sx, sy;
     if (!in_area(x, y)) {
 	strcpy(tmpbuf, "(nothing)");
 	return;
-    } else if (terrain_visible(side, x, y)) {
+    } else if (vp->show_all || terrain_visible(side, x, y)) {
 	strcpy(tmpbuf, " ");
 	/* Describe the side of the people here. */
 	if (people_sides_defined()) {
@@ -1659,7 +1794,7 @@ int sx, sy;
 		peopdesc = ctrlbuf;
 	    }
 	}
-	if (units_visible(side, x, y)) {
+	if (vp->show_all || units_visible(side, x, y)) {
 	    if (unit != NULL) {
 		if (unit->side != side) {
 		    sidedesc = side_adjective(unit->side);
@@ -1707,7 +1842,10 @@ int sx, sy;
 	    strcat(tmpbuf, peopdesc);
 	    strcat(tmpbuf, " ");
 	}
-	t2 = cell_terrain(side, x, y);
+	if (side->see_all || vp->show_all)
+	  t2 = terrain_at(x, y);
+	else
+	  t2 = vterrain(terrain_view(side, x, y));
 	strcat(tmpbuf, t_type_name(t2));
 	if (sayin) {
 	    strcat(tmpbuf, ")");
@@ -1737,7 +1875,7 @@ int sx, sy;
 	latlong_desc(descbuf, x, y, xf, yf, 3);
 	strcat(tmpbuf, descbuf);
     }
-    if (terrain_visible(side, x, y)) {
+    if (vp->show_all || terrain_visible(side, x, y)) {
 	feature = feature_at(x, y);
 	if (feature != NULL) {
 	    if (feature->size > 0) {
@@ -1871,9 +2009,7 @@ Unit *unit;
     return (unit != NULL
 	    && alive(unit)
 	    && inside_area(unit->x, unit->y)
-	    && (unit->act
-		&& unit->act->acp > 0 /*
-		&& !has_pending_action(unit) */)
+	    && has_acp_left(unit)
 	    && (unit->plan
 		&& !unit->plan->asleep
 		&& !unit->plan->reserve
@@ -1967,19 +2103,15 @@ int ch, *dir1p, *dir2p, *modp;
 /* (should share diff cell and same cell interaction code) */
 
 int
-advance_into_cell(side, unit, x, y, other)
-Side *side;
-Unit *unit, *other;
-int x, y;
+advance_into_cell(Side *side, Unit *unit, int x, int y, Unit *other)
 {
     int z, m;
 
 #ifdef DESIGNERS
     /* Designers use this function to push units around, bound only by the
        limits on occupancy. */
-    if (side->designer) {
-	return net_designer_teleport(unit, x, y, other);
-    }
+    if (is_designer(side))
+      return net_designer_teleport(unit, x, y, other);
 #endif /* DESIGNERS */
     z = unit->z;
     if (x != unit->x || y != unit->y) {
@@ -2001,7 +2133,7 @@ int x, y;
 		}
 		/* If a unit was clicked on, decide how to interact. */
 		if (unit_trusts_unit(unit, other)
-		    || (other->side == NULL
+		    || (other->side == indepside
 			&& sides_allow_entry(unit, other))) {
 		    /* A friend, maybe get on it. */
 		    if (can_occupy(unit, other)) {
@@ -2137,15 +2269,13 @@ int x, y;
     return TRUE;
 }
 
-/* Given a unit and amounts of supplies desired to transfer, move as much of them
-   as possible into the unit's transport. */
+/* Given a unit and amounts of supplies desired to transfer, move as
+   much of them as possible into the unit's transport. */
 
 int give_supplies_to_one(Unit *unit, Unit *unit2, short *amts, short *rslts);
 
 int
-give_supplies(unit, amts, rslts)
-Unit *unit;
-short *amts, *rslts;
+give_supplies(Unit *unit, short *amts, short *rslts)
 {
     int dir, x1, y1, didsome;
     Unit *unit2;
@@ -2637,13 +2767,10 @@ int use_both_chars;
    location. */
 
 int
-terrain_seen_at(side, x, y)
-Side *side;
-int x, y;
+terrain_seen_at(Side *side, int x, int y)
 {
     if (in_area(x, y)
-	&& (side == NULL
-	    || all_see_all
+	&& (side->see_all
 #ifdef DESIGNERS
 	    || side->designer
 #endif /* DESIGNERS */
@@ -2660,14 +2787,11 @@ int x, y;
 /* (should result depend on contents of stack?) */
 
 Unit *
-unit_seen_at(side, x, y)
-Side *side;
-int x, y;
+unit_seen_at(Side *side, int x, int y)
 {
     if (!in_area(x, y))
       return NULL;
-    if (side == NULL
-	|| all_see_all
+    if (side->see_all
 #ifdef DESIGNERS
 	|| side->designer
 #endif /* DESIGNERS */
