@@ -7,11 +7,9 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern void interp_utype_list(short *arr, Obj *lis);
 extern int type_can_sit_on_conn(int u, int x, int y);
 #include "kernel.h"
 extern int num_sides_allowed(int u);
-extern void wreck_unit(Unit *unit);
 extern int side_owns_occupant(Side *side, Unit *unit);
 
 /* This is not a limit, just sets initial allocation of unit objects
@@ -199,8 +197,8 @@ int type, makebrains;
     /* At ground level. */
     newunit->z = 0;
     /* Units default to being independent. */
-    newunit->side = NULL;
-    newunit->origside = NULL;
+    newunit->side = indepside;
+    newunit->origside = indepside;
     /* Create at max hp, let others reduce if necessary. */
     newunit->hp = newunit->hp2 = u_hp(type);
     /* Create fully functional, let other routines set incompleteness. */
@@ -1207,27 +1205,29 @@ Unit *unit;
     unit->nexthere = NULL;
 }
 
+/* Add only the terrain types of adjacent cells to the unit's side's
+   view, don't show units or anything else. */
+
 void
-glimpse_adjacent_terrain(unit)
-Unit *unit;
+glimpse_adjacent_terrain(Unit *unit)
 {
     int x = unit->x, y = unit->y, dir, x1, y1;
     Side *side = unit->side;
 
     if (u_vision_range(unit->type) == 0
 	&& unit->transport == NULL
-	&& !all_see_all
+	&& !g_see_all()
 	&& !g_terrain_seen()
 	&& side != NULL) {
 	for_all_directions(dir) {
-		if (point_in_dir(x, y, dir, &x1, &y1)) {
-		    if (terrain_view(side, x1, y1) == UNSEEN) {
-			set_terrain_view(side, x1, y1,
-					 buildtview(terrain_at(x1, y1)));
-			update_cell_display(side, x1, y1,
-					    UPDATE_ALWAYS | UPDATE_ADJ);
-		    }
+	    if (point_in_dir(x, y, dir, &x1, &y1)) {
+		if (terrain_view(side, x1, y1) == UNSEEN) {
+		    set_terrain_view(side, x1, y1,
+				     buildtview(terrain_at(x1, y1)));
+		    update_cell_display(side, x1, y1,
+					UPDATE_ALWAYS | UPDATE_ADJ);
 		}
+	    }
 	}
     }
 }
@@ -1337,10 +1337,6 @@ int reason;
     Side *oldside = unit->side;
     Unit *occ;
 
-    if (newside == indepside) {
-	run_warning("non-null indepside");
-	newside = NULL;
-    }
     if (oldside == newside)
       return;
     /* Fail if the unit may not be on the new side. */
@@ -1457,8 +1453,6 @@ type_allowed_on_side(u, side)
 int u;
 Side *side;
 {
-    if (side == NULL)
-      side = indepside;
     if (side->uavail == NULL) {
 
 	int u2;
@@ -1534,9 +1528,6 @@ int
 unit_trusts_unit(unit1, unit2)
 Unit *unit1, *unit2;
 {
-    if (unit1->side == NULL || unit2->side == NULL)
-      return FALSE;
-    /* (should eventually be possible for some indeps to trust) */
     return (unit1->side == unit2->side
 	    || trusted_side(unit1->side, unit2->side));
 }
@@ -1557,11 +1548,9 @@ Side *side;
     int u = unit->type;
     Side *oldside, *newside;
 
-    if (side == indepside)
-      side = NULL;
     if (unit->side != side) {
 	/* Subtract from the counts for the ex-side. */
-	oldside = (unit->side ? unit->side : indepside);
+	oldside = unit->side;
 	if (oldside->numunits)
 	  --(oldside->numunits[u]);
 	if (oldside->numlive && in_play(unit))
@@ -1572,7 +1561,7 @@ Side *side;
 	unit->side = side;
 	/* Make sure this unit is off anybody else's list. */
 	delete_unit(unit);
-	newside = (side ? side : indepside);
+	newside = side;
 	insert_unit(newside->unithead, unit);
 	/* Add to counts for the side. */
 	if (newside->numunits)
@@ -1590,7 +1579,7 @@ Side *side;
 	}
 	/* Turn on automation for units that switch to being independent or under AI control. Note that the 
 	reverse is NOT true. Switching from AI to human control will therefore leave the unit on automatic. */
-	if (side == indepside || side == NULL || !side_has_display(side) || side_has_ai(side)) {
+	if (side == indepside || !side_has_display(side) || side_has_ai(side)) {
 		unit->autoplan = TRUE;
 		unit->autoresearch = TRUE;
 		unit->autobuild = TRUE;
@@ -1774,7 +1763,7 @@ int reason;
     /* Maybe enter the loss into the historical record. */
     if (reason >= 0)
       record_unit_death(unit, reason);
-    remove_unit_from_vector((unit->side ? unit->side : indepside)->actionvector, unit, -1);
+    remove_unit_from_vector(unit->side->actionvector, unit, -1);
     if (side != NULL) {
 	/* Invalidate the side's point value cache. */
 	side->point_value_valid = FALSE;
@@ -2677,23 +2666,32 @@ int u, s, x, y;
 /* Move a unit to a given location instantly, with all sides observing. */
 
 int
-designer_teleport(unit, x, y, other)
-Unit *unit, *other;
-int x, y;
+designer_teleport(Unit *unit, int x, int y, Unit *other)
 {
+    int oldx = unit->x, oldy = unit->y, rslt;
+    Side *side2;
+
     if (other != NULL && can_occupy(unit, other)) {
 	leave_cell(unit);
 	enter_transport(unit, other);
 	all_see_cell(x, y);
-	return TRUE;
+	rslt = TRUE;
     } else if (can_occupy_cell(unit, x, y)) {
-	leave_cell(unit);
-	enter_cell(unit, x, y);
-	all_see_cell(x, y);
-	return TRUE;
+	change_cell(unit, x, y);
+	rslt = TRUE;
     } else {
-	return FALSE;
+	rslt = FALSE;
     }
+    if (rslt) {
+	/* Provide accurate info on affected cells. */
+	for_all_sides(side2) {
+	    if (is_designer(side2)) {
+		see_exact(side2, oldx, oldy);
+		see_exact(side2, x, y);
+	    }
+	}
+    }
+    return rslt;
 }
 
 int
