@@ -134,7 +134,7 @@ The test for (var) != (u)->nexthere is to stop the macro from climbing up above
 
 #define alive(unit) ((unit)->hp > 0)
 
-#define indep(unit) ((unit)->side == NULL || (unit)->side == indepside)
+#define indep(unit) ((unit)->side == indepside)
 
 #define completed(unit) \
   ((unit)->cp >= completenesses[(unit)->type])
@@ -217,7 +217,7 @@ The test for (var) != (u)->nexthere is to stop the macro from climbing up above
   (((unit)->extras && (unit)->extras->hook) ? (unit)->extras->hook : lispnil)
 
 #define unit_doctrine(unit)  \
-  ((unit->side ? unit->side : indepside)->udoctrine[unit->type])
+  (unit->side->udoctrine[unit->type])
 
 /* A sortable vector of units, generally useful. */
 
@@ -289,6 +289,11 @@ typedef struct a_actorstate {
 #define has_pending_action(unit)  \
   ((unit)->act && (unit)->act->nextaction.type != ACTION_NONE)
 
+/* This is true if the unit still has acp left to act with. */
+
+#define has_acp_left(unit) \
+  ((unit)->act && (unit)->act->acp > u_acp_min((unit)->type))
+
 /* All the definitions that govern planning. */
 
 /* A goal is a predicate object that can be tested to see whether it has
@@ -505,7 +510,8 @@ extern void add_unit_to_stack(Unit *unit, int x, int y);
 extern void remove_unit_from_stack(Unit *unit);
 extern void glimpse_adjacent_terrain(Unit *unit);
 extern void add_to_unit_hp(Unit *unit, int hp);
-extern void wreck_unit(Unit *unit);
+
+extern void interp_utype_list(short *arr, Obj *lis);
 
 /* Declarations of plan-related functions. */
 
