@@ -10,8 +10,6 @@ any later version.  See the file COPYING.  */
 #include "misc.h"
 extern int select_by_weight(int *arr, int numvals);
 extern void debugging_string(char *buf);
-extern int warnings_logged;
-extern void log_warning(char *typ, char *str);
 #include "lisp.h"
 #include "dir.h"
 
@@ -23,6 +21,32 @@ extern void log_warning(char *typ, char *str);
 #endif
 #endif
 
+#ifdef MAC
+
+/* Fake definitions for the Mac. */
+
+struct timeval {
+    time_t tv_sec;
+    int tv_usec;
+};
+
+extern int gettimeofday(struct timeval *tv, void *tz);
+
+int gettimeofday(struct timeval *tv, void *tz)
+{
+    int ticks = TickCount();
+
+    tv->tv_sec = ticks / 60;
+    tv->tv_usec = (ticks % 60) * (1000000 / 60);
+    return 0;
+}
+
+#else
+
+#include <sys/time.h>
+
+#endif /* MAC */
+
 /* Direction-to-delta conversions. */
 
 int dirx[NUMDIRS] = DIRX;
@@ -37,8 +61,6 @@ int warnings_suppressed;
 
 int warnings_logged = TRUE;
 
-static FILE *ewfp;
-
 /* If true, allocation attempts will garner complaints, but not actually
    fail.  (This is primarily for debugging addon code, such as new AIs
    and user interfaces.) */
@@ -669,6 +691,9 @@ debugg_printf(char *str, ...)
 
 #endif /* DEBUGGING */
 
+/* The following code records execution traces of game activities.  This
+   is generally only useful for high-level code such as run_game. */
+
 struct a_timeline_entry {
   int start;
   int end;
@@ -677,8 +702,10 @@ struct a_timeline_entry {
   int detail2;
 };
 
+#define BLOCKSIZE 10000
+
 typedef struct a_timeline_block {
-  struct a_timeline_entry entries[10000];
+  struct a_timeline_entry entries[BLOCKSIZE];
   int index;
   struct a_timeline_block *next;
 } TimelineBlock;
@@ -691,48 +718,37 @@ static TimelineBlock *current_timeline_block;
 
 static char *current_activity;
 
-#ifdef UNIX
-
-#include <sys/time.h>
-
 static struct timeval initial_time;
-#endif
 
 void
 record_activity_start(char *type, int detail)
 {
     TimelineBlock *tlblock;
     int usec;
+    struct timeval curtime;
 
     if (!activity_trace)
       return;
     if (current_activity != NULL)
       run_warning("starting activity %s before %s done\n",
 		  type, current_activity);
+    /* Allocate a timeline block if needed. */
     if (current_timeline_block == NULL) {
 	current_timeline_block =
 	  (TimelineBlock *) xmalloc(sizeof(TimelineBlock));
     }
     if (starting_trace) {
 	current_timeline_block->index = 0;
-#ifdef UNIX
 	gettimeofday(&initial_time, NULL);
-#endif
 	starting_trace = FALSE;
     }
     tlblock = current_timeline_block;
-    if (tlblock->index >= 9999)
+    if (tlblock->index >= (BLOCKSIZE - 2))
       return;
-#ifdef UNIX
-    {
-	struct timeval curtime;
-
-	gettimeofday(&curtime, NULL);
-	usec = (curtime.tv_sec - initial_time.tv_sec) * 1000000
-	  + curtime.tv_usec - initial_time.tv_usec;
-	tlblock->entries[tlblock->index].start = usec;
-    }
-#endif
+    gettimeofday(&curtime, NULL);
+    usec = (curtime.tv_sec - initial_time.tv_sec) * 1000000
+      + curtime.tv_usec - initial_time.tv_usec;
+    tlblock->entries[tlblock->index].start = usec;
     tlblock->entries[tlblock->index].type = type;
     tlblock->entries[tlblock->index].detail1 = detail;
     current_activity = type;
@@ -743,25 +759,20 @@ record_activity_end(char *type, int detail)
 {
     TimelineBlock *tlblock;
     int usec;
+    struct timeval curtime;
 
     if (!activity_trace)
       return;
     if (type != current_activity)
       run_warning("ending activity %s instead of %s\n",
-		  type, current_activity);
+		  type, (current_activity ? current_activity : "<null>"));
     tlblock = current_timeline_block;
-    if (tlblock->index >= 9999)
+    if (tlblock->index >= (BLOCKSIZE - 2))
       return;
-#ifdef UNIX
-    {
-	struct timeval curtime;
-
-	gettimeofday(&curtime, NULL);
-	usec = (curtime.tv_sec - initial_time.tv_sec) * 1000000
-	  + curtime.tv_usec - initial_time.tv_usec;
-	tlblock->entries[tlblock->index].end = usec;
-    }
-#endif
+    gettimeofday(&curtime, NULL);
+    usec = (curtime.tv_sec - initial_time.tv_sec) * 1000000
+      + curtime.tv_usec - initial_time.tv_usec;
+    tlblock->entries[tlblock->index].end = usec;
     tlblock->entries[tlblock->index].detail2 = detail;
     ++(tlblock->index);
     current_activity = NULL;
@@ -784,12 +795,14 @@ dump_activity_trace(void)
 	    fprintf(fp, "%d %d %s %d %d\n",
 		    entry->start, entry->end - entry->start, entry->type,
 		    entry->detail1, entry->detail2);
+#if 0  /* doubles size of trace */
 	    if (tlblock->entries[i+1].start > entry->end + 5) {
 		fprintf(fp, "%d %d %s %d %d\n",
 			entry->end + 1,
 			tlblock->entries[i+1].start - entry->end,
 			"gap", 0, 0);
 	    }
+#endif
 	}
 	fclose(fp);
     }
@@ -872,12 +885,24 @@ run_warning(char *str, ...)
     low_run_warning(buf);
 }
 
+/* When we log a warning, we want to open and close the file each time,
+   just in case the warning immediately precedes disaster. */
+
 void
 log_warning(char *typ, char *str)
 {
-    ewfp = open_file("Xconq.Warnings", "a");
+    static int first_warning = TRUE;
+    static FILE *ewfp;
+
+    if (ewfp == NULL) {
+	/* (should make filename platform-specific) */
+	ewfp = open_file("Xconq.Warnings", (first_warning ? "w" : "a"));
+	/* (should record date) */
+    }
     if (ewfp != NULL) {
-      fprintf(ewfp, "%s: %s\n", typ, str);
-      fclose(ewfp);
+	fprintf(ewfp, "%s: %s\n", typ, str);
+	fclose(ewfp);
+	ewfp = NULL;
+	first_warning = FALSE;
     }
 }
