@@ -1,5 +1,5 @@
 /* Worlds and areas in Xconq.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -7,8 +7,8 @@ the Free Software Foundation; either version 2, or (at your option)
 any later version.  See the file COPYING.  */
 
 #include "conq.h"
-extern int num_features PARAMS ((void));
-extern void divide_into_regions PARAMS ((char *tlayer, TRegion **rlayer));
+extern int num_features(void);
+extern void divide_into_regions(char *tlayer, TRegion **rlayer);
 #include "kernel.h"
 
 #include <math.h>
@@ -322,19 +322,11 @@ allocate_area_terrain()
     area.units = malloc_area_layer(Unit *);
 
     /* Advanced unit support. */
-
-// --- USER LAYER FIX -----------------------------------------
-
     area.user = malloc_area_layer(short);
 
     /* NOUSER != 0, so need to blast it over the layer. Note: sizeof(short) important, 
     since memset by default assumes char, and only half the layer get blasted. */
     memset(area.user, NOUSER, area.width * area.height * sizeof(short));
-
-//    area.user = malloc_area_layer(Unit *);
-
-// --------------------------------------------------------
-
 }
 
 /* Set up the auxiliary terrain layer of the area. */
@@ -484,8 +476,6 @@ allocate_area_winds()
     }
 }
 
-// --- ADVANCED UNIT SUPPORT ------------------------------------
-
 void
 allocate_area_users()
 {
@@ -498,8 +488,6 @@ allocate_area_users()
     }
 }
 
-// ----------------------------------------------------------
-
 int
 fn_terrain_at(x, y)
 int x, y;
@@ -542,8 +530,6 @@ int x, y;
     return control_side_at(x, y);
 }
 
-// ---ADVANCED UNIT SUPPORT -------------------------------------------------------
-
 int
 fn_user_at(x, y)
 int x, y;
@@ -551,8 +537,6 @@ int x, y;
     return user_at(x, y);
 }
 
-// -----------------------------------------------------------------------------
-
 int
 fn_material_at(x, y)
 int x, y;
@@ -599,7 +583,7 @@ void
 fn_set_terrain_at(x, y, val)
 int x, y, val;
 {
-    extern warnbadterrain, numbadterrain;
+    extern int warnbadterrain, numbadterrain;
 
     /* It's important not to put bad values into the terrain layer. */
     if (!is_terrain_type(val)) {
@@ -637,8 +621,6 @@ int x, y, val;
     set_control_side_at(x, y, val);
 }
 
-// ---ADVANCED UNIT SUPPORT -------------------------------------------------------
-
 void
 fn_set_user_at(x, y, val)
 int x, y, val;
@@ -646,8 +628,6 @@ int x, y, val;
     set_user_at(x, y, val);
 }
 
-// -----------------------------------------------------------------------------
-
 void
 fn_set_raw_feature_at(x, y, val)
 int x, y, val;
@@ -809,7 +789,7 @@ int x, y, t2;
 
 int
 search_around(x0, y0, maxdist, pred, rxp, ryp, incr)
-int x0, y0, maxdist, (*pred) PARAMS ((int, int)), *rxp, *ryp, incr;
+int x0, y0, maxdist, (*pred)(int, int), *rxp, *ryp, incr;
 {
     int clockwise, dist, dd, d, dir, x1, y1, i, dir2, x, y, xw;
 
@@ -839,8 +819,8 @@ int x0, y0, maxdist, (*pred) PARAMS ((int, int)), *rxp, *ryp, incr;
 int
 search_and_apply(x0, y0, maxdist, pred, rxp, ryp, incr, fn, num)
 int x0, y0, maxdist, *rxp, *ryp, incr, num;
-int (*pred) PARAMS ((int, int));
-void (*fn) PARAMS ((int, int));
+int (*pred)(int, int);
+void (*fn)(int, int);
 {
     int clockwise, dist, x0w, dd, d, dir, x1, y1, i, dir2, x, y, xw;
 
@@ -848,11 +828,13 @@ void (*fn) PARAMS ((int, int));
     clockwise = (flip_coin() ? 1 : -1);
     if (maxdist >= 0) {
 	x0w = wrapx(x0);
-	if (inside_area(x0w, y0) && (*pred)(x0w, y0)) {
-	    *rxp = x0w;  *ryp = y0;
-	    (*fn)(x0w, y0);
-	    if (--num <= 0)
-	      return TRUE;
+	if (inside_area(x0w, y0)) {
+	    if ((*pred)(x0w, y0)) {
+		*rxp = x0w;  *ryp = y0;
+		(*fn)(x0w, y0);
+	    } else {
+		return 0;
+	    }
 	}
     }
     for (dist = 1; dist <= maxdist; dist += incr) {
@@ -867,17 +849,19 @@ void (*fn) PARAMS ((int, int));
 		y = y1 + i * diry[dir2] * incr;
 		if (between(0, y, area.height-1)) {
 		    xw = wrapx(x);
-		    if (inside_area(x, y) && (*pred)(xw, y)) {
-			*rxp = xw;  *ryp = y;
-			(*fn)(xw, y);
-			if (--num <= 0)
-			  return TRUE;
+		    if (inside_area(x, y)) {
+			if ((*pred)(xw, y)) {
+			    *rxp = xw;  *ryp = y;
+			    (*fn)(xw, y);
+			} else {
+			    return 0;
+			}
 		    }
 		}
 	    }
 	}
     }
-    return FALSE;
+    return 0;
 }
 
 /* Apply a function to every cell within the given radius, being careful (for
@@ -891,7 +875,7 @@ int stop_apply;
 void
 apply_to_area(x0, y0, dist, fn)
 int x0, y0, dist;
-void (*fn) PARAMS ((int, int));
+void (*fn)(int, int);
 {
     int x, y, x1, y1, x2, y2;
 
@@ -920,7 +904,7 @@ void (*fn) PARAMS ((int, int));
 void
 apply_to_area_plus_edge(x0, y0, dist, fn)
 int x0, y0, dist;
-void (*fn) PARAMS ((int, int));
+void (*fn)(int, int);
 {
     int x, y, x1, y1, x2, y2;
 
@@ -945,7 +929,7 @@ void (*fn) PARAMS ((int, int));
 void
 apply_to_ring(x0, y0, distmin, distmax, fn)
 int x0, y0, distmin, distmax;
-void (*fn) PARAMS ((int, int));
+void (*fn)(int, int);
 {
     int dist, x, y, x1, y1, x2, y2;
 
@@ -972,7 +956,7 @@ void (*fn) PARAMS ((int, int));
 void
 apply_to_hexagon(x0, y0, w2, h2, fn)
 int x0, y0, w2, h2;
-void (*fn) PARAMS ((int, int));
+void (*fn)(int, int);
 {
     int x, y, x1, y1, x2, y2;
 
@@ -996,14 +980,14 @@ void (*fn) PARAMS ((int, int));
 /* Apply a function all along a path. */
 
 void
-apply_to_path(fx, fy, tx, ty, dirtest, dirsort, fn, shortest)
-int fx, fy, tx, ty, shortest;
-int (*dirtest) PARAMS ((int x, int y, int dir));
-int (*dirsort) PARAMS ((int x, int y, int *dirchoices, int numchoices));
-int (*fn) PARAMS ((int x, int y, int dir, int j, int numchoices));
+apply_to_path(int fx, int fy, int tx, int ty,
+	      int (*dirtest)(int x, int y, int dir),
+	      int (*dirsort)(int x, int y, int *dirchoices, int numchoices),
+	      int (*fn)(int x, int y, int dir, int j, int numchoices),
+	      int shortest)
 {
     int i = 500, j, x = fx, y = fy, moved;
-    int dx, dxa, dy, dirchoices[NUMDIRS], axis, hextant, tmp, sig;
+    int dx, dxa, dy, dirchoices[NUMDIRS], axis, hextant, sig;
     int d1, d2, d3, d4;
     int numchoices, shortestnumchoices;
 
@@ -1121,7 +1105,7 @@ int (*fn) PARAMS ((int x, int y, int dir, int j, int numchoices));
 int
 find_path(fx, fy, tx, ty, chooser, maxwps, waypoints, numwpsp)
 int fx, fy, tx, ty, maxwps, *numwpsp;
-int (*chooser) PARAMS ((int, int, int, int, int *));
+int (*chooser)(int, int, int, int, int *);
 Waypoint *waypoints;
 {
     int ndirs, trythese[NUMDIRS], i;
@@ -1145,7 +1129,7 @@ Waypoint *waypoints;
 
 int
 search_straight_line(x0, y0, x1, y1, pred, rxp, ryp)
-int x0, y0, x1, y1, (*pred) PARAMS ((int, int)), *rxp, *ryp;
+int x0, y0, x1, y1, (*pred)(int, int), *rxp, *ryp;
 {
     int i, dist, x, y, xw;
 
@@ -1421,15 +1405,8 @@ renumber_features()
     }
 }
 
-static int
-is_feature_cell(x, y)
-int x, y;
-{
-    return (raw_feature_at(x, y) == tmpint);
-}
-
 void
-compute_all_feature_centroids()
+compute_all_feature_centroids(void)
 {
     compute_feature_centroid(NULL);
 }
@@ -1438,10 +1415,9 @@ compute_all_feature_centroids()
    for each feature in the world. */
 
 void
-compute_feature_centroid(feature)
-Feature *feature;
+compute_feature_centroid(Feature *feature)
 {
-    int x, y, fid, maxdistx, maxdisty, maxdist;
+    int x, y;
     Feature *tmpfeature;
 
     /* Only do this if features and a feature layer to work with. */
@@ -1474,37 +1450,12 @@ Feature *feature;
 		tmpfeature->x = tmpfeature->x / tmpfeature->size;
 		tmpfeature->y = tmpfeature->y / tmpfeature->size;
 	    }
-
-// --- REMOVE THIS TO FIX THE FEATURE NAME BUG ----------------------------------------------
-
-/*
-	This piece of code causes many feature names to be drawn in totally wrong positions, usually on top of another
-	feature name anywhere else on the map. Basically, it seems that the code incorrectly copies existing  feature->x 
-	and feature->y values from one feature to several other features. I have tried to find the bug, but with no success. 
-	However, everything works fine if the code just is deleted, as far as I can tell.  Also, even if one could get this 
-	code to work as intended, it really makes no sense in trying to find the closest point.  For example, if the feature 
-	is two islands (such as the Azores) isn't it better to draw the name between the two than on top of either island?
-*/
-	    /* If tmpfeature centroid not actually inside tmpfeature, find closest point. */
-/*	    if (in_area(tmpfeature->x, tmpfeature->y) && tmpfeature->size >0
-		&& raw_feature_at(x, y) != tmpfeature->id) {
-		maxdistx = max(tmpfeature->xmax - tmpfeature->x, tmpfeature->x - tmpfeature->xmin);
-		maxdisty = max(tmpfeature->ymax - tmpfeature->y, tmpfeature->y - tmpfeature->ymin);
-		maxdist = max(maxdistx, maxdisty);
-		tmpint = tmpfeature->id;
-		search_around(tmpfeature->x, tmpfeature->y, maxdist, is_feature_cell, &x, &y, 1);
-		tmpfeature->x = x;  tmpfeature->y = y;
-	    }
-*/
-
-// -------------------------------------------------------------------------------
-
 	}
     }
 }
 
 int 
-num_features()
+num_features(void)
 {
     int f = 0, x, y;
 
@@ -1899,8 +1850,11 @@ int lat, lon, *xp, *yp, *xfp, *yfp;
     /* Latitude of 0 passes through the center of the area. */
     *yp = y1 / 1000 - area.latitude + area.halfheight;
     *yfp = y1 % 1000;
+
     /* Convert longitude to cell. */
-    if (lon <= 0)
+    /* Only do this for wrapped areas, or it will prevent drawing of 
+    the Western hemisphere meridians on the Mac. */
+    if (lon <= 0 && area.xwrap)
       lon += MINUTES;
     fx1 = (((float) lon) * world.circumference) / MINUTES;
     fx1 -= area.longitude;
@@ -1923,9 +1877,9 @@ int lat, lon, *xp, *yp, *xfp, *yfp;
     return TRUE;
 }
 
-void add_neighbor PARAMS ((TRegion *reg1, TRegion *reg2));
+void add_neighbor(TRegion *reg1, TRegion *reg2);
 
-int region_value PARAMS ((int x, int y));
+int region_value(int x, int y);
 
 int
 region_value(x, y)
@@ -2043,16 +1997,16 @@ TRegion *reg1, *reg2;
 
 #ifdef DESIGNERS
 
-static void paint_cell_1 PARAMS ((int x, int y));
-static void paint_coating_1 PARAMS ((int x, int y));
-static void paint_people_1 PARAMS ((int x, int y));
-static void paint_control_1 PARAMS ((int x, int y));
-static void paint_feature_1 PARAMS ((int x, int y));
-static void paint_elevation_1 PARAMS ((int x, int y));
-static void paint_temperature_1 PARAMS ((int x, int y));
-static void paint_material_1 PARAMS ((int x, int y));
-static void paint_clouds_1 PARAMS ((int x, int y));
-static void paint_winds_1 PARAMS ((int x, int y));
+static void paint_cell_1(int x, int y);
+static void paint_coating_1(int x, int y);
+static void paint_people_1(int x, int y);
+static void paint_control_1(int x, int y);
+static void paint_feature_1(int x, int y);
+static void paint_elevation_1(int x, int y);
+static void paint_temperature_1(int x, int y);
+static void paint_material_1(int x, int y);
+static void paint_clouds_1(int x, int y);
+static void paint_winds_1(int x, int y);
 
 /* Cell painting. */
 
@@ -2093,6 +2047,10 @@ int x, y, dir, t, mode;
     set_border_at(x, y, dir, t, (mode < 0 ? !oldbord : mode));
     if (oldbord != border_at(x, y, dir, t)) {
 	update_cell_display(side, x, y, UPDATE_ALWAYS | UPDATE_ADJ);
+	/* We need to do this because UPDATE_ADJ is a hint, not a
+	   requirement to redraw adjacent cells. */
+	if (point_in_dir(x, y, dir, &x1, &y1))
+	  update_cell_display(side, x1, y1, UPDATE_ALWAYS | UPDATE_ADJ);
     }
 }
 
@@ -2110,6 +2068,10 @@ int x, y, dir, t, mode;
     set_connection_at(x, y, dir, t, (mode < 0 ? !oldconn : mode));
     if (oldconn != connection_at(x, y, dir, t)) {
 	update_cell_display(side, x, y, UPDATE_ALWAYS | UPDATE_ADJ);
+	/* We need to do this because UPDATE_ADJ is a hint, not a
+	   requirement to redraw adjacent cells. */
+	if (point_in_dir(x, y, dir, &x1, &y1))
+	  update_cell_display(side, x1, y1, UPDATE_ALWAYS | UPDATE_ADJ);
     }
 }
 
@@ -2156,7 +2118,7 @@ static void
 paint_people_1(x, y)
 int x, y;
 {
-    int oldpeop = people_side_at(x, y), dir, x1, y1;
+    int oldpeop = people_side_at(x, y);
 
     if (oldpeop != tmpint) {
 	set_people_side_at(x, y, tmpint);
@@ -2183,7 +2145,7 @@ static void
 paint_control_1(x, y)
 int x, y;
 {
-    int oldpeop = control_side_at(x, y), dir, x1, y1;
+    int oldpeop = control_side_at(x, y);
 
     if (oldpeop != tmpint) {
 	set_control_side_at(x, y, tmpint);
@@ -2211,7 +2173,7 @@ static void
 paint_feature_1(x, y)
 int x, y;
 {
-    int oldfid = raw_feature_at(x, y), dir, x1, y1;
+    int oldfid = raw_feature_at(x, y);
     Feature *oldfeature;
 
     if (oldfid != tmpint) {
@@ -2229,7 +2191,6 @@ int x, y;
 	    }
 	}
 	/* Might need to redraw feature borders in adjacent cells. */
-	/* (should test before redirecting redraw?) */
 	update_cell_display(tmpside, x, y, UPDATE_ALWAYS | UPDATE_ADJ);
     }
 }
@@ -2251,7 +2212,7 @@ static void
 paint_elevation_1(x, y)
 int x, y;
 {
-    int n, t = terrain_at(x, y), oldelev = elev_at(x, y), dir, x1, y1;
+    int n, t = terrain_at(x, y), oldelev = elev_at(x, y);
 
     /* Clip desired elevation to what's allowed for the terrain here. */
     n = max(t_elev_min(t), min(tmpint, t_elev_max(t)));
@@ -2356,7 +2317,7 @@ int x, y;
 	changed = TRUE;
     }
     if (changed)
-         update_cell_display(tmpside, x, y, UPDATE_ALWAYS | UPDATE_ADJ);
+      update_cell_display(tmpside, x, y, UPDATE_ALWAYS | UPDATE_ADJ);
 }
 
 /* Winds painting. */
