@@ -1,5 +1,5 @@
 /* Definitions relating to worlds and areas in Xconq.
-   Copyright (C) 1987-1989, 1991-1998 Stanley T. Shebs.
+   Copyright (C) 1987-1989, 1991-1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -170,10 +170,12 @@ typedef struct a_region_link {
 #define for_all_stack(x,y,var)  \
   for ((var) = unit_at((x), (y)); (var) != NULL;  (var) = (var)->nexthere)
 
-/* Iterate through all units in this cell including occs within occs within occs. */
+/* Iterate through all units in this cell including occs within occs
+   within occs. */
 
-/* This nifty little macro will climb the occupant : nexthere tree and follow all branches 
-four levels down to find all the occs within occs within occs within units in the stack. */ 
+/* This nifty little macro will climb the occupant : nexthere tree and
+   follow all branches four levels down to find all the occs within
+   occs within occs within units in the stack. */
 
 #define for_all_stack_with_occs(x,y,var)  \
   for ((var) = unit_at((x), (y)); \
@@ -457,117 +459,113 @@ extern int any_clouds;
 
 /* World-related functions. */
 
-extern void init_world PARAMS ((void));
-extern int set_world_circumference PARAMS ((int circum, int warn));
-extern int set_area_shape PARAMS ((int width, int height, int warn));
-extern int valid_area_shape PARAMS ((int width, int height, int warn));
-extern void check_area_shape PARAMS ((void));
-extern void calculate_world_globals PARAMS ((void));
-extern void count_terrain_subtypes PARAMS ((void));
-extern void final_init_world PARAMS ((void));
+extern void init_world(void);
+extern int set_world_circumference(int circum, int warn);
+extern int set_area_shape(int width, int height, int warn);
+extern int valid_area_shape(int width, int height, int warn);
+extern void check_area_shape(void);
+extern void calculate_world_globals(void);
+extern void count_terrain_subtypes(void);
+extern void final_init_world(void);
 
-extern void allocate_area_terrain PARAMS ((void));
-extern void allocate_area_aux_terrain PARAMS ((int t));
-extern void allocate_area_scratch PARAMS ((int n));
-extern void allocate_area_elevations PARAMS ((void));
-extern void allocate_area_temperatures PARAMS ((void));
-extern void allocate_area_people_sides PARAMS ((void));
-extern void allocate_area_control_sides PARAMS ((void));
-extern void allocate_area_material PARAMS ((int m));
-extern void allocate_area_clouds PARAMS ((void));
-extern void allocate_area_cloud_altitudes PARAMS ((void));
-extern void allocate_area_cloud_bottoms PARAMS ((void));
-extern void allocate_area_cloud_heights PARAMS ((void));
-extern void allocate_area_winds PARAMS ((void));
+extern void allocate_area_terrain(void);
+extern void allocate_area_aux_terrain(int t);
+extern void allocate_area_scratch(int n);
+extern void allocate_area_elevations(void);
+extern void allocate_area_temperatures(void);
+extern void allocate_area_people_sides(void);
+extern void allocate_area_control_sides(void);
+extern void allocate_area_material(int m);
+extern void allocate_area_clouds(void);
+extern void allocate_area_cloud_altitudes(void);
+extern void allocate_area_cloud_bottoms(void);
+extern void allocate_area_cloud_heights(void);
+extern void allocate_area_winds(void);
 
-extern int fn_terrain_at PARAMS ((int x, int y));
-extern int fn_aux_terrain_at PARAMS ((int x, int y));
-extern int fn_feature_at PARAMS ((int x, int y));
-extern int fn_elevation_at PARAMS ((int x, int y));
-extern int fn_people_side_at PARAMS ((int x, int y));
-extern int fn_control_side_at PARAMS ((int x, int y));
-extern int fn_material_at PARAMS ((int x, int y));
-extern int fn_temperature_at PARAMS ((int x, int y));
-extern int fn_raw_cloud_at PARAMS ((int x, int y));
-extern int fn_raw_cloud_bottom_at PARAMS ((int x, int y));
-extern int fn_raw_cloud_height_at PARAMS ((int x, int y));
-extern int fn_raw_wind_at PARAMS ((int x, int y));
-extern void allocate_area_users PARAMS ((void));
-extern int fn_user_at PARAMS ((int x, int y));
-extern void fn_set_user_at PARAMS ((int x, int y, int val));
-extern void fn_set_terrain_at PARAMS ((int x, int y, int val));
-extern void fn_set_aux_terrain_at PARAMS ((int x, int y, int val));
-extern void fn_set_people_side_at PARAMS ((int x, int y, int val));
-extern void fn_set_control_side_at PARAMS ((int x, int y, int val));
-extern void fn_set_raw_feature_at PARAMS ((int x, int y, int val));
-extern void fn_set_elevation_at PARAMS ((int x, int y, int val));
-extern void fn_set_material_at PARAMS ((int x, int y, int val));
-extern void fn_set_temperature_at PARAMS ((int x, int y, int val));
-extern void fn_set_raw_wind_at PARAMS ((int x, int y, int val));
-extern void fn_set_raw_cloud_at PARAMS ((int x, int y, int val));
-extern void fn_set_raw_cloud_bottom_at PARAMS ((int x, int y, int val));
-extern void fn_set_raw_cloud_height_at PARAMS ((int x, int y, int val));
+extern int fn_terrain_at(int x, int y);
+extern int fn_aux_terrain_at(int x, int y);
+extern int fn_feature_at(int x, int y);
+extern int fn_elevation_at(int x, int y);
+extern int fn_people_side_at(int x, int y);
+extern int fn_control_side_at(int x, int y);
+extern int fn_material_at(int x, int y);
+extern int fn_temperature_at(int x, int y);
+extern int fn_raw_cloud_at(int x, int y);
+extern int fn_raw_cloud_bottom_at(int x, int y);
+extern int fn_raw_cloud_height_at(int x, int y);
+extern int fn_raw_wind_at(int x, int y);
+extern void allocate_area_users(void);
+extern int fn_user_at(int x, int y);
+extern void fn_set_user_at(int x, int y, int val);
+extern void fn_set_terrain_at(int x, int y, int val);
+extern void fn_set_aux_terrain_at(int x, int y, int val);
+extern void fn_set_people_side_at(int x, int y, int val);
+extern void fn_set_control_side_at(int x, int y, int val);
+extern void fn_set_raw_feature_at(int x, int y, int val);
+extern void fn_set_elevation_at(int x, int y, int val);
+extern void fn_set_material_at(int x, int y, int val);
+extern void fn_set_temperature_at(int x, int y, int val);
+extern void fn_set_raw_wind_at(int x, int y, int val);
+extern void fn_set_raw_cloud_at(int x, int y, int val);
+extern void fn_set_raw_cloud_bottom_at(int x, int y, int val);
+extern void fn_set_raw_cloud_height_at(int x, int y, int val);
 
-extern void change_terrain_type PARAMS ((int x, int y, int t2));
+extern void change_terrain_type(int x, int y, int t2);
 
-extern int search_around PARAMS ((int x0, int y0, int maxdist,
-				 int (*pred)(int, int),
-				 int *rxp, int *ryp, int incr));
-extern int search_and_apply PARAMS ((int x0, int y0, int maxdist,
-				    int (*pred)(int, int),
-				    int *rxp, int *ryp, int incr,
-				    void (*fn)(int, int), int num));
-extern void apply_to_area PARAMS ((int x0, int y0, int dist,
-				  void (*fn)(int, int)));
-extern void apply_to_area_plus_edge PARAMS ((int x0, int y0, int dist,
-					    void (*fn)(int, int)));
-extern void apply_to_ring PARAMS ((int x0, int y0, int distmin, int distmax,
-				  void (*fn)(int, int)));
-extern void apply_to_hexagon PARAMS ((int x0, int y0, int w2, int h2,
-				     void (*fn)(int, int)));
-extern void apply_to_path PARAMS ((int fx, int fy, int tx, int ty,
-				  int (*dirtest)(int x, int y, int dir),
-				  int (*dirsort)(int x, int y, int *dirchoices, int numchoices),
-				  int (*fn)(int x, int y, int dir, int j, int numchoices),
-				  int shortest));
+extern int search_around(int x0, int y0, int maxdist, int (*pred)(int, int),
+			 int *rxp, int *ryp, int incr);
+extern int search_and_apply(int x0, int y0, int maxdist, int (*pred)(int, int),
+			    int *rxp, int *ryp, int incr,
+			    void (*fn)(int, int), int num);
+extern void apply_to_area(int x0, int y0, int dist, void (*fn)(int, int));
+extern void apply_to_area_plus_edge(int x0, int y0, int dist,
+				    void (*fn)(int, int));
+extern void apply_to_ring(int x0, int y0, int distmin, int distmax,
+			  void (*fn)(int, int));
+extern void apply_to_hexagon(int x0, int y0, int w2, int h2,
+			     void (*fn)(int, int));
+extern void apply_to_path(int fx, int fy, int tx, int ty,
+			  int (*dirtest)(int x, int y, int dir),
+			  int (*dirsort)(int x, int y, int *dirchoices,
+					 int numchoices),
+			  int (*fn)(int x, int y, int dir, int j,
+				    int numchoices),
+			  int shortest);
 #if 0
-int find_path PARAMS ((int fx, int fy, int tx, int ty,
-		      int (*chooser)(int, int, int, int, int *),
-		      int maxwps, Waypoint *waypoints, int *numwpsp));
+int find_path(int fx, int fy, int tx, int ty,
+	      int (*chooser)(int, int, int, int, int *),
+	      int maxwps, Waypoint *waypoints, int *numwpsp);
 #endif
-extern int search_straight_line PARAMS ((int x0, int y0, int x1, int y1,
-					 int (*pred)(int, int),
-					 int *rxp, int *ryp));
+extern int search_straight_line(int x0, int y0, int x1, int y1,
+				int (*pred)(int, int), int *rxp, int *ryp);
 
-extern void set_border_at PARAMS ((int x, int y, int dir, int t, int onoff));
-extern void set_connection_at PARAMS ((int x, int y, int dir, int t, int onoff));
-extern void patch_linear_terrain PARAMS ((int t));
+extern void set_border_at(int x, int y, int dir, int t, int onoff);
+extern void set_connection_at(int x, int y, int dir, int t, int onoff);
+extern void patch_linear_terrain(int t);
 
-extern void init_features PARAMS ((void));
-extern Feature *find_feature PARAMS ((int fid));
-extern Feature *feature_at PARAMS ((int x, int y));
-extern void compute_all_feature_centroids PARAMS ((void));
-extern void compute_feature_centroid PARAMS ((Feature *feature));
+extern void init_features(void);
+extern Feature *find_feature(int fid);
+extern Feature *feature_at(int x, int y);
+extern void compute_all_feature_centroids(void);
+extern void compute_feature_centroid(Feature *feature);
 
-extern int point_in_dir PARAMS ((int x, int y, int dir, int *xp, int *yp));
-extern int interior_point_in_dir PARAMS ((int x, int y, int dir,
-					  int *xp, int *yp));
-extern int point_in_dir_n PARAMS ((int x, int y, int dir, int n,
-				   int *xp, int *yp));
-extern int interior_point_in_dir_n PARAMS ((int x, int y, int dir, int n,
-					    int *xp, int *yp));
-extern int random_point PARAMS ((int *xp, int *yp));
-extern int random_edge_point PARAMS ((int *xp, int *yp));
-extern int random_point_near PARAMS ((int cx, int cy, int radius,
-				      int *xp, int *yp));
-extern int random_point_in_area PARAMS ((int cx, int cy, int rx, int ry,
-					 int *xp, int *yp));
-extern void terrain_subtype_warning PARAMS ((char *context, int t));
-extern int approx_dir PARAMS ((int dx, int dy));
-extern int hextant PARAMS ((int dx, int dy));
-extern int distance PARAMS ((int x1, int y1, int x2, int y2));
-extern int world_distance PARAMS ((int x1, int y1, int x2, int y2));
-extern int closest_dir PARAMS ((int x, int y));
+extern int point_in_dir(int x, int y, int dir, int *xp, int *yp);
+extern int interior_point_in_dir(int x, int y, int dir, int *xp, int *yp);
+extern int point_in_dir_n(int x, int y, int dir, int n, int *xp, int *yp);
+extern int interior_point_in_dir_n(int x, int y, int dir, int n,
+				   int *xp, int *yp);
+extern int random_point(int *xp, int *yp);
+extern int random_edge_point(int *xp, int *yp);
+extern int random_point_near(int cx, int cy, int radius, int *xp, int *yp);
+extern int random_point_in_area(int cx, int cy, int rx, int ry,
+				int *xp, int *yp);
+extern void terrain_subtype_warning(char *context, int t);
+extern int approx_dir(int dx, int dy);
+extern int hextant(int dx, int dy);
+extern int distance(int x1, int y1, int x2, int y2);
+extern int world_distance(int x1, int y1, int x2, int y2);
+extern int closest_dir(int x, int y);
 
-extern void xy_to_latlong PARAMS ((int x, int y, int xf, int yf, int *latp, int *lonp));
-extern int latlong_to_xy PARAMS ((int lat, int lon, int *xp, int *yp, int *xfp, int *yfp));
+extern void xy_to_latlong(int x, int y, int xf, int yf, int *latp, int *lonp);
+extern int latlong_to_xy(int lat, int lon, int *xp, int *yp,
+			 int *xfp, int *yfp);
