@@ -143,66 +143,53 @@ static int tmpcompress;
 /* Preparation and preallocation for writing. */
 
 void
-init_write()
+init_write(void)
 {
     spare_module = create_game_module("spare module");
     shortestbuf = xmalloc(BUFSIZE);
 }
 
 /* A saved game should include everything necessary to recreate a game
-   exactly.  It is important that this routine not attempt to use graphics,
-   since it may be called when graphics code fails, and that it not allocate
-   memory, since it may be called upon memory exhaustion.  Returns TRUE if
-   the save was successful. */
+   exactly.  It is important that this routine have the option to not
+   use graphics, since it may be called when graphics code fails, and
+   not to allocate memory, since it may be called upon memory
+   exhaustion.  Returns TRUE if the save was successful. */
 
 int
-write_entire_game_state(fname)
-char *fname;
+write_entire_game_state(char *fname)
 {
     Module *module;
     int rslt;
 
-    /* Note in the history that a copy was made. */
+    /* Record the attempt to save state.  Do it before actually saving,
+       so that it appears in the saved history. */
     if (!memory_exhausted && !debugging_state_sync)
       record_event(H_GAME_SAVED, ALLSIDES);
     /* No additional allocation should ever happen during saving,
        so complain if it does. */
     xmalloc_warnings = TRUE;
     module = spare_module;
-    /* Reset the module's contents, might have been used already. */
-    memset(module, 0, sizeof(Module));
+    copy_module(module, mainmodule);
     module->name = fname;
     module->filename = fname;
-    module->instructions = lispnil;
-    module->notes = lispnil;
-    module->designnotes = lispnil;
-    module->startlineno = 1;
-    module->endlineno = 1;
+    module->version = NULL;
+    module->variants = NULL;
+    /* We write all types etc, so suppress base module load attempts. */
+    module->basemodulename = NULL;
     module->compress_tables = TRUE;
     module->compress_layers = TRUE;
     module->def_all = TRUE;
-    /* Record information about the original main module, for use after
-       the game has been restored.  mainmodule should point to something,
-       but it doesn't actually have to. */
-    if (mainmodule != NULL) {
-	if (empty_string(mainmodule->origmodulename)) {
-	    /* If no original module, use the main module. */
-	    module->origmodulename = mainmodule->name;
-	    module->origvariants = mainmodule->variants;
-	    module->origversion = mainmodule->version;
-	} else {
-	    /* Copy original module info through to this one; thus original
-	       module info is "sticky", preserved across multiple saves. */
-	    module->origmodulename = mainmodule->origmodulename;
-	    module->origvariants = mainmodule->origvariants;
-	    module->origversion = mainmodule->origversion;
-	}
-    }
     rslt = write_game_module(module);
     xmalloc_warnings = FALSE;
     /* Record that the game's state is accurately saved away. */
-    if (rslt)
-      gamestatesafe = TRUE;
+    if (rslt) {
+	gamestatesafe = TRUE;
+	if (!memory_exhausted && !debugging_state_sync) {
+	    /* Report success to the users.  We can't use notify_event
+	       because we want to report the filename. */
+	    notify_all("Game was saved to \"%s\".", fname);
+	}
+    }
     return rslt;
 }
 
@@ -343,8 +330,7 @@ write_game_module(Module *module)
 }
 
 static void
-write_variants(varray)
-Variant *varray;
+write_variants(Variant *varray)
 {
     int i;
     Obj *rest;
@@ -377,7 +363,7 @@ Variant *varray;
 /* Write definitions of all the types. */
 
 static void
-write_types()
+write_types(void)
 {
     int u, m, t, i, ival;
     char *typename, *sval;
@@ -524,8 +510,7 @@ write_types()
 /* Write definitions of all the tables. */
 
 static void
-write_tables(compress)
-int compress;
+write_tables(int compress)
 {
     int tbl;
 
@@ -1380,10 +1365,10 @@ Module *module;
 
     newline_form();
     add_to_form(";");
-    add_num_to_form(numsides);
-    add_to_form("sides");
+    add_num_to_form(numtotsides);
+    add_to_form("sides including the independent 0 side.");
     newline_form();
-    Dprintf("Will try to write %d sides ...\n", numsides);
+    Dprintf("Will try to write %d sides ...\n", numtotsides);
     for_all_sides(side) {
 	start_form(key(K_SIDE));
 	add_num_to_form(side->id);
@@ -1399,6 +1384,9 @@ Module *module;
 	  write_side_view(side, module->compress_layers);
 	Dprintf("  Wrote side %s\n", side_desig(side));
     }
+
+#if 0		/* The independent side is now handled as side 0 above. */
+
     start_form(key(K_INDEPENDENT_UNITS));
     newline_form();
     write_side_properties(indepside);
@@ -1406,6 +1394,9 @@ Module *module;
     end_form();
     newline_form();
     Dprintf("  Wrote independent unit properties\n");
+
+#endif
+
     Dprintf("... Done writing sides\n");
 }
 
@@ -1446,7 +1437,7 @@ Side *side;
     write_num_prop(key(K_ADVANTAGE), side->advantage, 1, FALSE, TRUE);
     write_num_prop(key(K_ADVANTAGE_MIN), side->minadvantage, 1, FALSE, TRUE);
     write_num_prop(key(K_ADVANTAGE_MAX), side->maxadvantage, 1, FALSE, TRUE);
-    write_num_prop(key(K_CONTROLLED_BY), side_number(side->controlled_by), 0, FALSE, TRUE);
+    write_num_prop(key(K_CONTROLLED_BY), (side->controlled_by ? side_number(side->controlled_by) : 0), 0, FALSE, TRUE);
     write_num_prop(key(K_SELF_UNIT), (side->self_unit ? side->self_unit->id : 0), 0, FALSE, TRUE);
     write_num_prop(key(K_PLAYER), (side->player ? side->player->id : 0), 0, FALSE, TRUE);
     write_num_prop(key(K_DEFAULT_DOCTRINE),
@@ -1760,9 +1751,6 @@ write_side_view(side, compress)
 {
     int t, m;
 
-    /* View layers are not defined if see-all is in effect. */
-    if (all_see_all)
-      return;
     tmpside = side;
     tmpcompress = compress;
     if (side->terrview)
@@ -1797,16 +1785,18 @@ write_side_view(side, compress)
 	    }
 	}
     }
-    write_one_side_view_layer(K_UNIT_VIEW, fn_unit_view);
-    if (!debugging_state_sync)
-      write_one_side_view_layer(K_UNIT_VIEW_DATES, fn_unit_view_date);
+    if (side->unitview) {
+	write_one_side_view_layer(K_UNIT_VIEW, fn_unit_view);
+	if (!debugging_state_sync)
+	  write_one_side_view_layer(K_UNIT_VIEW_DATES, fn_unit_view_date);
+    }
     if (!g_see_weather_always()) {
-	if (any_temp_variation) {
+	if (side->tempview) {
 	    write_one_side_view_layer(K_TEMPERATURE_VIEW, fn_temp_view);
 	    write_one_side_view_layer(K_TEMPERATURE_VIEW_DATES,
 				      fn_temp_view_date);
 	}
-	if (any_clouds) {
+	if (side->cloudview) {
 	    write_one_side_view_layer(K_CLOUD_VIEW, fn_cloud_view);
 	    write_one_side_view_layer(K_CLOUD_BOTTOM_VIEW,
 				      fn_cloud_bottom_view);
@@ -1814,7 +1804,7 @@ write_side_view(side, compress)
 				      fn_cloud_height_view);
 	    write_one_side_view_layer(K_CLOUD_VIEW_DATES, fn_cloud_view_date);
 	}
-	if (any_wind_variation) {
+	if (side->windview) {
 	    write_one_side_view_layer(K_WIND_VIEW, fn_wind_view);
 	    write_one_side_view_layer(K_WIND_VIEW_DATES, fn_wind_view_date);
 	}
