@@ -28,7 +28,6 @@ extern void global_advance_dialog(Side *side, Unit *unit, int advance);
 extern void unit_plan_dialog(Unit *unit);
 extern int unit_build_dialog(Unit *unit);
 extern int has_advance_to_research(Side *side, int atype);
-extern CIconHandle mac_create_cicn(Image *img);
 
 static void copy_rect_from_gworld(WindowPtr win, Map *map, Rect cityrect, Rect itemrect);
 static void draw_city_statistics(WindowPtr win, Unit *unit);
@@ -740,12 +739,9 @@ draw_city_statistics(WindowPtr win, Unit *unit)
 		/* Get the best 16 x 16 unit image from family */
 		uimg = best_image(uimages[unit2->type], 16, 16);
 		macuimg = (MacImage *) uimg->hook;
-		/* This is necessary if using imf data instead of lib-mac. */
-		if (!macuimg->colricon) {
-    			macuimg->colricon = (Handle) mac_create_cicn(uimg);
-    			macuimg->cicn_inited = FALSE;
-			mac_init_cicn(uimg);
-		}
+		/* mac_init_cicn now always creates a colricon. */
+		if (!macuimg->colricon)
+		     mac_init_cicn(uimg);
 		/* Get bitmap & maskmap from cicn and set srcrect. */
 		cicnhandle = (CIconHandle) macuimg->colricon;
 		bm = (*(cicnhandle))->iconBMap;
