@@ -18,7 +18,6 @@ any later version.  See the file COPYING.  */
 
 /* --- FUNCTIONS PROTOTYPES -------------------------------------------------*/
 
-extern CIconHandle mac_create_cicn(Image *img);
 extern void mac_init_cicn(Image *img);
 static int append_image_names(MenuHandle menu);
 static int append_color_names(MenuHandle menu);
@@ -733,20 +732,14 @@ set_side_colors(int e)
 		/* Plot 5 sample icons (if available) */
 		for (i = 0; i <= 4; i++) {
 			/* Skip now if we ran out of unit types */			
-			if (i > numutypes - 1) continue;
+			if (i > numutypes - 1)
+			     continue;
 			/* Get the best unit image from family */
 			uimg = best_image(uimages[i], 32, 32);
 			macuimg = (MacImage *) uimg->hook;
-			/* Get the cicn if it exists */
-
-			/* This is necessary if using imf data instead of lib-mac. Why? */
-			/* (the unit cicns do exist when called by draw_unit_image). */
-			if (!macuimg->colricon) {
-	    			macuimg->colricon = (Handle) mac_create_cicn(uimg);
-	    			macuimg->cicn_inited = FALSE;
-				mac_init_cicn(uimg);
-			}
-			
+			/* mac_init_cicn now always creates colricon. */
+			if (!macuimg->colricon)
+			     mac_init_cicn(uimg);
 			cicnhandle = (CIconHandle) macuimg->colricon;
 			/* Get pixmap, bitmap & maskmap from cicn and set srcrect */
 			bm = (*(cicnhandle))->iconBMap;
@@ -1453,42 +1446,48 @@ int
 append_color_names(MenuHandle menu)
 {
 	int	num = 0, startlineno = 1, endlineno = 1;
+	LibraryPath *p;
 	Obj	*form;
 	FILE	*fp;
 
-    	make_pathname(xconq_libs->path, "colors.imf", "", spbuf);
-	fp = open_file(spbuf, "r");
-	if (fp == NULL) {
+	for_all_library_paths(p) {
+    		make_pathname(p->path, "colors.imf", "", spbuf);
+		fp = open_file(spbuf, "r");
+		if (fp != NULL) {
+			while ((form = read_form(fp, &startlineno, &endlineno)) != lispeof) {
+				if (append_imf_name(form, menu))
+				    ++num;
+			}
+			fclose(fp);
+			return TRUE;
+		}
+	}
 		run_warning("Could not find your colors.imf file");
 		return FALSE;		
 	}
-	while ((form = read_form(fp, &startlineno, &endlineno)) != lispeof) {
-		if (append_imf_name(form, menu))
-		    ++num;
-	}
-	fclose(fp);
-	return TRUE;
-}	
 
 int
 append_terrain_names(MenuHandle menu)
 {
 	int	num = 0, startlineno = 1, endlineno = 1;
+	LibraryPath *p;
 	Obj	*form;
 	FILE	*fp;
 
-    	make_pathname(xconq_libs->path, "terrain.imf", "", spbuf);
-	fp = open_file(spbuf, "r");
-	if (fp == NULL) {
+	for_all_library_paths(p) {
+    		make_pathname(p->path, "terrain.imf", "", spbuf);
+		fp = open_file(spbuf, "r");
+		if (fp != NULL) {
+			while ((form = read_form(fp, &startlineno, &endlineno)) != lispeof) {
+				if (append_imf_name(form, menu))
+				    ++num;
+			}
+			fclose(fp);
+			return TRUE;
+		}
+	}
 		run_warning("Could not find your terrain.imf file");
-		return 0;		
-	}
-	while ((form = read_form(fp, &startlineno, &endlineno)) != lispeof) {
-		if (append_imf_name(form, menu))
-		    ++num;
-	}
-	fclose(fp);
-	return num;
+	return FALSE;		
 }	
 
 int
