@@ -127,11 +127,6 @@ Side *dside = NULL;
 
 Handle spare;
 
-/* This is true if savable prefs etc have been saved since being changed. */
-/* (always true for now, nothing being remembered) */
-
-int interfacestatesafe = TRUE;
-
 /* This is true when a single click suffices to move a unit. */
 
 int defaultmoveonclick = TRUE;
@@ -574,7 +569,11 @@ event_loop()
 			run_local_ai(1, 20);
 			net_run_game(1);
 			maybe_select_next_unit();
+
+#if 0
 			run_local_ai(2, 20);
+#endif
+
 			/* If the game ended, force various changes in interaction. */
 			if (endofgame)
 			  set_end_of_game_interaction_modes();
@@ -1208,8 +1207,7 @@ maybe_select_next_unit()
 	    /* Scroll over to the current unit if appropriate. */
 	    if (map->curunit != NULL
 	    	&& in_play(map->curunit)
-			&& (map->curunit->act
-				&& map->curunit->act->acp > 0)  /* should be "above min"? */
+		&& has_acp_left(map->curunit)
 	    	&& (map->curunit->plan
 				&& !map->curunit->plan->asleep
 				&& !map->curunit->plan->reserve
@@ -1716,7 +1714,7 @@ update_side_display(Side *side, Side *side2, int rightnow)
 	GrafPtr oldport;
 	extern int gamenumsides;
 
-	if (active_display(side) && side2 != NULL) {
+	if (active_display(side) && side2 != indepside) {
 		GetPort(&oldport);
 		if (gamewin != nil && ((WindowPeek) gamewin)->visible) {
 			if (gamenumsides == numsides) {
@@ -1735,7 +1733,6 @@ update_side_display(Side *side, Side *side2, int rightnow)
 			/* (should be able to quit from here?) */
 			CautionAlert(aOutOfGame, nil); 
 			wasingame = FALSE;
-			dside->may_set_see_all = TRUE;
 		}
 	}
 }
@@ -1766,13 +1763,12 @@ update_turn_display(Side *side, int rightnow)
 		}
 		/* This routine might have been called because the game is over. */
 		if (endofgame && !told_outcome && side == dside) {
-		    side->may_set_see_all = TRUE;
 		    if (!side->see_all) {
-		    	side->see_all = TRUE;
 		    	/* Can't do update forcing here because modal dialogs will
 		    	   come up before windows actually get to update. */
 		    	for_all_maps(map) {
 					map->see_all = TRUE;
+					map->vp->show_all = TRUE;
 					draw_map(map);
 				}
 		    }
