@@ -336,14 +336,21 @@ any later version.  See the file COPYING.  */
 #define diVariantsWorldSeen 4
 #define diVariantsSeeAll 5
 #define diVariantsSequential 6
-#define diVariantsFirstCheckBox 7
+#define diVariantsPeople 7
+#define diVariantsEconomy 8
+#define diVariantsSupply 9
+#define diVariantsIndepsAI 10
+#define diVariantsIndepsBuild 11
+#define diVariantsIndepsResearch 12
+#define diVariantsIndepsTreasury 13
+#define diVariantsFirstCheckBox 14
 /* and next 6 also */
-#define diVariantsFirstSlider 14
+#define diVariantsFirstSlider 20
 /* and next 2 also */
-#define diVariantsWorldSize 17
-#define diVariantsRealTime 18
-#define diVariantsMoreVariants 19
-#define diVariantsHelp 20
+#define diVariantsWorldSize 23
+#define diVariantsRealTime 24
+#define diVariantsMoreVariants 25
+#define diVariantsHelp 26
 
 #define dProgress 132
 
