@@ -532,8 +532,6 @@ mac_interp_image_1(ImageFamily *imf, Image *img, Image *subimg, int subi, int fo
 	            && macimg->masksicn == nil
 	            && macimg->monoicon == nil
 	            && macimg->maskicon == nil))) {
-	    macimg->colricon = (Handle) mac_create_cicn(subimg);
-	    macimg->cicn_inited = FALSE;
 		mac_init_cicn(subimg);
 		colrdone = TRUE;
 	}
@@ -807,7 +805,14 @@ mac_init_cicn_1(Image *img)
 	MacImage *macimg;
 
 	macimg = (MacImage *) img->hook;
-	if (macimg->colricon != NULL && !macimg->cicn_inited) {
+	
+	/* First make sure we have a colricon! */
+	if (macimg->colricon == NULL) {
+		macimg->colricon = (Handle) mac_create_cicn(img);
+		macimg->cicn_inited = FALSE;
+	}
+	/* Then init the cicn if necessary. */
+	if (macimg->cicn_inited == FALSE) {
 		cicnhandle = (CIconHandle) macimg->colricon;
 
 		/* Hang 'em High! */
