@@ -15,7 +15,7 @@ extern char *connection_method_name;
 
 /* Limit on the number of check boxes and sliders in the variants dialog. */
 
-#define MAXCHECKBOXES 7
+#define MAXCHECKBOXES 6
 #define MAXSLIDERS 3
 
 #define toggle_checkbox(ih) \
@@ -93,6 +93,14 @@ int vary_world;
 int vary_sequential;
 int vary_real_time;
 
+int vary_people;
+int vary_economy;
+int vary_supply;
+int vary_indepside_ai;
+int vary_indepside_build;
+int vary_indepside_research;
+int vary_indepside_treasury;
+
 /* This is the dialog used to set the size and shape of the world. */
 
 DialogPtr world_shape_win = nil;
@@ -141,6 +149,14 @@ int new_seen;
 int new_seeall;
 int new_sequential;
 
+int new_people;
+int new_economy;
+int new_supply;
+int new_indepside_ai;
+int new_indepside_build;
+int new_indepside_research;
+int new_indepside_treasury;
+
 Obj *variants;
 
 UserItemUPP draw_variant_slider_proc;
@@ -159,7 +175,7 @@ int playerbaseline = 14;
 
 int selectedplayer = -1;
 
-#define selected_a_player() (between(0, selectedplayer, numsides - 1))
+#define selected_a_player() (between(1, selectedplayer, numsides))
 
 #define selected_player()  \
   (selected_a_player() ? assignments[selectedplayer].player : NULL)
@@ -740,6 +756,9 @@ start_new_game()
 		/* If the loaded game is not valid, we will get an alert somewhere in here,
 		   and possibly bomb out if the player chooses not to continue. */
 		check_game_validity();
+
+		/* This is where the unix code calls broadcast_game_module. */
+
 	}
 	return launch_game();
 }
@@ -843,6 +862,13 @@ variants_dialog()
 	set_variant_item(diVariantsWorldSeen, vary_world_seen, TRUE, new_seen);
 	set_variant_item(diVariantsSeeAll, vary_see_all, TRUE, new_seeall);
 	set_variant_item(diVariantsSequential, vary_sequential, TRUE, new_sequential);
+	set_variant_item(diVariantsPeople, vary_people, TRUE, new_people);
+	set_variant_item(diVariantsEconomy, vary_economy, TRUE, new_economy);
+	set_variant_item(diVariantsSupply, vary_supply, TRUE, new_supply);
+	set_variant_item(diVariantsIndepsAI, vary_indepside_ai, TRUE, new_indepside_ai);
+	set_variant_item(diVariantsIndepsBuild, vary_indepside_build, TRUE, new_indepside_build);
+	set_variant_item(diVariantsIndepsResearch, vary_indepside_research, TRUE, new_indepside_research);
+	set_variant_item(diVariantsIndepsTreasury, vary_indepside_treasury, TRUE, new_indepside_treasury);
 	set_variant_item(diVariantsWorldSize, vary_world, FALSE, 0);
 	set_variant_item(diVariantsRealTime, vary_real_time, FALSE, 0);
 	set_variant_item(diVariantsMoreVariants, /* more_variants */ FALSE, FALSE, 0);
@@ -878,6 +904,13 @@ variants_dialog()
 			case diVariantsWorldSeen:
 			case diVariantsSeeAll:
 			case diVariantsSequential:
+			case diVariantsPeople:
+			case diVariantsEconomy:
+			case diVariantsSupply:
+			case diVariantsIndepsAI:
+			case diVariantsIndepsBuild:
+			case diVariantsIndepsResearch:
+			case diVariantsIndepsTreasury:
 				/* Toggle check boxes. */
 				GetDItem(variants_win, ditem, &itemtype, &itemhandle, &itemrect);
 				toggle_checkbox(itemhandle);
@@ -934,6 +967,8 @@ interpret_variants()
 
 	any_variants = FALSE;
 	vary_world_seen = vary_see_all = vary_sequential = FALSE;
+	vary_people = vary_economy = vary_supply = FALSE;
+	vary_indepside_ai = vary_indepside_build = vary_indepside_research = vary_indepside_treasury = FALSE;
 	vary_world = vary_real_time = FALSE;
 	if (selected_game == NULL || selected_game->variants == NULL)
 	  return;
@@ -974,6 +1009,76 @@ interpret_variants()
 					}
 				}
 				break;
+			case K_PEOPLE:
+				vary_people = TRUE;
+				new_people = FALSE;
+				if (var->dflt != lispnil) {
+					vartmp = eval(var->dflt);
+					if (numberp(vartmp)) {
+						new_people= c_number(vartmp);
+					}
+				}
+				break;
+			case K_ECONOMY:
+				vary_economy = TRUE;
+				new_economy = FALSE;
+				if (var->dflt != lispnil) {
+					vartmp = eval(var->dflt);
+					if (numberp(vartmp)) {
+						new_economy = c_number(vartmp);
+					}
+				}
+				break;
+			case K_SUPPLY:
+				vary_supply = TRUE;
+				new_supply = FALSE;
+				if (var->dflt != lispnil) {
+					vartmp = eval(var->dflt);
+					if (numberp(vartmp)) {
+						new_supply = c_number(vartmp);
+					}
+				}
+				break;
+			case K_INDEPSIDE_HAS_AI:
+				vary_indepside_ai = TRUE;
+				new_indepside_ai = FALSE;
+				if (var->dflt != lispnil) {
+					vartmp = eval(var->dflt);
+					if (numberp(vartmp)) {
+						new_indepside_ai = c_number(vartmp);
+					}
+				}
+				break;
+			case K_INDEPSIDE_CAN_BUILD:
+				vary_indepside_build = TRUE;
+				new_indepside_build = FALSE;
+				if (var->dflt != lispnil) {
+					vartmp = eval(var->dflt);
+					if (numberp(vartmp)) {
+						new_indepside_build = c_number(vartmp);
+					}
+				}
+				break;
+			case K_INDEPSIDE_CAN_RESEARCH:
+				vary_indepside_research = TRUE;
+				new_indepside_research = FALSE;
+				if (var->dflt != lispnil) {
+					vartmp = eval(var->dflt);
+					if (numberp(vartmp)) {
+						new_indepside_research = c_number(vartmp);
+					}
+				}
+				break;
+			case K_INDEPSIDE_HAS_TREASURY:
+				vary_indepside_treasury = TRUE;
+				new_indepside_treasury = FALSE;
+				if (var->dflt != lispnil) {
+					vartmp = eval(var->dflt);
+					if (numberp(vartmp)) {
+						new_indepside_treasury = c_number(vartmp);
+					}
+				}
+				break;
 			case K_WORLD_SIZE:
 				/* If the area is already set up, it's too late. */
 				if (area.width > 0 || area.height > 0)
@@ -1067,6 +1172,34 @@ implement_variants()
 		GetDItem(variants_win, diVariantsSequential, &itemtype, &itemhandle, &itemrect);
 		push_key_int_binding(&variants, K_SEQUENTIAL, GetCtlValue((ControlHandle) itemhandle));
 	}
+	if (vary_people) {
+		GetDItem(variants_win, diVariantsPeople, &itemtype, &itemhandle, &itemrect);
+		push_key_int_binding(&variants, K_PEOPLE, GetCtlValue((ControlHandle) itemhandle));
+	}
+	if (vary_economy) {
+		GetDItem(variants_win, diVariantsEconomy, &itemtype, &itemhandle, &itemrect);
+		push_key_int_binding(&variants, K_ECONOMY, GetCtlValue((ControlHandle) itemhandle));
+	}
+	if (vary_supply) {
+		GetDItem(variants_win, diVariantsSupply, &itemtype, &itemhandle, &itemrect);
+		push_key_int_binding(&variants, K_SUPPLY, GetCtlValue((ControlHandle) itemhandle));
+	}
+	if (vary_indepside_ai) {
+		GetDItem(variants_win, diVariantsIndepsAI, &itemtype, &itemhandle, &itemrect);
+		push_key_int_binding(&variants, K_INDEPSIDE_HAS_AI, GetCtlValue((ControlHandle) itemhandle));
+	}
+	if (vary_indepside_build) {
+		GetDItem(variants_win, diVariantsIndepsBuild, &itemtype, &itemhandle, &itemrect);
+		push_key_int_binding(&variants, K_INDEPSIDE_CAN_BUILD, GetCtlValue((ControlHandle) itemhandle));
+	}
+	if (vary_indepside_research) {
+		GetDItem(variants_win, diVariantsIndepsResearch, &itemtype, &itemhandle, &itemrect);
+		push_key_int_binding(&variants, K_INDEPSIDE_CAN_RESEARCH, GetCtlValue((ControlHandle) itemhandle));
+	}
+	if (vary_indepside_treasury) {
+		GetDItem(variants_win, diVariantsIndepsTreasury, &itemtype, &itemhandle, &itemrect);
+		push_key_int_binding(&variants, K_INDEPSIDE_HAS_TREASURY, GetCtlValue((ControlHandle) itemhandle));
+	}
 	if (vary_world) {
 		/* It is critically important that users not be able to reshape already-alloced
 		   areas, but do let them know that their request had to be overridden. */
@@ -1603,10 +1736,10 @@ draw_player_setup_list(WindowPtr win, short ditem)
 	entryrect = itemrect;
 	entryrect.bottom = entryrect.top + playerh;
 	InsetRect(&entryrect, 1, 1);
-	for (i = 0; i < g_sides_max(); ++i) {
+	for (i = 1; i <= g_sides_max(); ++i) {
 		if (i >= numvisentries) {
 			/* Not visible, don't draw. */
-		} else if (i < numsides) {
+		} else if (i < numtotsides) {
 			PenNormal();
 			/* Clear this entry. */
 			tmprect = entryrect;
@@ -1730,7 +1863,7 @@ adjust_advantage(Player *player, Side *side, int amt)
 void
 select_player(int n)
 {
-	if ((!between(0, n, numsides-1))
+	if ((!between(1, n, numsides))
 	    || (assignments[n].side && !(assignments[n].side->ingame))) {
 	    n = -1;
 	}
@@ -1930,8 +2063,10 @@ hit_player_setup_dialog(int ditem, Point pt)
 			changedselected = TRUE;
 			break;
 		case diPlayerSetupAI:
-			/* Click between mplayer and not, for now */
-			if (tmpplayer->aitypename) {
+			/* Click between mplayer, iplayer and no AI. */
+			if (strcmp(tmpplayer->aitypename, "mplayer") == 0) {
+				tmpplayer->aitypename = "iplayer";
+			} else if (strcmp(tmpplayer->aitypename, "iplayer") == 0) {
 				tmpplayer->aitypename = NULL;
 			} else {
 				tmpplayer->aitypename = "mplayer";
@@ -1962,7 +2097,7 @@ hit_player_setup_dialog(int ditem, Point pt)
 			break;
 		case diPlayerSetupList:
 			GetDItem(playersetupwin, diPlayerSetupList, &itemtype, &itemhandle, &itemrect);
-			select_player((pt.v - itemrect.top) / playerh);
+			select_player((pt.v - itemrect.top) / playerh + 1);
 			if (tmpplayer != selected_player())
 			  changedselected = TRUE;
 			break;
@@ -2084,7 +2219,6 @@ open_game_from_name_and_volume(Str255 name, int vrefnum)
 	module = get_game_module(NULL);
 	p2c(name, modulename);
 	module->filename = copy_string(modulename);
-	module->hook = NULL;
 	/* This module is effectively the "selected game", whether or not
 	   it's loadable. */
 	selected_game = module;
@@ -2099,6 +2233,9 @@ open_game_from_name_and_volume(Str255 name, int vrefnum)
 	}
 	/* If the loaded module has bugs, we will get alerts here. */
 	check_game_validity();
+	
+	/* This is where the unix code calls broadcast_game_module. */
+	
 	/* We can now join up with the "new game" startup sequence. */
 	return launch_game();
 }
@@ -2123,7 +2260,6 @@ launch_game()
 	/* Get the emblems so they can be displayed in the player dialog. */
 	init_all_emblem_images();
 	init_emblem_cicns();
-
 	/* It is important that unit cicns are loaded after the emblems since functions
 	that reinit cicns assume that emblems always are located above the unit cicns. */
 	init_unit_images();
@@ -2132,6 +2268,8 @@ launch_game()
 	return player_setup_dialog();
 }
 
+/* Calling chain: launch_game -> player_setup_dialog -> launch_game_2. */
+
 void
 launch_game_2()
 {
