@@ -1584,7 +1584,7 @@ Map *map;
 	OffsetRect(&tmprect, 0, 11);
 	if (map->see_all) {
 		InvertRect(&tmprect);
-	} else if (!dside->may_set_see_all) {
+	} else if (!dside->may_set_show_all) {
 		gray_out_rect(&tmprect);
 	}
 	OffsetRect(&tmprect, 0, 11);
@@ -2140,7 +2140,10 @@ Unit *unit;
 	if (map->vp->draw_grid && map->vp->power == 5)
 	  --tmprect.bottom;
 	/* First, draw an outer frame, for contrast. */
-	if (map->autoselect && unit->act && unit->act->initacp > 0 && unit->act->acp > 0) {
+	if (map->autoselect
+		&& unit->act
+		&& unit->act->initacp > 0
+		&& has_acp_left(unit)) {
 		PenPat(&animation_patterns[animation_pattern_state]);
 	} else {
 		PenPat(QDPat(white));
@@ -2154,7 +2157,7 @@ Unit *unit;
 	/* Black is for units that can still act, dark gray for actors, gray if the
 	   unit can't do anything. */
 	PenPat((unit->act && unit->act->initacp > 0) ?
-			((unit->act->acp > 0) ? QDPat(black) : QDPat(dkGray)) : QDPat(gray));
+			(has_acp_left(unit) ? QDPat(black) : QDPat(dkGray)) : QDPat(gray));
 	/* Wide border if awake, narrow if asleep or napping. */
 	size = ((unit->plan && (unit->plan->asleep || unit->plan->reserve)) ? 1 : 2);
 	PenSize(size, size);
@@ -2215,7 +2218,7 @@ Unit *unit;
 	if (map->vp->draw_grid && map->vp->power == 5)
 	  --tmprect.bottom;
 	/* First, draw an outer white frame, for contrast. */
-	if (unit->act && unit->act->initacp > 0 && unit->act->acp > 0) {
+	if (unit->act && unit->act->initacp > 0 && has_acp_left(unit)) {
 		PenPat(&animation_patterns[animation_pattern_state]);
 	} else {
 		PenPat(QDPat(white));
@@ -2243,7 +2246,7 @@ Unit *unit;
 	InsetRect(&tmprect, 1, 1);
 	/* Black is for units that can still act, dark gray for actors, gray if the unit can't do anything. */
 	PenPat((unit->act && unit->act->initacp > 0) ?
-			((unit->act->acp > 0) ? QDPat(black) : QDPat(dkGray)) : QDPat(gray));
+			(has_acp_left(unit) ? QDPat(black) : QDPat(dkGray)) : QDPat(gray));
 	/* Wide border if awake, narrow if asleep or napping. */
 	size = ((unit->plan && (unit->plan->asleep || unit->plan->reserve)) ? 1 : 2);
 	PenSize(size, size);
