@@ -782,11 +782,11 @@ do_menu_command(long which)
 			}
 			break;
 		case 	mColors:
-			if (menuitem <= numsides + 1) {
+			if (menuitem <= numtotsides) {
 				set_side_colors(menuitem - 1);
 			/* - 2 because of Independents and separator line */
-			} else if (menuitem <= numsides + FEATURES + 2) {
-				 set_feature_color(menuitem - numsides - 3);
+			} else if (menuitem <= numtotsides + FEATURES + 2) {
+				 set_feature_color(menuitem - numtotsides - 2);
 			} else {
 			/* Pass terrain by sanitized name instead of number */
 				GetItem(GetMenu(mColors), menuitem, daname);
@@ -1255,7 +1255,7 @@ quit_the_game()
 	if (endofgame) {
 		/* Game is already over, nothing to save, just leave. */
 		exit_macconq();
-	} else if (!gamestatesafe || !interfacestatesafe) {
+	} else if (!gamestatesafe) {
 		switch (CautionAlert(aQuitGame, nil)) {
 			case aiQuitGameOK:
 				if (all_others_willing_to_save(dside)) {
@@ -2506,7 +2506,7 @@ enable_commands_for_unit(MenuHandle menu, MenuHandle menu2, Unit *unit)
 			for_all_sides_plus_indep(side2) {
 				sn = (side2 == indepside ? numsides + 1 : side2->id);
 				if (unit_allowed_on_side(unit, side2)
-					&& !(unit->side == side2 || (unit->side == NULL && side2 == indepside))) {
+					&& unit->side != side2) {
 					EnableItem(menu3, sn);
 				} else {
 					DisableItem(menu3, sn);
