@@ -290,8 +290,9 @@ do_mouse_down_map_control_panel(Map *map, int h, int v, int mods)
 				toggle_map_ai(map);
 				break;
 			case 6:
-				if (dside->may_set_see_all) {
+				if (dside->may_set_show_all) {
 					map->see_all = !map->see_all;
+					map->vp->show_all = map->see_all;
 					force_map_update(map);
 				}
 				break;
@@ -1316,7 +1317,7 @@ select_another(Map *map, Unit *(*fn)(Side *side, Unit *unit))
 		scroll_to_unit(map, thisunit);
 		/* (should not be done this way, but how else?) */
 		if (map->autoselect
-			&& (thisunit->act && thisunit->act->acp > 0)
+			&& has_acp_left(thisunit)
 			&& (thisunit->plan && !thisunit->plan->asleep && !thisunit->plan->reserve && !thisunit->plan->delayed)) {
 			map->curunit = thisunit;
 		}
