@@ -242,7 +242,7 @@ draw_row(Map *map, int x0, int y, int len, int clearit)
 			draw_region(map, x, y);
 		}
 		/* If debugging, draw coverage on top of everything else. */
-		if (DebugG && !all_see_all && map->vp->hw >= 16) {
+		if (DebugG && !dside->see_all && map->vp->hw >= 16) {
 			UNWRAP_SX(map, sx, 
 				draw_coverage(sx, sy, pwr, cover(dside, xw, y), alt_cover(dside, xw, y)));
 		}
@@ -414,7 +414,7 @@ draw_row(Map *map, int x0, int y, int len, int clearit)
 		  draw_region(map, x, y);
 	}
 	/* If debugging, draw coverage on top of everything else. */
-	if (DebugG && !all_see_all && map->vp->hw >= 16) {
+	if (DebugG && !dside->see_all && map->vp->hw >= 16) {
 		for (x = x0; x < x0 + len; ++x) {
 			xw = wrapx(x);	
 			xform(map, x, y, &sx, &sy);		/* No need to test for in_area here. */
@@ -888,7 +888,7 @@ draw_borders(Map *map, int x, int y, int b)
 	}
 	if (bitmask != 0) {
 		tmpdrawlighting = map->vp->draw_lighting;
-		tmpdrawcoverage = (!all_see_all && map->vp->draw_cover);
+		tmpdrawcoverage = (!dside->see_all && map->vp->draw_cover);
 		over = cell_overlay(xw, y);
 		xform(map, x, y, &sx, &sy);
 		/* (should compute and pass in overlay) */
@@ -915,7 +915,7 @@ draw_connections(Map *map, int x, int y, int c)
 	}
 	if (bitmask != 0) {
 		tmpdrawlighting = map->vp->draw_lighting;
-		tmpdrawcoverage = (!all_see_all && map->vp->draw_cover);
+		tmpdrawcoverage = (!dside->see_all && map->vp->draw_cover);
 		over = cell_overlay(xw, y);
 		xform(map, x, y, &sx, &sy);
 		/* (should compute and pass in overlay) */
@@ -1173,7 +1173,7 @@ draw_units(Map *map, int x, int y)
 				sx += (map->vp->hw - sw) / 2;  sy += (map->vp->hh - sw) / 2;
 				if (unit->occupant != NULL
 					&& sw >= 8
-	    			&& (unit->side == dside || all_see_all || u_see_occupants(unit->type))) {
+	    			&& (unit->side == dside || dside->see_all || u_see_occupants(unit->type))) {
 					/* Draw a "grouping box", in white, but with no occs drawn. */
 					SetRect(&tmprect, sx, sy, sx + sw, sy + sh);
 					s = side_number(unit->side);
@@ -1254,13 +1254,7 @@ draw_unit_and_occs(Map *map, Unit *unit, int sx, int sy, int sw, int sh)
 	   will also be visible. */
 	if (unit->transport && unit->side == unit->transport->side)
 	  emblem = FALSE;
-	if (unit->occupant != NULL
-		&& sw > 8
-	    && (dside->see_all
-		    || unit->side == dside
-		    || u_see_occupants(unit->type)
-		    || side_owns_occupant(dside, unit))) {
-
+	if (sw > 8 && occupants_visible(dside, map->vp, unit)) {
 		/* Draw a sort of "grouping box", in white. */
 		/* Make box 1 pixel smaller to avoid leakage of its lower left corner into the grid. */
 		SetRect(&tmprect, sx, sy, sx + sw - 1, sy + sh - 1);
