@@ -13,7 +13,7 @@ extern int update_total_hist_lines(Side *side);
 extern int build_hist_contents(Side *side, int n, HistEvent **histcontents, int numvis);
 
 #define unit_doctrine(unit)  \
-  ((unit->side ? unit->side : indepside)->udoctrine[unit->type])
+  (unit->side->udoctrine[unit->type])
 
 #include "kpublic.h"
 #include "macconq.h"
@@ -258,7 +258,7 @@ draw_game()
 	/* Draw a solid separating line between date info and side list. */
 	MoveTo(0, gametophgt);
 	Line(gamewinw, 0);
-	for_all_sides(side2)
+	for_all_real_sides(side2)
 	  draw_game_side(side2);
 	SetPort(oldport);
 }
@@ -323,7 +323,7 @@ draw_game_clocks()
 	}
 	/* Draw per-side clocks if any limits defined. */
 	if (g_rt_per_side() > 0) {
-		for_all_sides(side2) {
+		for_all_real_sides(side2) {
 			if (side2->ingame) {
 				s2 = side_number(side2);
 				sy = gametophgt + (s2 - 1) * gamesidehgt + gamesideclockoffset;
@@ -1898,7 +1898,7 @@ create_notice_window()
 		noticewin = GetNewWindow(wFloatResize, NULL, NULL);
 	}
 	SetWTitle(noticewin, "\pNotices");
-	SizeWindow(noticewin, 300, 120, true);
+	SizeWindow(noticewin, 400, 120, true);
 	SetPort(noticewin);
 	TextFont(small_font_id);
 	TextSize(small_font_size);
@@ -2171,8 +2171,6 @@ zoom_notice(int part)
 void
 show_scores_window()
 {
-    extern char *get_scores(Side *side);
-
 	if (scoreswin == nil) {
 		create_scores_window();
 		append_scores(get_scores(dside));
