@@ -31,16 +31,14 @@ static void aux_others(Side *side, Map *map, int cancel);
 static void aux_remove_terrain(Side *side, Map *map, int cancel);
 static void aux_remove_terrain_2(Side *side, Map *map, int cancel);
 static void do_remove_terrain_2(Side *side, Map *map, int t);
+static void aux_quit_resign(Side *side, Map *map, int cancel);
+static void aux_quit_resign_to(Side *side, Map *map, int cancel);
+static void aux_quit_exit(Side *side, Map *map, int cancel);
+static void aux_quit_save(Side *side, Map *map, int cancel);
+static void aux_quit_leave(Side *side, Map *map, int cancel);
 static void aux_resign(Side *side, Map *map, int cancel);
-static void aux_resign_2(Side *side, Map *map, int cancel);
-static void aux_leave_game(Side *side, Map *map, int cancel);
-static void aux_kill_game(Side *side, Map *map, int cancel);
-static void aux_resign_b(Side *side, Map *map, int cancel);
-static void aux_save_2(Side *side, Map *map, int cancel);
-static void aux_save_1(Side *side, Map *map, int cancel);
-static void aux_save_1_1(Side *side, Map *map, int cancel);
+static void aux_resign_to(Side *side, Map *map, int cancel);
 static void aux_set_formation(Side *side, Map *map, int cancel);
-static void save_the_game(Side *side);
 
 static void aux_design(Side *side, Map *map, int cancel);
 
@@ -50,7 +48,13 @@ static void aux_design(Side *side, Map *map, int cancel);
   if (!in_play((map)->curunit) || (map)->curunit_id != (map)->curunit->id) {  \
     (map)->curunit = NULL;  \
     (map)->curunit_id = 0;  \
-    cmd_error((dside), "No current unit to command!");  \
+    cmd_error(dside, "No current unit to command!");  \
+    return;  \
+  }
+
+#define DURING_GAME_ONLY()  \
+  if (endofgame) {  \
+    cmd_error(dside, "Cannot do after game is over!");  \
     return;  \
   }
 
@@ -65,6 +69,7 @@ do_add_terrain(Side *side)
     int u, t, numtypes, tfirst = NONTTYPE, possibles[MAXTTYPES];
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     u = unit->type;
     numtypes = 0;
@@ -89,10 +94,7 @@ do_add_terrain(Side *side)
 }
 
 static void
-aux_add_terrain(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_add_terrain(Side *side, Map *map, int cancel)
 {
     int t;
 
@@ -129,10 +131,7 @@ int t;
 }
 
 static void
-aux_add_terrain_2(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_add_terrain_2(Side *side, Map *map, int cancel)
 {
     int x, y, dir;
     Unit *unit;
@@ -175,16 +174,14 @@ do_attack(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
     
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     map->argunitid = unit->id;
     ask_position(side, map, "Attack where?", aux_attack);
 }
 
 static void
-aux_attack(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_attack(Side *side, Map *map, int cancel)
 {
     int x, y;
     Unit *unit, *unit2;
@@ -218,6 +215,7 @@ do_auto(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
     
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     if (unit->plan) {
 	net_set_unit_ai_control(side, unit, !unit->plan->aicontrol, FALSE);
@@ -233,6 +231,7 @@ do_build(Side *side)
     int u, u2, possibles[MAXUTYPES], numtypes, ufirst = NONUTYPE;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     u = unit->type;
     if (!can_build(unit)) {
@@ -282,10 +281,7 @@ do_build(Side *side)
 }
 
 static void
-aux_build(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_build(Side *side, Map *map, int cancel)
 {
     int u2;
     Unit *unit;
@@ -321,10 +317,7 @@ int cancel;
 }
 
 static void
-aux_build_2(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_build_2(Side *side, Map *map, int cancel)
 {
     int x, y;
     Unit *unit;
@@ -373,6 +366,7 @@ do_clear_plan(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     net_set_unit_plan_type(side, unit, PLAN_NONE);
 }
@@ -385,6 +379,8 @@ do_collect(Side *side)
     int mtocollect;
     char *arg, *rest;
 
+    DURING_GAME_ONLY();
+    REQUIRE_UNIT(map);
     mtocollect = NONMTYPE;
     if (nummtypes == 0) {
 	cmd_error(side, "No materials to collect");
@@ -417,6 +413,8 @@ do_delay(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
+    REQUIRE_UNIT(map);
     if (unit != NULL) {
 	if (unit->plan)
 	  net_delay_unit(unit, TRUE);
@@ -437,6 +435,7 @@ do_detach(Side *side)
     int rslt;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     if (!completed(unit)) {
 	cmd_error(side, "%s is incomplete; cannot detach",
@@ -458,6 +457,7 @@ do_detonate(Side *side)
     int rslt;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     rslt = check_detonate_action(unit, unit, unit->x, unit->y, unit->z);
     if (valid(rslt)) {
@@ -472,6 +472,7 @@ do_dir(Side *side)
 {
     Map *map = side->ui->curmap;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     aux_move_dir(side, map, map->curunit);
 }
@@ -481,6 +482,7 @@ do_dir_multiple(Side *side)
 {
     Map *map = side->ui->curmap;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     map->prefixarg = 9999;
     aux_move_dir(side, map, map->curunit);
@@ -525,6 +527,7 @@ do_disband(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     net_disband_unit(side, unit);
 }
@@ -535,6 +538,7 @@ do_disembark(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit, *transport;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     transport = unit->transport;
     if (transport == NULL) {
@@ -573,10 +577,7 @@ do_distance(Side *side)
 }
 
 static void
-aux_distance(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_distance(Side *side, Map *map, int cancel)
 {
     int x, y, dist;
     Unit *unit;
@@ -608,6 +609,7 @@ do_embark(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit, *transport;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     transport = embarkation_unit(unit);
     if (transport != NULL) {
@@ -654,6 +656,7 @@ do_fire(Side *side)
     Unit *other;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
 
     if (map->inpch == '\0') {
@@ -697,10 +700,7 @@ do_fire(Side *side)
 }
 
 static void
-aux_fire_at(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_fire_at(Side *side, Map *map, int cancel)
 {
     int x, y;
     Unit *unit, *other;
@@ -736,6 +736,7 @@ do_fire_into(Side *side)
     int x = map->inpx, y = map->inpy, rslt;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
 
     if (inside_area(x, y)) {
@@ -765,6 +766,7 @@ do_follow_action(Side *side)
 {
     Map *map = side->ui->curmap;
     
+    DURING_GAME_ONLY();
     map->follow_action = !map->follow_action;
     if (map->follow_action) {
 	notify(side, "Following the action on map.");
@@ -782,11 +784,12 @@ do_give(Side *side)
     Unit *unit = map->curunit, *mainunit = NULL;
     char buf[BUFSIZE];
 
+    DURING_GAME_ONLY();
+    REQUIRE_UNIT(map);
     if (nummtypes == 0) {
 	cmd_error(side, "No materials in this game!");
 	return;
     }
-    REQUIRE_UNIT(map);
     u = unit->type;
     mainunit = unit->transport;
     if (mainunit == NULL) {
@@ -827,6 +830,7 @@ do_give_unit(Side *side)
     Map *map = side->ui->curmap;
     Side *side2;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     if (between(0, map->prefixarg, numsides)) {
 	side2 = side_n(map->prefixarg);
@@ -890,6 +894,7 @@ do_idle(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     if (map->prefixarg < 0)
       map->prefixarg = 9999;
@@ -946,12 +951,12 @@ do_map(Side *side)
 	vp->isodir = right_dir(vp->isodir);
 	printf("Looking %s\n", dirnames[vp->isodir]);
 	redraw_map(map);
-    } else if (strcmp(cmdargstr, "seeall") == 0) {
-	if (!side->may_set_see_all) {
-	    cmd_error(side, "May not set to see all!");
+    } else if (strcmp(cmdargstr, "show_all") == 0) {
+	if (!side->may_set_show_all) {
+	    cmd_error(side, "You are not permitted to see everything!");
 	    return;
 	}
-	map->see_all = !map->see_all;
+	set_show_all(map, !map->show_all);
 	redraw_map(map);
     } else if (strcmp(cmdargstr, "unit-colorize") == 0) {
 	map->colorize_units = !map->colorize_units;
@@ -986,10 +991,7 @@ do_message(Side *side)
 }
 
 static void
-aux_message(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_message(Side *side, Map *map, int cancel)
 {
     char *msg;
     SideMask sidemask;
@@ -1024,16 +1026,14 @@ do_move_to(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     map->argunitid = unit->id;
     ask_position(side, map, "Move to where?", aux_move_to);
 }
 
 static void
-aux_move_to(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_move_to(Side *side, Map *map, int cancel)
 {
     int x, y;
     Unit *unit;
@@ -1043,7 +1043,7 @@ int cancel;
     if (grok_position(side, map, &x, &y, NULL)) {
 	unit = find_unit(map->argunitid);
 #ifdef DESIGNERS
-	if (side->designer) {
+	if (is_designer(side)) {
 	    net_designer_teleport(unit, x, y, NULL);
 	} else
 #endif /* DESIGNERS */
@@ -1066,6 +1066,7 @@ do_name(Side *side)
     char tmpbuf[BUFSIZE];
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     map->argunitid = unit->id;
     sprintf(tmpbuf, "New name for %s:", unit_handle(side, unit));
@@ -1073,10 +1074,7 @@ do_name(Side *side)
 }
 
 static void
-aux_name(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_name(Side *side, Map *map, int cancel)
 {
     char *name;
     Unit *unit;
@@ -1101,7 +1099,7 @@ int cancel;
 void
 do_new_map(Side *side)
 {
-    cmd_error(side, "Not implemented.");
+    create_map();
 }
 
 /* This is a command to examine all occupants and suboccupants, in an
@@ -1117,6 +1115,7 @@ do_occupant(Side *side)
     Unit *nextocc;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     nextocc = find_next_occupant(unit);
     if (nextocc != unit) {
@@ -1139,10 +1138,7 @@ do_other(Side *side)
 }
 
 static void
-aux_others(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_others(Side *side, Map *map, int cancel)
 {
     char *cmd;
 
@@ -1184,20 +1180,22 @@ do_quit(Side *side)
     Map *map = side->ui->curmap;
 
     if (side->ingame) {
-	if (all_others_willing_to_quit(side)) {
-	    /* Everbody else is willing to get out, but confirm us anyway. */
+	if (gamestatesafe
+	    || all_others_willing_to_quit(side)
+	    || is_designer(side)) {
+	    /* For the above cases, there is no obstacle to quitting,
+	       but confirm anyway, in case there was a slip of the
+	       keyboard. */
 	    ask_bool(side, map, "Do you really want to quit?", FALSE,
-		     aux_kill_game);
+		     aux_quit_exit);
+	} else if (keeping_score()) {
+	    ask_bool(side, map,
+		     "Do you want to save the game before quitting?",
+		     FALSE, aux_quit_save);
 	} else {
-	    if (1 /* outcome needs resolution */) {
-		/* if not everybody willing to draw, then we have to resign */
-		ask_bool(side, map, "Do you really want to give up?", FALSE,
-			 aux_resign);
-	    } else {
-		/* Everybody is just participating. */
-		ask_bool(side, map, "Do you want to leave this game?", FALSE,
-			 aux_leave_game);
-	    }
+	    /* Everybody is just participating. */
+	    ask_bool(side, map, "Do you want to leave this game?", FALSE,
+		     aux_quit_leave);
 	}
     } else {
 	/* We're already out of the game, not really anything to confirm. */
@@ -1207,11 +1205,38 @@ do_quit(Side *side)
     }
 }
 
+/* (Have an extra confirm for designers not to lose unsaved work?) */
+
 static void
-aux_resign(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_quit_exit(Side *side, Map *map, int cancel)
+{
+    if (cancel)
+      return;
+    if (grok_bool(side, map)) {
+	exit_xconq(side);
+    } else {
+	/* Nothing to do if we said not to exit. */
+    }
+}
+
+static void
+aux_quit_save(Side *side, Map *map, int cancel)
+{
+    if (cancel)
+      return;
+    if (grok_bool(side, map)) {
+	do_save(side);
+	/* Don't exit unless we know we saved successfully. */
+	if (gamestatesafe)
+	  exit_xconq(side);
+    } else {
+	ask_bool(side, map, "You cannot quit without resigning; give up now?",
+		 FALSE, aux_quit_resign);
+    }
+}
+
+static void
+aux_quit_resign(Side *side, Map *map, int cancel)
 {
     if (cancel)
       return;
@@ -1219,18 +1244,16 @@ int cancel;
 	if (numsides > 2) {
 	    /* (should suggest resigning to a trusted side) */
 	    ask_side(side, map, "To whom do you wish to surrender?", NULL,
-		     aux_resign_2);
+		     aux_quit_resign_to);
 	} else {
 	    net_resign_game(side, NULL);
+	    /* (should exit now, or go through std keep-going dialog?) */
 	}
     }
 }
 
 static void
-aux_resign_2(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_quit_resign_to(Side *side, Map *map, int cancel)
 {
     Side *side2;
 
@@ -1240,41 +1263,22 @@ int cancel;
 	net_resign_game(side, side2);
     } else {
 	/* Iterate until grok_side is happy. */
-	map->modalhandler = aux_resign_2;
+	map->modalhandler = aux_quit_resign_to;
     }
 }
 
 /* Do the act of leaving the game. */
 
 static void
-aux_leave_game(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_quit_leave(Side *side, Map *map, int cancel)
 {
     if (cancel)
       return;
     if (grok_bool(side, map)) {
+	/* (should probably structure differently, but how?) */
 	remove_side_from_game(side);
-	/* Now go back and see what happens if we're not in the game. */ 
-	do_quit(side);
-    } else {
-	/* nothing to do if we said not to exit */
-    }
-}
-
-/* (Have an extra confirm for designers not to lose unsaved work?) */
-
-static void
-aux_kill_game(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
-{
-    if (cancel)
-      return;
-    if (grok_bool(side, map)) {
 	exit_xconq(side);
+    } else {
 	/* Nothing to do if we said not to exit. */
     }
 }
@@ -1284,7 +1288,7 @@ int cancel;
 void
 do_recenter(Side *side)
 {
-    Map *map = dside->ui->curmap;
+    Map *map = side->ui->curmap;
 
     REQUIRE_UNIT(map);
     recenter(map, map->curunit->x, map->curunit->y);
@@ -1309,6 +1313,7 @@ do_remove_terrain(Side *side)
     int u, t, numtypes, tfirst = NONTTYPE, possibles[MAXTTYPES];
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     u = unit->type;
     numtypes = 0;
@@ -1334,10 +1339,7 @@ do_remove_terrain(Side *side)
 }
 
 static void
-aux_remove_terrain(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_remove_terrain(Side *side, Map *map, int cancel)
 {
     int t;
 
@@ -1371,10 +1373,7 @@ int t;
 }
 
 static void
-aux_remove_terrain_2(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_remove_terrain_2(Side *side, Map *map, int cancel)
 {
     int x, y, dir;
     Unit *unit;
@@ -1417,6 +1416,7 @@ do_repair(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit, *other;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     unit = map->curunit;
     if (valid(check_repair_action(unit, unit, unit))) {
@@ -1437,6 +1437,7 @@ do_reserve(Side *side)
 {
     Map *map = side->ui->curmap;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     net_set_unit_reserve(side, map->curunit, TRUE, TRUE /* is this right??? */);
 }
@@ -1454,22 +1455,38 @@ do_resign(Side *side)
 	beep(side);
     } else {
 	ask_bool(side, map, "Are you sure you want to resign now?",
-		 FALSE, aux_resign_b);
+		 FALSE, aux_resign);
     }
 }
 
-/* This is semi-redundant with aux_resign. */
-
 static void
-aux_resign_b(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_resign(Side *side, Map *map, int cancel)
 {
     if (cancel)
       return;
     if (grok_bool(side, map)) {
-	net_resign_game(side, NULL);
+	if (numsides > 2) {
+	    /* (should suggest resigning to a trusted side) */
+	    ask_side(side, map, "To whom do you wish to surrender?", NULL,
+		     aux_resign_to);
+	} else {
+	    net_resign_game(side, NULL);
+	}
+    }
+}
+
+static void
+aux_resign_to(Side *side, Map *map, int cancel)
+{
+    Side *side2;
+
+    if (cancel)
+      return;
+    if (grok_side(side, map, &side2)) {
+	net_resign_game(side, side2);
+    } else {
+	/* Iterate until grok_side is happy. */
+	map->modalhandler = aux_resign_to;
     }
 }
 
@@ -1483,6 +1500,7 @@ do_return(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     /* (should doublecheck range and error out if no chance) */
     if (in_play(unit)) {
@@ -1490,147 +1508,28 @@ do_return(Side *side)
     }
 }
 
-/* Stuff game state into a file.  By default, it goes into the current
-   directory.  If designing a game, we can specify exactly which parts
-   of the game state are to be written. */
-
-/* The command proper just sets up different modal handlers, depending on
-   whether we're building (and therefore saving a scenario/fragment), or
-   saving as much game state as possible, for resumption later. */
+/* Stuff game state into a file. */
 
 void
 do_save(Side *side)
 {
-    Map *map = side->ui->curmap;
-
-#ifdef DESIGNERS
-    if (side->designer) {
-	eval_tcl_cmd("popup_designer_save");
-	return;
-    }
-#endif /* DESIGNERS */
-    if (0 /* (should be "savemustquit") */) {
-	ask_bool(side, map, "You really want to save?", FALSE, aux_save_2);
-    } else {
-	save_the_game(side);
-    }
+    eval_tcl_cmd("popup_game_save {%s} {%s}",
+		 saved_game_filename(), (cmdargstr ? cmdargstr : "0"));
 }
 
-/* Make a module appropriate to a save file, write the file, and leave. */
-
-static void
-aux_save_2(Side *side, Map *map, int cancel)
-{
-    if (cancel)
-      return;
-    if (grok_bool(side, map)) {
-	save_the_game(side);
-    }
-}
-
-static void
-save_the_game(Side *side)
-{
-    char *savename = saved_game_filename();
-
-    /* (should use name in save dialog) */
-    notify_all("Game will be saved to \"%s\" ...", savename);
-    if (write_entire_game_state(savename)) {
-	/* this should be conditional? */
-	exit_xconq(NULL);
-    } else {
-	cmd_error(side, "Can't open file \"%s\"!", savename);
-    }
-}
-
-#ifdef DESIGNERS
-
-static Module *tmpmodule;
-
-static void
-aux_save_1_1(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
-{
-    char *filenamespec;
-
-    if (cancel)
-      return;
-    if (grok_string(side, map, &filenamespec)) {
-	tmpmodule->filename = filenamespec;
-	notify(side, "File will be written to \"%s\" ...",
-	       tmpmodule->filename);
-	if (write_game_module(tmpmodule)) {
-	    notify(side, "Done writing to \"%s\".", tmpmodule->filename);
-	} else {
-	    cmd_error(side, "Can't open file \"%s\"!", tmpmodule->filename);
-	}
-    } else {
-	map->modalhandler = aux_save_1_1;
-    }
-}
-
-static void
-aux_save_1(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
-{
-    int save;
-    char *contentspec;
-
-    if (cancel)
-      return;
-    if (grok_string(side, map, &contentspec)) {
-	tmpmodule = create_game_module("game-data");
-	/* Use the spec string to decide which pieces to save. */
-	save = FALSE;
-	if (strcmp(contentspec, "all") == 0) {
-	    tmpmodule->def_all = TRUE;
-	    tmpmodule->compress_layers = TRUE;
-	    save = TRUE;
-	} else if (strcmp(contentspec, "world") == 0) {
-	    tmpmodule->def_world = TRUE;
-	    tmpmodule->def_areas = TRUE;
-	    tmpmodule->def_area_terrain = TRUE;
-	    tmpmodule->def_area_misc = TRUE;
-	    tmpmodule->def_area_weather = TRUE;
-	    tmpmodule->def_area_material = TRUE;
-	    save = TRUE;
-	} else {
-	    cmd_error(side, "Don't understand content spec \"%s\"!",
-		      contentspec);
-	    return;
-	}
-	if (save) {
-	    ask_string(side, map, "Save data to where?", "game-data.g",
-		       aux_save_1_1);
-	} else {
-	    notify(side, "Nothing requested to be saved.");
-	}
-    } else {
-	map->modalhandler = aux_save_1;
-    }
-}
-
-#endif /* DESIGNERS */
-
 void
 do_set_formation(Side *side)
 {
     Map *map = side->ui->curmap;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     map->argunitid = map->curunit->id;
     ask_position(side, map, "Form up on who?", aux_set_formation);
 }
 
 static void
-aux_set_formation(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_set_formation(Side *side, Map *map, int cancel)
 {
     int x, y;
     Unit *unit, *leader;
@@ -1665,7 +1564,7 @@ int cancel;
 void
 do_set_view_angle(Side *side)
 {
-    Map *map = dside->ui->curmap;
+    Map *map = side->ui->curmap;
     VP *vp = widget_vp(map);
 
     vp->isometric = !vp->isometric;
@@ -1686,6 +1585,7 @@ do_sleep(Side *side)
     Map *map = side->ui->curmap;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     net_set_unit_asleep(side, unit, TRUE, TRUE /* is this right??? */);
 }
@@ -1695,6 +1595,7 @@ do_standing_orders(Side *side)
 {
     int rslt;
 
+    DURING_GAME_ONLY();
     if (cmdargstr) {
 	rslt = parse_standing_order(side, cmdargstr);
 	if (rslt < 0)
@@ -1708,19 +1609,19 @@ do_survey(Side *side)
 {
     Map *map = side->ui->curmap;
 
-    if (map->mode == survey_mode) {
+    if (map->mode == survey_mode && !endofgame) {
 	map->mode = move_mode;
-	if (side->designer)
+	if (is_designer(side))
 	  map->mode = survey_mode; /* should be last design mode */
     } else if (map->mode == move_mode) {
 	map->mode = survey_mode;
-    } else if (side->designer) {
+    } else if (is_designer(side)) {
 	map->mode = survey_mode;
     } else {
 	beep(side);
 	return;
     }
-    if (!side->designer) {
+    if (!is_designer(side)) {
 	map->autoselect = !map->autoselect;
 	map->move_on_click = !map->move_on_click;
     }
@@ -1728,9 +1629,9 @@ do_survey(Side *side)
     if (!map->autoselect && map->curunit != NULL)
       update_at_unit(map, map->curunit);
     if (map->mode == move_mode)
-      eval_tcl_cmd("update_mode move");
+      eval_tcl_cmd("update_mode %d move", map->number);
     else if (map->mode == survey_mode)
-      eval_tcl_cmd("update_mode survey");
+      eval_tcl_cmd("update_mode %d survey", map->number);
 }
 
 /* Take supplies from transport. */
@@ -1742,11 +1643,12 @@ do_take(Side *side)
     short m, amts[MAXMTYPES], rslts[MAXMTYPES], needed;
     Unit *unit = map->curunit;
 
+    DURING_GAME_ONLY();
+    REQUIRE_UNIT(map);
     if (nummtypes == 0) {
 	cmd_error(side, "No materials in this game!");
 	return;
     }
-    REQUIRE_UNIT(map);
     for_all_material_types(m) {
 	amts[m] = map->prefixarg;
     }
@@ -1797,6 +1699,7 @@ do_wake_all(Side *side)
 {
     Map *map = side->ui->curmap;
 
+    DURING_GAME_ONLY();
     REQUIRE_UNIT(map);
     /* Do the curunit explicitly, might only be an occupant. */
     if (in_play(map->curunit)) {
@@ -1827,13 +1730,17 @@ do_world_map(Side *side)
 void
 do_zoom_in(Side *side)
 {
-    eval_tcl_cmd("zoom_in_out 1");
+    Map *map = side->ui->curmap;
+
+    eval_tcl_cmd("zoom_in_out %d 1", map->number);
 }
 
 void
 do_zoom_out(Side *side)
 {
-    eval_tcl_cmd("zoom_in_out -1");
+    Map *map = side->ui->curmap;
+
+    eval_tcl_cmd("zoom_in_out %d -1", map->number);
 }
 
 #ifdef DESIGNERS
@@ -1844,7 +1751,7 @@ do_design(Side *side)
     Map *map = side->ui->curmap;
     Map *map2;
 
-    if (!side->designer) {
+    if (!is_designer(side)) {
 	if (!designed_on) {
 	    ask_bool(side, map, "Do you really want to start designing?",
 		     FALSE, aux_design);
@@ -1853,18 +1760,17 @@ do_design(Side *side)
 	}
     } else {
 	net_become_nondesigner(side);
+	eval_tcl_cmd("update_show_all_info %d", dside->may_set_show_all);
 	for_all_maps(map2) {
-	    map2->see_all = (all_see_all || dside->may_set_see_all);
+	    set_show_all(map2, side->show_all);
+	    redraw_map(map);
 	}
 	eval_tcl_cmd("dismiss_design_palette");
     }
 }
 
 static void
-aux_design(side, map, cancel)
-Side *side;
-Map *map;
-int cancel;
+aux_design(Side *side, Map *map, int cancel)
 {
     if (cancel)
       return;
@@ -1881,12 +1787,14 @@ really_do_design(Side *side)
     Map *map;
 
     net_become_designer(side);
+    eval_tcl_cmd("update_show_all_info %d", dside->may_set_show_all);
     for_all_maps(map) {
-	map->see_all = (all_see_all || dside->may_set_see_all);
+	set_show_all(map, side->show_all);
+	redraw_map(map);
 	map->autoselect = FALSE;
 	map->mode = survey_mode;
+	eval_tcl_cmd("update_mode %d survey", map->number);
     }
-    eval_tcl_cmd("update_mode survey");
     eval_tcl_cmd("popup_design_palette");
 }
 
