@@ -104,6 +104,7 @@ typedef struct a_ui {
     XColor *diffcolor;		/* unusual/distinct color (usually maroon) */
     XColor *badcolor;		/* color for non-OKness (usually red) */
     XColor *warncolor;		/* color for warnings (usually yellow) */
+    XColor *goodcolor;
     XColor *grid_color;
     XColor *unseen_color;
     XColor *contour_color;
@@ -213,15 +214,15 @@ typedef struct a_ui {
 
     int numscheduled;
     struct a_movie movies[10];
-    short told_outcome;
     struct a_map *curmap;
 } UI;
 
 typedef struct a_map {
+    int number;
     enum mapmode mode;
     int autoselect;
     int move_on_click;
-    int see_all;
+    int show_all;
     int terrain_images;
     int terrain_patterns;
     int colorize_units;
@@ -250,6 +251,8 @@ typedef struct a_map {
     char answer[BUFSIZE];	/* string being typed in */
     int tmpint;
 
+    int lastrawx, lastrawy;
+
     short anim_state;
 
     char *widget;
@@ -293,7 +296,6 @@ extern void draw_blast(Map *map, Unit *unit, int blasttype);
 extern void set_tool_cursor(Side *side, Map *map);
 
 extern void initial_ui_init(void);
-extern void ui_init(void);
 extern void init_display(void);
 extern void init_redraws(void);
 extern void ui_mainloop(void);
@@ -325,3 +327,5 @@ extern void ask_side(Side *side, Map *map, char *prompt, Side *dfltside,
 extern int grok_side(Side *side, Map *map, Side **side2p);
 
 extern void exit_xconq(Side *side);
+
+extern void set_show_all(Map *map, int value);
