@@ -382,7 +382,9 @@ static int try_images = 1;
 
 static int use_images;
 
+#ifdef UNIX
 static XImage *test_image;
+#endif
 static int imdepth;
 
 static char *ximbuf;
@@ -503,7 +505,6 @@ tk_make_color_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 	}
     }
     if (use_images) {
-	Visual *vis;
 #if 0 /* this is probably the right approach to use someday */
 	int numvisuals;
 	XVisualInfo visinfo, *visinfoptr;
@@ -514,6 +515,7 @@ tk_make_color_pixmap(Tk_Window rootwin, ImageFamily *imf, Image *img)
 				    &visinfo, &numvisuals);
 #endif
 #ifdef UNIX
+	Visual *vis;
 	vis = Tk_Visual(rootwin);
 	xim = XCreateImage(dpy, vis, imdepth, ZPixmap, 0, ximbuf,
 			   img->w, img->h, 32, 0);
@@ -722,6 +724,52 @@ blacken_masked_area(ImageFamily *imf, Image *img)
 	    break;
 	}
     }
+    if (black < 0
+	&& (1 << img->pixelsize) >= img->numcolors
+	&& img->pixelsize < 8) {
+	char *newdata, *nrp;
+	int newpsize, nrmask, nri;
+
+	newpsize = img->pixelsize * 2;
+	/* Don't need to mess with palette because it already has an
+	   additional spot allocated, and we only need the one. */
+	rmask = (1 << img->pixelsize) - 1;
+	ri = 8 - img->pixelsize;
+	rp = img->rawcolrdata;
+	newdata = xmalloc(img->h * computed_rowbytes(img->w, newpsize));
+	nrmask = (1 << newpsize) - 1;
+	nri = 8 - newpsize;
+	nrp = newdata;
+	for (r = 0; r < img->h; r++) {
+	  for (c = 0; c < img->w; c++) {
+	    rc = ((int) (*rp >> ri)) & rmask;
+	    /* OR the color data into its new location. */
+	    *nrp |= (char) (rc << nri);
+	    if (ri) {
+		ri -= img->pixelsize;
+	    } else {
+		ri = 8 - img->pixelsize;
+		++rp;
+	    }
+	    if (nri) {
+		nri -= newpsize;
+	    } else {
+		nri = 8 - newpsize;
+		++nrp;
+	    }
+	  }
+	  if ((img->pixelsize * img->w) % 8) {
+	    ri = 8 - img->pixelsize;
+	    ++rp;
+	  }
+	  if ((newpsize * img->w) % 8) {
+	    nri = 8 - newpsize;
+	    ++nrp;
+	  }
+	}
+	img->pixelsize = newpsize;
+	img->rawcolrdata = newdata;
+    }
     /* If a spare color is available, put black there. */
     if (black < 0 && (1 << img->pixelsize) > img->numcolors) {
 	black = img->numcolors;
