@@ -154,16 +154,21 @@ int min_h_for_unit_image = 16;
 #endif /* DESIGNERS */
 
 void
-init_ui(side)
-Side *side;
+init_ui(Side *side)
 {
     if (side_wants_display(side)) {
-        side->ui = (UI *) xmalloc(sizeof(UI));
-	Dprintf("One UI is %d bytes.\n", sizeof(UI));
-	get_preferences();
-    } else {
-	side->ui = NULL;
+	if (dside == NULL) {
+	    dside = side;
+	    dside->ui = (UI *) xmalloc(sizeof(UI));
+	    Dprintf("One UI is %d bytes.\n", sizeof(UI));
+	    get_preferences();
+	    return;
+	} else {
+	    init_warning("Only one display allowed, cannot open for side %d",
+			 side_number(side));
+	}
     }
+    side->ui = NULL;
 }
 
 /* Open display, create all the windows we'll need, do misc setup
@@ -227,6 +232,8 @@ init_display(void)
     init_bitmaps();
     init_cursors();
     update_view_controls_info();
+    eval_tcl_cmd("update_show_all_info %d", dside->may_set_show_all);
+    eval_tcl_cmd("set designer %d", is_designer(dside));
 
     /* Compute the position of each unit type in the list of unit types. */
     {
@@ -257,7 +264,7 @@ init_display(void)
 #ifdef DESIGNERS
     /* If this side is already a designer (perhaps via command-line option)
        popup the design controls now. */
-    if (dside->designer)
+    if (is_designer(dside))
       really_do_design(dside);
 #endif /* DESIGNERS */
 
@@ -281,6 +288,7 @@ set_colors(void)
     dside->ui->graycolor = dside->ui->whitecolor;
     dside->ui->badcolor = dside->ui->whitecolor;
     dside->ui->warncolor = dside->ui->whitecolor;
+    dside->ui->goodcolor = dside->ui->whitecolor;
     dside->ui->grid_color = dside->ui->fgcolor;
     dside->ui->unseen_color = dside->ui->fgcolor;
     dside->ui->contour_color = dside->ui->fgcolor;
@@ -331,6 +339,8 @@ set_optional_colors(void)
 	  dside->ui->badcolor = color;
 	if ((color = request_color("yellow")) != NULL)
 	  dside->ui->warncolor = color;
+	if ((color = request_color("green")) != NULL)
+	  dside->ui->goodcolor = color;
     }
 }
 
@@ -724,6 +734,8 @@ init_bitmaps(void)
 		    cursclouds_bits, cursclouds_width, cursclouds_height);
     Tk_DefineBitmap(interp, Tk_GetUid("paint_winds"),
 		    curswinds_bits, curswinds_width, curswinds_height);
+    Tk_DefineBitmap(interp, Tk_GetUid("paint_view"),
+		    cursview_bits, cursview_width, cursview_height);
 #endif
 }
 
@@ -961,9 +973,8 @@ tk_describe_image(Side *side, Image *img)
 void
 update_view_controls_info(void)
 {
-    eval_tcl_cmd("update_view_controls_info %d %d %d %d %d %d %d %d %d",
-		 all_see_all,
-		 dside->may_set_see_all,
+    eval_tcl_cmd("update_view_controls_info %d %d %d %d %d %d %d %d",
+		 dside->see_all,
 		 people_sides_defined(),
 		 control_sides_defined(),
 		 elevations_defined(),
@@ -984,7 +995,7 @@ update_action_controls_info(Map *map)
 
     unit = map->curunit;
     strcpy(flagsbuf, "{");
-    if (in_play(unit)) {
+    if (!beforestart && !endofgame && in_play(unit)) {
 	if (u_acp(unit->type) > 0)
 	  canact = TRUE;
 	if (unit->plan)
