@@ -1,5 +1,5 @@
 /* Imf sample list code for the tcl/tk interface to Xconq.
-   Copyright (C) 1998 Stanley T. Shebs.
+   Copyright (C) 1998, 1999 Stanley T. Shebs.
 
 Xconq is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -128,7 +128,7 @@ static Tk_ConfigSpec config_specs[] = {
     {TK_CONFIG_INT, "-showcolor", "showColor", "ShowColor",
 	"1", Tk_Offset(Imfsample, show_color), 0},
     {TK_CONFIG_INT, "-shownames", "showNames", "ShowNames",
-	"1", Tk_Offset(Imfsample, show_names), 0},
+	"0", Tk_Offset(Imfsample, show_names), 0},
     {TK_CONFIG_INT, "-showmasks", "showMasks", "ShowMasks",
 	"1", Tk_Offset(Imfsample, show_masks), 0},
     {TK_CONFIG_INT, "-showsolid", "showSolid", "ShowSolid",
@@ -149,17 +149,22 @@ static void imfsample_display(ClientData cldata);
 static void imfsample_event_proc(ClientData cldata, XEvent *eventPtr);
 static int imfsample_widget_cmd(ClientData cldata, Tcl_Interp *interp,
 				int argc, char **argv);
+static void imfsample_add_imf(Imfsample *imfsample, char *imfname);
+static void imfsample_replace_imf(Imfsample *imfsample, char *imfname);
+static void imfsample_replace_emblem(Imfsample *imfsample, char *imfname);
+static void imfsample_remove_imf(Imfsample *imfsample, char *imfname);
+static void draw_one_main_image(Imfsample *imfsample, Drawable d, GC gc,
+				ImageFamily *imf,
+				int sx, int sy, int sw, int sh);
+static void draw_one_image(Imfsample *imfsample, Drawable d, GC gc,
+			   Image *img, int sx, int sy, int sw, int sh);
 
 /* The command to create an image sample window. */
 
 int
-imfsample_cmd(cldata, interp, argc, argv)
-ClientData cldata;
-Tcl_Interp *interp;
-int argc;
-char **argv;
+imfsample_cmd(ClientData cldata, Tcl_Interp *interp, int argc, char **argv)
 {
-    Tk_Window main = (Tk_Window) cldata;
+    Tk_Window mainw = (Tk_Window) cldata;
     Imfsample *imfsample;
     Tk_Window tkwin;
 
@@ -169,7 +174,7 @@ char **argv;
 	return TCL_ERROR;
     }
 
-    tkwin = Tk_CreateWindowFromPath(interp, main, argv[1], (char *) NULL);
+    tkwin = Tk_CreateWindowFromPath(interp, mainw, argv[1], (char *) NULL);
     if (tkwin == NULL)
       return TCL_ERROR;
 
@@ -279,13 +284,17 @@ char **argv;
 	       && (length >= 2)) {
 	if (strcmp(argv[2], "imf") == 0) {
 	    imfsample_replace_imf(imfsample, argv[3]);
+	} else if (strcmp(argv[2], "emblem") == 0) {
+	    imfsample_replace_emblem(imfsample, argv[3]);
 	}
     } else if ((c == 'r') && (strncmp(argv[1], "remove", length) == 0)
 	       && (length >= 2)) {
 	if (strcmp(argv[2], "imf") == 0) {
 	    imfsample_remove_imf(imfsample, argv[3]);
+	} else if (strcmp(argv[2], "emblem") == 0) {
+	    imfsample->numimages = 1;
 	} else if (strcmp(argv[2], "all") == 0) {
-	    imfsample_remove_imf(imfsample, argv[3]);
+	    imfsample->numimages = 0;
 	}
     } else if ((c == 's') && (strncmp(argv[1], "select", length) == 0)
 	       && (length >= 2)) {
@@ -346,9 +355,8 @@ error:
     return TCL_ERROR;
 }
 
-imfsample_add_imf(imfsample, imfname)
-Imfsample *imfsample;
-char *imfname;
+static void
+imfsample_add_imf(Imfsample *imfsample, char *imfname)
 {
     int i;
     ImageFamily *imf = NULL;
@@ -360,7 +368,7 @@ char *imfname;
 	}
 	return;
     }
-    imf = hack_find_imf(imfname);
+    imf = tk_find_imf(imfname);
     if (imf == NULL) {
 	fprintf(stderr, "Missing imf %s\n", imfname);
 	return;
@@ -368,18 +376,16 @@ char *imfname;
     imfsample->imf_list[imfsample->numimages++] = imf;
 }
 
-imfsample_replace_imf(imfsample, imfname)
-     Imfsample *imfsample;
-     char *imfname;
+static void
+imfsample_replace_imf(Imfsample *imfsample, char *imfname)
 {
-    int i;
     ImageFamily *imf = NULL;
 
     if (imfsample->numimages == 0) {
 	imfsample_add_imf(imfsample, imfname);
 	return;
     }
-    imf = hack_find_imf(imfname);
+    imf = tk_find_imf(imfname);
     if (imf == NULL) {
 	fprintf(stderr, "Missing imf %s\n", imfname);
 	return;
@@ -387,21 +393,33 @@ imfsample_replace_imf(imfsample, imfname)
     imfsample->imf_list[0] = imf;
 }
 
-imfsample_remove_imf(imfsample, imfname)
-     Imfsample *imfsample;
-     char *imfname;
+static void
+imfsample_replace_emblem(Imfsample *imfsample, char *imfname)
+{
+    ImageFamily *imf = NULL;
+
+    if (imfsample->numimages == 1) {
+	imfsample_add_imf(imfsample, imfname);
+	return;
+    }
+    imf = tk_find_imf(imfname);
+    if (imf == NULL) {
+	fprintf(stderr, "Missing imf %s\n", imfname);
+	return;
+    }
+    imfsample->imf_list[1] = imf;
+}
+
+static void
+imfsample_remove_imf(Imfsample *imfsample, char *imfname)
 {
     /* (should look for specific imf) */
     imfsample->numimages = 0;
 }
 
 static int
-imfsample_configure(interp, imfsample, argc, argv, flags)
-Tcl_Interp *interp;
-Imfsample *imfsample;
-int argc;
-char **argv;
-int flags;
+imfsample_configure(Tcl_Interp *interp, Imfsample *imfsample,
+		    int argc, char **argv, int flags)
 {
     /* Interpret the configuration arguments according to the specs. */
     if (Tk_ConfigureWidget(interp, imfsample->tkwin, config_specs,
@@ -487,7 +505,7 @@ static void
 imfsample_display(ClientData cldata)
 {
     char *str;
-    int rows, row, col, namex, namey, i, n, sx, sy;
+    int row, col, namex, namey, n, sx, sy;
     Imfsample *imfsample = (Imfsample *) cldata;
     Display *dpy = imfsample->display;
     Tk_Window tkwin = imfsample->tkwin;
@@ -516,8 +534,11 @@ imfsample_display(ClientData cldata)
     /* Collect GC and font for subsequent work. */
     gc = imfsample->gc;
     XSetClipMask(dpy, gc, None);
-    if (imfsample->show_names)
-      tkfont = Tk_GetFont(interp, tkwin, "system");
+    if (imfsample->show_names) {
+      tkfont = Tk_GetFont(interp, tkwin, "-size 10");
+      XSetFont(imfsample->display, gc, Tk_FontId(tkfont));
+    }
+
 
     /* Redraw the widget's background/border. */
     if (imfsample->with_terrain >= 0) {
@@ -595,7 +616,7 @@ imfsample_display(ClientData cldata)
 	      break;
 	    sx = col * imfsample->eltw;
 	    sy = (row - imfsample->firstvisrow) * imfsample->elth;
-	    draw_one_image(imfsample, d, gc, imfsample->imf_list[n],
+	    draw_one_main_image(imfsample, d, gc, imfsample->imf_list[n],
 			   sx + imfsample->pad, sy + imfsample->pad,
 			   imfsample->iwidth, imfsample->iheight);
 	    if (imfsample->show_names) {
@@ -645,169 +666,124 @@ imfsample_destroy(char *ptr)
     ckfree((char *) imfsample);
 }
 
-/* Draw a single image at a given location. */
+/* Draw a single image plus optional emblem at a given location. */
 
-int
-draw_one_image(imfsample, d, gc, imf, sx, sy, sw, sh)
-Imfsample *imfsample;
-Drawable d;
-GC gc;
-ImageFamily *imf;
-int sx, sy;
+static void
+draw_one_main_image(Imfsample *imfsample, Drawable d, GC gc, ImageFamily *imf,
+		    int sx, int sy, int sw, int sh)
 {
-    int sx2, sy2;
-    Image *uimg;
-    TkImage *tkimg;
-    Tk_Window tkwin = imfsample->tkwin;
-    Display *dpy = Tk_Display(tkwin);
-    XColor *imagecolor = black_color;
-    XColor *maskcolor = white_color;
+    ImageFamily *eimf;
+    Image *img, *eimg;
+    int ex, ey, ew, eh;
 
-    uimg = best_image(imf, sw, sh);
-    if (uimg == NULL)
+    img = best_image(imf, sw, sh);
+    if (img == NULL)
       return;
-    if (!uimg->istile) {
-	/* Offset the image to draw in the middle of its area,
-	   whether larger or smaller than the given area. */
-	sx2 = sx + (sw - uimg->w) / 2;  sy2 = sy + (sh - uimg->h) / 2;
-	/* Only change the size of the rectangle being drawn if it's
-	   smaller than what was passed in. */
-	if (uimg->w < sw) {
-	    sx = sx2;
-	    sw = uimg->w;
-	}
-	if (uimg->h < sh) {
-	    sy = sy2;
-	    sh = uimg->h;
-	}
-    }
-    tkimg = (TkImage *) uimg->hook;
-    if (tkimg == NULL)
-      return;
-    XSetClipMask(dpy, gc, None);
-    XSetClipOrigin(dpy, gc, sx2, sy2);
-    XSetFillStyle(dpy, gc, FillSolid);
-    if (tkimg->colr != None && imfsample->show_color) {
-	if (uimg->istile) {
-	    XSetFillStyle(dpy, gc, FillTiled);
-	    XSetTile(dpy, gc, tkimg->colr);
-	    XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
-	} else {
-	    if (tkimg->mask != None && imfsample->show_masks) {
-		/* Use the image's mask to do clipped drawing. */
-		XSetClipMask(dpy, gc, tkimg->mask);
-	    }
-	    /* Draw the color image. */
-	    XCopyArea(dpy, tkimg->colr, d, gc, 0, 0, sw, sh, sx, sy);
-	}
-    } else if (tkimg->solid != NULL && imfsample->show_color) {
-	XSetForeground(dpy, gc, tkimg->solid->pixel);
-	XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
-    } else if (tkimg->mono != None || tkimg->mask != None) {
-	/* Set the color we're going to use for the mask; use the
-	   imagecolor if we'll be using the mask as the only image. */
-	XSetForeground(dpy, gc,
-		       (tkimg->mono == None ? imagecolor : maskcolor)->pixel);
-	/* Set the clip mask to be explicit mask or unit's image. */
-	if (tkimg->mask && imfsample->show_masks)
-	  XSetClipMask(dpy, gc, tkimg->mask);
-	else
-	  XSetClipMask(dpy, gc, tkimg->mono);
-	/* Draw the mask. */
-	XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
-	/* Draw the image proper. */
-	if (tkimg->mono != None) {
-	    XSetForeground(dpy, gc, imagecolor->pixel);
-	    XSetClipMask(dpy, gc, tkimg->mono);
-	    XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
-	}
-    }
+    draw_one_image(imfsample, d, gc, img, sx, sy, sw, sh);
     if (imfsample->with_emblem >= 0) {
-	ImageFamily *eimf = imfsample->imf_list[imfsample->with_emblem];
-	Image *eimg;
-	int ex, ey, ew, eh;
-
-	if (emblem_position(uimg, NULL, NULL, sw, sh, &ex, &ey, &ew, &eh)) {
-	    draw_one_emblem(imfsample, d, gc, eimf, sx + ex, sy + ey, ew, eh);
+	eimf = imfsample->imf_list[imfsample->with_emblem];
+	if (eimf != NULL
+	    && emblem_position(img, eimf->name, eimf, sw, sh,
+			       &ex, &ey, &ew, &eh)) {
+	  eimg = best_image(eimf, ew, eh);
+	  if (eimg == NULL)
+	    return;
+	  draw_one_image(imfsample, d, gc, eimg, sx + ex, sy + ey, ew, eh);
 	}
     }
 }
 
 /* Draw a single image at a given location. */
 
-int
-draw_one_emblem(imfsample, d, gc, imf, sx, sy, sw, sh)
-Imfsample *imfsample;
-Drawable d;
-GC gc;
-ImageFamily *imf;
-int sx, sy;
+static void
+draw_one_image(Imfsample *imfsample, Drawable d, GC gc, Image *img,
+	       int sx, int sy, int sw, int sh)
 {
     int sx2, sy2;
-    Image *eimg;
     TkImage *tkimg;
     Tk_Window tkwin = imfsample->tkwin;
     Display *dpy = Tk_Display(tkwin);
     XColor *imagecolor = black_color;
     XColor *maskcolor = white_color;
 
-    eimg = best_image(imf, sw, sh);
-    if (eimg == NULL)
-      return;
-    if (!eimg->istile) {
+    if (!img->istile) {
 	/* Offset the image to draw in the middle of its area,
 	   whether larger or smaller than the given area. */
-	sx2 = sx + (sw - eimg->w) / 2;  sy2 = sy + (sh - eimg->h) / 2;
+	sx2 = sx + (sw - img->w) / 2;  sy2 = sy + (sh - img->h) / 2;
 	/* Only change the size of the rectangle being drawn if it's
 	   smaller than what was passed in. */
-	if (eimg->w < sw) {
+	if (img->w < sw) {
 	    sx = sx2;
-	    sw = eimg->w;
+	    sw = img->w;
 	}
-	if (eimg->h < sh) {
+	if (img->h < sh) {
 	    sy = sy2;
-	    sh = eimg->h;
+	    sh = img->h;
 	}
     }
-    tkimg = (TkImage *) eimg->hook;
+    tkimg = (TkImage *) img->hook;
     if (tkimg == NULL)
       return;
     XSetClipMask(dpy, gc, None);
-    XSetClipOrigin(dpy, gc, sx2, sy2);
-    XSetFillStyle(dpy, gc, FillSolid);
     if (tkimg->colr != None && imfsample->show_color) {
-	if (eimg->istile) {
+	if (img->istile) {
 	    XSetFillStyle(dpy, gc, FillTiled);
 	    XSetTile(dpy, gc, tkimg->colr);
 	    XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
 	} else {
+	  if (use_clip_mask) {
 	    if (tkimg->mask != None && imfsample->show_masks) {
+	        XSetClipOrigin(dpy, gc, sx2, sy2);
 		/* Use the image's mask to do clipped drawing. */
 		XSetClipMask(dpy, gc, tkimg->mask);
 	    }
-	    /* Draw the color image. */
-	    XCopyArea(dpy, tkimg->colr, d, gc, 0, 0, sw, sh, sx, sy);
+	  } else {
+	    if (tkimg->mask != None && imfsample->show_masks) {
+	      XSetFunction(dpy, gc, GXand);
+	      XCopyArea(dpy, tkimg->mask, d, gc, 0, 0, sw, sh, sx, sy);
+	    }
+	    XSetFunction(dpy, gc, GXor);
+	  }
+	  /* Draw the color image. */
+	  XCopyArea(dpy, tkimg->colr, d, gc, 0, 0, sw, sh, sx, sy);
+	  if (!use_clip_mask)
+	    XSetFunction(dpy, gc, GXcopy);
 	}
     } else if (tkimg->solid != NULL && imfsample->show_color) {
+	XSetFillStyle(dpy, gc, FillSolid);
 	XSetForeground(dpy, gc, tkimg->solid->pixel);
 	XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
     } else if (tkimg->mono != None || tkimg->mask != None) {
-	/* Set the color we're going to use for the mask; use the
-	   imagecolor if we'll be using the mask as the only image. */
-	XSetForeground(dpy, gc,
-		       (tkimg->mono == None ? imagecolor : maskcolor)->pixel);
-	/* Set the clip mask to be explicit mask or unit's image. */
-	if (tkimg->mask && imfsample->show_masks)
-	  XSetClipMask(dpy, gc, tkimg->mask);
-	else
-	  XSetClipMask(dpy, gc, tkimg->mono);
-	/* Draw the mask. */
-	XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
-	/* Draw the image proper. */
-	if (tkimg->mono != None) {
+	if (use_clip_mask) {
+	  XSetFillStyle(dpy, gc, FillSolid);
+	  /* Set the color we're going to use for the mask; use the
+	     imagecolor if we'll be using the mask as the only image. */
+	  XSetForeground(dpy, gc,
+			 (tkimg->mono == None ? imagecolor : maskcolor)->pixel);
+	  XSetClipOrigin(dpy, gc, sx2, sy2);
+	  /* Set the clip mask to be explicit mask or unit's image. */
+	  if (tkimg->mask && imfsample->show_masks)
+	    XSetClipMask(dpy, gc, tkimg->mask);
+	  else
+	    XSetClipMask(dpy, gc, tkimg->mono);
+	  /* Draw the mask. */
+	  XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
+	  /* Draw the image proper. */
+	  if (tkimg->mono != None) {
 	    XSetForeground(dpy, gc, imagecolor->pixel);
 	    XSetClipMask(dpy, gc, tkimg->mono);
 	    XFillRectangle(dpy, d, gc, sx, sy, sw, sh);
+	  }
+	} else {
+	  if (tkimg->mask != None && imfsample->show_masks) {
+	    XSetFunction(dpy, gc, GXand);
+	    XCopyArea(dpy, tkimg->mask, d, gc, 0, 0, sw, sh, sx, sy);
+	  }
+	  if (tkimg->mono != None) {
+	    XSetFunction(dpy, gc, GXor);
+	    XCopyArea(dpy, tkimg->mono, d, gc, 0, 0, sw, sh, sx, sy);
+	  }
+	  XSetFunction(dpy, gc, GXcopy);
 	}
     }
 }
