@@ -14,9 +14,6 @@ any later version.  See the file COPYING.  */
 
 char tmpbuf[500];
 
-int numremotes;
-int my_rid;
-
 int
 main(int argc, char *argv[])
 {
