@@ -1123,7 +1123,7 @@ XtPointer call_data;
 	  continue;
 	/* acp left? */
 	if ((filters[numutypes+2] || filters[numutypes+3]) &&
-	    !(unit->act && unit->act->acp > 0))
+	    !has_acp_left(unit))
 	  continue;
 
 	/* unit is OK */
