@@ -495,7 +495,7 @@ Map *map;
     clear_current(side, map);
     unit = unit_at(nx, ny);
     if (unit != NULL 
-	&& (side_controls_unit(side, unit) || all_see_all)) {
+	&& (side_controls_unit(side, unit) || side->see_all)) {
 	set_current_unit(side, map, unit);
     } else {
 	set_current_xy(side, map, nx, ny);
@@ -1967,7 +1967,7 @@ Side *side;
     } else {
 	net_become_nondesigner(side);
 	for_all_maps(side, map2) {
-	    map2->seeall = (all_see_all || side->may_set_see_all);
+	    map2->seeall = side->see_all;
 	    update_controls(side, map2);
 	    for_all_unit_types(u) {
 		enable_in_unit_type_list(side, map2, u, FALSE);
@@ -2001,7 +2001,7 @@ Side *side;
 
     net_become_designer(side);
     for_all_maps(side, map2) {
-	map2->seeall = (all_see_all || side->may_set_see_all);
+	map2->seeall = (side->see_all || side->may_set_show_all);
 	update_controls(side, map2);
 	for_all_unit_types(u) {
 	    enable_in_unit_type_list(side, map2, u, TRUE);
