@@ -1026,7 +1026,7 @@ int x, y;
 	    }
 	    if (unit == NULL) {
 		for_all_stack(x, y, unit) {
-		    if (map->seeall || unit_actually_visible(side, unit))
+		    if (unit_visible(side, map->vp, unit))
 		      break;
 		}
 	    }
@@ -1075,7 +1075,7 @@ int x, y;
 	} else {
 	    didone = FALSE;
 	    for_all_stack(x, y, unit) {
-		if (unit_actually_visible(side, unit)) {
+		if (unit_visible(side, map->vp, unit)) {
 		    x_xform_unit(side, map, unit, &sx, &sy, &sw, &sh);
 		    draw_unit_and_occs(side, map, unit, sx, sy, sw, sh, TRUE);
 		    didone = TRUE;
@@ -1368,7 +1368,7 @@ Map *map;
        that used all acp, gray if the unit can't do anything. */
     shade = (unit ?
 	     ((unit->act && unit->act->initacp > 0) ?
-	      ((unit->act->acp > 0) ? black : darkgray) :
+	      (has_acp_left(unit) ? black : darkgray) :
 	      gray) :
 	     black);
     /* Box at larger sizes need to come in slightly, otherwise we
@@ -1912,9 +1912,8 @@ Map *map;
 	if (inside_area(x, y)) {
 	    /* (should pick the "most visible" unit at x,y) */
 	    unit2 = unit_at(x, y);
-	    if ((map->seeall || units_visible(side, x, y))
-		&& unit2 != NULL
-		&& (map->seeall || unit_actually_visible(side, unit2))) {
+	    if (unit2 != NULL
+		&& unit_visible(side, map->vp, unit2)) {
 		sprintf(infobuf, "%s", unit_handle(side, unit2));
 		draw_info_text(side, map, 0, 0, len, infobuf);
 		location_desc(infobuf, side, unit2, unit2->type, x, y);
