@@ -242,7 +242,7 @@ char *geospec;
     map->vp->draw_temperature = FALSE;
     map->vp->draw_clouds = FALSE;
     map->vp->draw_winds = FALSE;
-    map->seeall = all_see_all;
+    map->seeall = side->show_all;
     map->vp->draw_cover = FALSE;
     map->vp->latlong_interval = side->ui->default_latlong_interval;
     /* Start the map off in generic move mode normally. */
@@ -640,7 +640,7 @@ Map *map;
       XtVaCreateManagedWidget("all", toggleWidgetClass, map->controlform,
 			      XtNlabel, "All",
 			      XtNresize, False,
-			      XtNsensitive, !all_see_all,
+			      XtNsensitive, side->may_set_show_all,
 			      XtNwidth, wid,
 			      XtNfromVert, map->controls[ZOOM_OUT],
 			      XtNvertDistance, 10,
@@ -1966,7 +1966,7 @@ XtPointer call_data;
 	map->vp->draw_people = !map->vp->draw_people;
 	break;
       case SHOW_ALL:
-	if (!all_see_all)
+	if (side->may_set_show_all)
 	  map->seeall = !map->seeall;
 	else
 	  beep(side);
@@ -2637,7 +2637,7 @@ Map *map;
 			      NULL);
     map->ctrlpanel_buttons[SHOW_ALL] =
       XtVaCreateManagedWidget("seeAll", toggleWidgetClass, map->ctrlpanel_form,
-			      XtNsensitive, !all_see_all,
+			      XtNsensitive, side->may_set_show_all,
 			      XtNlabel, "See All",
 			      NULL);
     map->ctrlpanel_buttons[SHOW_LATLONG] =
@@ -2898,7 +2898,7 @@ Map *map;
     set_control_state(side, map, SHOW_COVER,
 		      !map->seeall, map->vp->draw_cover);
     set_control_state(side, map, SHOW_ALL,
-		      side->may_set_see_all, map->seeall);
+		      side->may_set_show_all, map->seeall);
     set_control_state(side, map, SHOW_LATLONG,
 		      world.circumference > 0, map->vp->draw_latlong);
     set_control_state(side, map, SHOW_MORE,
